@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,19 +37,20 @@
 #include "callbacks_mainwindow_menu.h"
 #include "gui_savedialog.h"
 #include "support.h"
-#include "types.h"
 #include "gui_utils.h"
 #include "utils.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "gui_netkeyer.h"
 #include "netkeyer.h"
+#include "main.h"
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *mainnotebook;
 extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
 extern keyerstatetype keyerstate;
+extern statetype state;
 extern GList *logwindowlist;
 extern GtkUIManager *ui_manager;
 
@@ -64,22 +65,22 @@ on_mainwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 	gboolean logchanged = FALSE;
 
 	for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logwindow = g_list_nth_data (logwindowlist, i);
-			if (logwindow->logchanged) logchanged = TRUE;
-		}
+	{
+		logwindow = g_list_nth_data (logwindowlist, i);
+		if (logwindow->logchanged) logchanged = TRUE;
+	}
 
 	if (logchanged)
-		{
-			create_savedialog ();
-			return (TRUE);
-		}
+	{
+		create_savedialog ();
+		return (TRUE);
+	}
 	else
-		{
-			save_windowsize_and_cleanup ();
-			gtk_main_quit ();
-			return (FALSE);
-		}
+	{
+		save_windowsize_and_cleanup ();
+		gtk_main_quit ();
+		return (FALSE);
+	}
 }
 
 /* switch between pages of the notebook */
@@ -243,6 +244,26 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 			}
 		}
 	break;
+	case GDK_Up:
+		if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
+		{
+			if (preferences.polltime == 0)
+				get_frequency ();
+			set_frequency (state.rigfrequency + 100);
+		}
+		else
+			return FALSE;
+	break;
+	case GDK_Down:
+		if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
+		{
+			if (preferences.polltime == 0)
+				get_frequency ();
+			set_frequency (state.rigfrequency - 100);
+		}
+		else
+			return FALSE;
+	break;
 	default:
 	return FALSE;
 	break;
@@ -250,6 +271,26 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	else
 	switch (event->keyval)
 	{
+		case GDK_Up:
+			if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
+			{
+				if (preferences.polltime == 0)
+					get_frequency ();
+				set_frequency (state.rigfrequency + 50);
+			}
+			else
+				return FALSE;
+		break;
+		case GDK_Down:
+			if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
+			{
+				if (preferences.polltime == 0)
+					get_frequency ();
+				set_frequency (state.rigfrequency - 50);
+			}
+			else
+				return FALSE;
+		break;
 		default:
 		return FALSE;
 		break;
