@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,11 @@
 #include "callbacks_mainwindow_list.h"
 #include "callbacks_mainwindow_qsoframe.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "utils.h"
+#include "gui_utils.h"
 #include "log.h"
+#include "main.h"
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *mainnotebook;
@@ -46,9 +48,9 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		*myrstentry, *remtv, *bandentry, *modeentry, *outcheckbutton,
 		*incheckbutton, *powerentry, *nameentry, *qthentry, *locatorentry,
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
-		*qsoframe, *framelabel;
-	gchar *frametext, *bandcopy, *entry, **bandspl, **modespl;
-	guint i, page, bandindex = 0, modeindex = 0;
+		*qsoframe, *framelabel, *awardsentry;
+	gchar *frametext, *bandcopy, *entry;
+	guint i, page;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	logtype *logw;
@@ -62,6 +64,7 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 	modeentry = lookup_widget (mainwindow, "modeentry");
 	rstentry = lookup_widget (mainwindow, "rstentry");
 	myrstentry = lookup_widget (mainwindow, "myrstentry");
+	awardsentry = lookup_widget (mainwindow, "awardsentry");
 	remtv = lookup_widget (mainwindow, "remtv");
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
@@ -77,11 +80,11 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 	/* unselect selected QSO's in the other logs */
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 	for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logw = g_list_nth_data (logwindowlist, i);
-			if (page != i)
-				gtk_tree_selection_unselect_all (gtk_tree_view_get_selection(GTK_TREE_VIEW (logw->treeview)));
-		}
+	{
+		logw = g_list_nth_data (logwindowlist, i);
+		if (page != i)
+			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection(GTK_TREE_VIEW (logw->treeview)));
+	}
 
 	if (gtk_tree_selection_get_selected (selection, &model, &iter))
 	{
@@ -92,6 +95,15 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		gtk_label_set_markup (GTK_LABEL (framelabel), frametext);
 		g_free (frametext);
 
+		/* we don't need to convert to uppercase here */
+		g_signal_handlers_block_by_func (GTK_OBJECT (awardsentry),
+			on_awardsentry_insert_text, user_data);
+		/* order matters, DXCC- string in the awards entry comes before callsign */
+		gtk_tree_model_get (model, &iter, AWARDS, &entry, -1);
+		gtk_entry_set_text (GTK_ENTRY (awardsentry), entry);
+		g_signal_handlers_unblock_by_func (GTK_OBJECT (awardsentry),
+			on_awardsentry_insert_text, user_data);
+
 		gtk_tree_model_get (model, &iter, DATE, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (dateentry), entry);
 		gtk_tree_model_get (model, &iter, GMT, &entry, -1);
@@ -100,54 +112,27 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		gtk_entry_set_text (GTK_ENTRY (endentry), entry);
 
 		/* we don't need to convert to uppercase here */
-		g_signal_handlers_block_by_func (GTK_OBJECT (callentry), on_callentry_insert_text, user_data);
+		g_signal_handlers_block_by_func (GTK_OBJECT (callentry),
+			on_callentry_insert_text, user_data);
 		gtk_tree_model_get (model, &iter, CALL, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (callentry), entry);
-		g_signal_handlers_unblock_by_func (GTK_OBJECT (callentry), on_callentry_insert_text, user_data);
+		g_signal_handlers_unblock_by_func (GTK_OBJECT (callentry),
+			on_callentry_insert_text, user_data);
 
 		/* update bandoptionmenu and entry */
 		gtk_tree_model_get (model, &iter, BAND, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (bandentry), entry);
-
-		bandspl = g_strsplit (preferences.bands, ",", 0);
 		if (strlen (entry) <= 2)
 			bandcopy = g_strdup (entry);
 		else
 			bandcopy = g_strdup(finddot (entry));
-
-		for (;;)
-		{
-			if (!bandspl[bandindex])
-				break;
-			if (g_ascii_strcasecmp (bandcopy, bandspl[bandindex]) == 0)
-			{
-				gtk_combo_box_set_active (GTK_COMBO_BOX (bandoptionmenu), 
-					bandindex);
-				break;
-			}
-			bandindex++;
-		}
+		activate_option (bandoptionmenu, preferences.bands, bandcopy);
 		g_free (bandcopy);
-		g_strfreev (bandspl);
 
 		/* update modeoptionmenu and entry */
 		gtk_tree_model_get (model, &iter, MODE, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (modeentry), entry);
-
-		modespl = g_strsplit (preferences.modes, ",", 0);
-		for (;;)
-		{
-			if (!modespl[modeindex])
-				break;
-			if (g_ascii_strcasecmp (entry, modespl[modeindex]) == 0)
-				{
-					gtk_combo_box_set_active (GTK_COMBO_BOX (modeoptionmenu), 
-						modeindex);
-					break;
-				}
-			modeindex++;
-		}
-		g_strfreev (modespl);
+		activate_option (modeoptionmenu, preferences.modes, entry);
 
 		gtk_tree_model_get (model, &iter, POWER, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (powerentry), entry);
@@ -155,6 +140,14 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		gtk_entry_set_text (GTK_ENTRY (rstentry), entry);
 		gtk_tree_model_get (model, &iter, MYRST, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (myrstentry), entry);
+
+		g_signal_handlers_block_by_func (GTK_OBJECT (awardsentry),
+			on_callentry_insert_text, user_data);
+		gtk_tree_model_get (model, &iter, AWARDS, &entry, -1);
+		gtk_entry_set_text (GTK_ENTRY (awardsentry), entry);
+		g_signal_handlers_unblock_by_func (GTK_OBJECT (awardsentry),
+			on_callentry_insert_text, user_data);
+
 		gtk_tree_model_get (model, &iter, QSLOUT, &entry, -1);
 		if (!g_ascii_strcasecmp (entry, "x") || !g_ascii_strcasecmp (entry, "y"))
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (outcheckbutton), TRUE);
