@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,25 +20,23 @@
 /*
  * callbacks_mainwindow_menu.c - menu's which don't create a dialog
  */
+#define _XOPEN_SOURCE
+#include <time.h>
 
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
-#ifndef __USE_XOPEN
-#define __USE_XOPEN
-#endif
-#include <time.h>
 
 #include "callbacks_mainwindow_menu.h"
 #include "gui_savedialog.h"
 #include "gui_utils.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "utils.h"
 #include "log.h"
 
-#include "strptime.h"
 #ifndef HAVE_STRPTIME
+#include "strptime.h"
 #define strptime(s,f,t) mystrptime(s,f,t)
 #endif
 
@@ -47,9 +45,8 @@
 # include "hamlib-utils.h"
 #endif
 
-extern GtkWidget *mainwindow;
+extern GtkWidget *mainwindow, *keyerwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
-extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
 extern GList *logwindowlist;
 
@@ -75,20 +72,20 @@ on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gboolean logchanged = FALSE;
 
 	for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logwindow = g_list_nth_data (logwindowlist, i);
-			if (logwindow->logchanged) logchanged = TRUE;
-		}
+	{
+		logwindow = g_list_nth_data (logwindowlist, i);
+		if (logwindow->logchanged) logchanged = TRUE;
+	}
 
 	if (logchanged)
-		{
-			create_savedialog ();
-		}
+	{
+		create_savedialog ();
+	}
 	else
-		{
-			save_windowsize_and_cleanup ();
-			gtk_main_quit ();
-		}
+	{
+		save_windowsize_and_cleanup ();
+		gtk_main_quit ();
+	}
 }
 
 /* save current page to the log */
@@ -108,7 +105,9 @@ on_menu_save_activate (GtkMenuItem * menuitem, gpointer user_data)
 		update_statusbar (temp);
 		g_free (temp);
 		logwindow->logchanged = FALSE;
-		gtk_label_set_text (GTK_LABEL (logwindow->label), logwindow->logname);
+		temp = g_strdup_printf ("<b>%s</b>", logwindow->logname);
+		gtk_label_set_markup (GTK_LABEL (logwindow->label), temp);
+		g_free (temp);
 	}
 }
 
@@ -173,13 +172,12 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_label_set_markup (GTK_LABEL (framelabel), temp);
 	g_free (temp);
 
-	locatorframe = lookup_widget (mainwindow, "locatorframe");
+	locatorframe = lookup_widget (scorewindow, "locatorframe");
 	if (GTK_WIDGET_VISIBLE (locatorframe))
-		{
-		locatorframe = lookup_widget (mainwindow, "locatorframe");
-			framelabel = gtk_frame_get_label_widget (GTK_FRAME(locatorframe));
-			gtk_label_set_text (GTK_LABEL (framelabel), _("Locator"));
-		}
+	{
+		framelabel = gtk_frame_get_label_widget (GTK_FRAME(locatorframe));
+		gtk_label_set_text (GTK_LABEL (framelabel), _("Locator"));
+	}
 	if (keyerwindow)
 		gtk_widget_grab_focus (callentry);
 	else
@@ -196,7 +194,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkWidget *datebutton, *gmtbutton, *endbutton, *endhbox,
 		*myrstentry, *unknown1hbox, *unknown2hbox, *unknownentry1, *unknownentry2,
 		*remarksvbox, *remtv, *bandentry, *modeentry, *rstentry, *powerhbox, 
-		*powerentry, *endentry, *callentry, *count;
+		*powerentry, *endentry, *callentry, *count, *awardsentry;
 	GtkTextBuffer *b;
 	gint c;
 	gchar *countstr, *str;
@@ -210,14 +208,14 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_signal_emit_by_name (G_OBJECT (gmtbutton), "clicked");
 	endhbox = lookup_widget (mainwindow, "endhbox");
 	if (GTK_WIDGET_VISIBLE (endhbox))
+	{
+		endentry = lookup_widget (mainwindow, "endentry");
+		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1)) == 0)
 		{
-			endentry = lookup_widget (mainwindow, "endentry");
-			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1)) == 0)
-			{
-				endbutton = lookup_widget (mainwindow, "endbutton");
-				g_signal_emit_by_name (G_OBJECT (endbutton), "clicked");
-			}
+			endbutton = lookup_widget (mainwindow, "endbutton");
+			g_signal_emit_by_name (G_OBJECT (endbutton), "clicked");
 		}
+	}
 
 	bandentry = lookup_widget (mainwindow, "bandentry");
 	modeentry = lookup_widget (mainwindow, "modeentry");
@@ -333,6 +331,12 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (myrstentry), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (myrstentry), preferences.defaultrxrst);
 	}
+	if (g_ascii_strcasecmp (preferences.defaultawards, "?"))
+	{
+		awardsentry = lookup_widget (mainwindow, "awardsentry");
+		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1)) == 0)
+			gtk_entry_set_text (GTK_ENTRY (awardsentry), preferences.defaultawards);
+	}
 	unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
 	if (GTK_WIDGET_VISIBLE (unknown1hbox)	&& g_ascii_strcasecmp (preferences.defaultfreefield1, "?"))
 	{
@@ -425,6 +429,7 @@ on_sort_log_activate (GtkMenuItem *menuitem, gpointer user_data)
 	gint page;
 	GtkTreeViewColumn *column;
 	GtkTreeModel *model;
+	gchar *label;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK(mainnotebook));
 	if (page >= 0)
@@ -436,7 +441,9 @@ on_sort_log_activate (GtkMenuItem *menuitem, gpointer user_data)
 		gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model), DATE, sort_by_date_time, NULL, NULL);
 		gtk_tree_view_column_clicked (column);
 		logw->logchanged = TRUE;
-		gtk_label_set_text (GTK_LABEL (logw->label), g_strconcat (logw->logname, " *", NULL));
+		label = g_strdup_printf ("<b>%s*</b>", logw->logname);
+		gtk_label_set_markup (GTK_LABEL (logw->label), label);
+		g_free (label);
 		gtk_tree_view_column_set_clickable (column, FALSE);
 		update_statusbar (_("Log sorted"));
 	}
