@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,28 +23,31 @@
 
 #include <gtk/gtk.h>
 #include <string.h>
+#include <stdlib.h>
 #include "callbacks_mainwindow_toolbar.h"
 #include "callbacks_mainwindow_menu.h"
 #include "support.h"
 #include "preferences.h"
-#include "types.h"
 #include "log.h"
 #include "utils.h"
+#include "main.h"
+#include "dxcc.h"
 
 #if WANT_HAMLIB
 #	include <hamlib/rig.h>
 #	include "hamlib-utils.h"
 #endif
 
-extern GtkWidget *mainwindow;
+extern GtkWidget *mainwindow, *scorewindow, *keyerwindow;
 extern GtkWidget *mainnotebook;
-extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
 extern statetype state;
 extern gchar **bandsplit;
 extern gchar **modesplit;
 extern gchar **qso;
 extern GList *logwindowlist;
+extern gushort w[400][MAX_BANDS];
+extern gushort c[400][MAX_BANDS];
 
 /* add a new qso to the log */
 void
@@ -54,17 +57,19 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		*remtv, *bandentry, *modeentry, *bandoptionmenu,
 		*modeoptionmenu, *incheckbutton, *outcheckbutton,
 		*qsoframe, *endhbox, *endentry, *powerhbox, *count,
+		*awardshbox, *awardsentry,
 		*powerentry, *namehbox, *nameentry, *qthhbox, *qthentry,
 		*locatorhbox, *locatorentry, *unknown1hbox, *unknownentry1,
 		*unknown2hbox, *unknownentry2, *qslhbox, *remarksvbox, *framelabel;
 	GtkTextBuffer *b;
 	GtkTextIter start, end;
-	gchar *temp;
-	gint bandindex, modeindex, i = 0, page, c;
+	gchar *temp, *label;
+	gint bandindex, modeindex, i = 0, page, f;
 	logtype *logw = NULL;
 	GtkTreeIter iter, selected;
 	GtkTreeModel *model;
 	GtkTreePath *path;
+	struct info lookup;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 	if (page >= 0)
@@ -116,10 +121,18 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		if (GTK_WIDGET_VISIBLE (endhbox))
 		{
 			endentry = lookup_widget (mainwindow, "endentry");
-			qso[GMTEND] =	gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1);
+			qso[GMTEND] = gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (endentry), 0, -1);
 		}
 
+		awardshbox = lookup_widget (mainwindow, "awardshbox");
+		if (GTK_WIDGET_VISIBLE (awardshbox))
+		{
+			awardsentry = lookup_widget (mainwindow, "awardsentry");
+			qso[AWARDS] = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
+			gtk_editable_delete_text (GTK_EDITABLE (awardsentry), 0, -1);
+		}
+
 		qslhbox = lookup_widget (mainwindow, "qslhbox");
 		if (GTK_WIDGET_VISIBLE (qslhbox))
 		{
@@ -184,15 +197,16 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 			b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
 			gtk_text_buffer_get_bounds (b, &start, &end);
 			qso[REMARKS] = gtk_text_buffer_get_text (b, &start, &end, TRUE);
+			g_strdelimit (qso[REMARKS], "\n", ' ');
 			gtk_text_buffer_set_text (b, "", 0);
 		}
 
 		/* add the QSO */
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
-		gtk_tree_store_prepend (GTK_TREE_STORE(model), &iter, NULL);
-		gtk_tree_store_set (GTK_TREE_STORE(model), &iter, NR, qso[NR], 
+		gtk_list_store_prepend (GTK_LIST_STORE(model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE(model), &iter, NR, qso[NR], 
 			DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND], CALL, qso[CALL], 
-			BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST], MYRST, qso[MYRST], 
+			BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST], MYRST, qso[MYRST], AWARDS, qso[AWARDS],
 			QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN], POWER, qso[POWER], NAME, qso[NAME], 
 			QTH, qso[QTH], LOCATOR, qso[LOCATOR], U1, qso[U1], U2, qso[U2], 
 			REMARKS, qso[REMARKS], -1);
@@ -215,6 +229,35 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (logw->treeview)));
 
+		if (GTK_WIDGET_VISIBLE(scorewindow))
+		{
+			/* update worked/confirmed array */
+			gchar *result = valid_awards_entry (qso[AWARDS]);
+			if (result)
+			{
+				lookup = lookupcountry_by_prefix (result);
+				g_free (result);
+			}
+			else
+				lookup = lookupcountry_by_callsign (qso[CALL]);
+			f = freq2enum (qso[BAND]);
+			if (preferences.scoringbands[f] == '1')
+			{
+				w[lookup.country][f]++;
+				w[lookup.country][BAND_ALL]++;
+				if (!g_ascii_strcasecmp (qso[QSLIN], "x") ||
+					!g_ascii_strcasecmp (qso[QSLIN], "y"))
+				{
+					c[lookup.country][f]++;
+					c[lookup.country][BAND_ALL]++;
+				}
+			/* check if this is a new country and update scoring */
+				if (w[lookup.country][f] == 1 ||
+					c[lookup.country][f] == 1)
+					update_dxccscoring ();
+			}
+		}
+
 		if (preferences.saving == 2)
 		{
 			savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
@@ -225,8 +268,9 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		{
 			temp = g_strdup_printf (_("QSO %s added to %s log"), qso[NR], logw->logname);
 			logw->logchanged = TRUE;
-			gtk_label_set_text (GTK_LABEL (logw->label),
-			g_strconcat (logw->logname, " *", NULL));
+			label = g_strdup_printf ("<b>%s*</b>", logw->logname);
+			gtk_label_set_markup (GTK_LABEL (logw->label), label);
+			g_free (label);
 		}
 		update_statusbar (temp);
 		g_free (temp);
@@ -237,11 +281,12 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		gtk_label_set_markup (GTK_LABEL (framelabel), temp);
 
 		gtk_widget_grab_focus (callentry);
+
 		if (keyerwindow)
 		{	/* increment counter for next QSO */
 			count = lookup_widget (keyerwindow, "count");
-			c = gtk_spin_button_get_value (GTK_SPIN_BUTTON (count));
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (count), c + 1);
+			i = gtk_spin_button_get_value (GTK_SPIN_BUTTON (count));
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (count), i + 1);
 		}
 	}
 }
@@ -254,25 +299,28 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *gmtbutton, *gmtentry, *endentry, *callentry, *bandentry,
 		*modeentry, *rstentry, *myrstentry, *remtv, *powerentry,
 		*nameentry, *qthentry, *unknownentry1, *unknownentry2,
-		*locatorentry, *incheckbutton, *outcheckbutton;
+		*locatorentry, *incheckbutton, *outcheckbutton, *awardsentry;
 	GtkTextBuffer *b;
-	gchar *statustext, *qsonumber;
-	gint i, page;
+	gchar *qsonumber, *label, *call, *freq, *awards, *temp;
+	gboolean qslin;
+	gint i, page, f;
 	logtype *logw;
 	GtkTreeIter selected, iter;
 	GtkTreeModel *model;
+	struct info lookup;
  
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 	logw = g_list_nth_data (logwindowlist, page);
 
 	if (page >= 0)
 	{
-		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(logw->treeview)), &model, &selected))
+		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection
+			(GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 		{
 			gtk_tree_model_get (model, &selected, NR, &qsonumber, -1);
-			statustext = g_strdup_printf (_("QSO %s deleted, %s log renumbered"), qsonumber, logw->logname);
-			update_statusbar (statustext);
-			g_free (statustext);
+			temp = g_strdup_printf (_("QSO %s deleted, %s log renumbered"),
+				qsonumber, logw->logname);
+			update_statusbar (temp);
 
 			gmtentry = lookup_widget (mainwindow, "gmtentry");
 			endentry = lookup_widget (mainwindow, "endentry");
@@ -281,6 +329,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			modeentry = lookup_widget (mainwindow, "modeentry");
 			rstentry = lookup_widget (mainwindow, "rstentry");
 			myrstentry = lookup_widget (mainwindow, "myrstentry");
+			awardsentry = lookup_widget (mainwindow, "awardsentry");
 			remtv = lookup_widget (mainwindow, "remtv");
 			incheckbutton = lookup_widget (mainwindow, "incheckbutton");
 			outcheckbutton = lookup_widget (mainwindow, "outcheckbutton");
@@ -292,14 +341,22 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
 			gtk_editable_delete_text (GTK_EDITABLE (gmtentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (endentry), 0, -1);
+
+			call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (callentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (modeentry), 0, -1);
+
+			freq = gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (bandentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (rstentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (myrstentry), 0, -1);
+
+			awards = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
+			gtk_editable_delete_text (GTK_EDITABLE (awardsentry), 0, -1);
 			b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
 			gtk_text_buffer_set_text (b, "", 0);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (outcheckbutton), FALSE);
+			qslin = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (incheckbutton));
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (incheckbutton), FALSE);
 			gtk_editable_delete_text (GTK_EDITABLE (powerentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (nameentry), 0, -1);
@@ -309,13 +366,15 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_editable_delete_text (GTK_EDITABLE (unknownentry2), 0, -1);
 
 			/* now remove the QSO from the log */
-			gtk_tree_store_remove (GTK_TREE_STORE (model), &selected);
+			gtk_list_store_remove (GTK_LIST_STORE (model), &selected);
 			logw->qsos--;
 
 			if (preferences.saving != 2)
 			{
 				logw->logchanged = TRUE;
-				gtk_label_set_text (GTK_LABEL (logw->label),	g_strconcat (logw->logname, " *", NULL));
+				label = g_strdup_printf ("<b>%s*</b>", logw->logname);
+				gtk_label_set_markup (GTK_LABEL (logw->label), label);
+				g_free (label);
 			}
 
 			/* update the first column with the number of qso's */
@@ -323,7 +382,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			for (i = 0; i < logw->qsos; i++)
 			{
 				qsonumber = g_strdup_printf ("%d", logw->qsos - i);
-				gtk_tree_store_set (GTK_TREE_STORE(model), &iter, NR, qsonumber, -1); 
+				gtk_list_store_set (GTK_LIST_STORE(model), &iter, NR, qsonumber, -1); 
 				g_free (qsonumber);
 				if (!(i % 50)) /* needed for responsiveness */
 				{
@@ -335,11 +394,43 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			gmtbutton = lookup_widget (mainwindow, "gmtbutton");
 			gtk_widget_grab_focus (gmtbutton);
 
+			if (GTK_WIDGET_VISIBLE(scorewindow))
+			{
+				/* update worked/confirmed array */
+				gchar *result = valid_awards_entry (awards);
+				if (result)
+				{
+					lookup = lookupcountry_by_prefix (result);
+					g_free (result);
+				}
+				else
+				lookup = lookupcountry_by_callsign (call);
+
+				f = freq2enum (freq);
+				if (preferences.scoringbands[f] == '1')
+				{
+					w[lookup.country][f]--;
+					w[lookup.country][BAND_ALL]--;
+					if (qslin)
+					{
+						c[lookup.country][f]--;
+						c[lookup.country][BAND_ALL]--;
+					}
+		/* check if this is the only country on this frequency */
+					if (w[lookup.country][f] == 0 ||
+						c[lookup.country][f] == 0)
+						update_dxccscoring ();
+				}
+			}
 			if (preferences.saving == 2)
 			{
 				savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
 				logw->logchanged = FALSE;
 			}
+		g_free (call);
+		g_free (freq);
+		g_free (awards);
+		g_free (temp);
 		}
 	}
 }
@@ -352,18 +443,19 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *dateentry, *gmtentry, *callentry, *rstentry, *myrstentry,
 		*remtv, *bandentry, *modeentry, *incheckbutton,
 		*outcheckbutton, *modeoptionmenu, *bandoptionmenu,
-		*qsoframe, *endhbox, *endentry, *powerhbox,
+		*qsoframe, *endhbox, *endentry, *powerhbox, *awardshbox, *awardsentry,
 		*powerentry, *namehbox, *nameentry, *qthhbox, *qthentry,
 		*locatorhbox, *locatorentry, *unknown1hbox, *unknownentry1,
 		*unknown2hbox, *unknownentry2, *qslhbox, *remarksvbox, *gmtbutton,
 		*framelabel;
 	GtkTextBuffer *b;
 	GtkTextIter start, end;
-	gint bandindex, modeindex, i = 0, page;
-	gchar *statustext, *temp;
+	gint bandindex, modeindex, i = 0, page, f;
+	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards;
 	logtype *logw;
 	GtkTreeIter selected;
 	GtkTreeModel *model;
+	struct info lookup;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 	logw = g_list_nth_data (logwindowlist, page);
@@ -383,11 +475,12 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 		for (i = 0; i < QSO_FIELDS; i++)
 			qso[i] = g_strdup ("");
 
-		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(logw->treeview)), &model, &selected))
+		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection
+			(GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 		{
 			gtk_tree_model_get (model, &selected, NR, &qso[NR], -1);
 					
-			qso[DATE] =	gtk_editable_get_chars (GTK_EDITABLE (dateentry), 0, -1);
+			qso[DATE] = gtk_editable_get_chars (GTK_EDITABLE (dateentry), 0, -1);
 			qso[GMT] = gtk_editable_get_chars (GTK_EDITABLE (gmtentry), 0, -1);
 			qso[CALL] = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
 
@@ -411,6 +504,14 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				qso[MODE] = lookup_mode (modeindex);
 			}
 
+			awardshbox = lookup_widget (mainwindow, "awardshbox");
+			if (GTK_WIDGET_VISIBLE (awardshbox))
+			{
+				awardsentry = lookup_widget (mainwindow, "awardsentry");
+				qso[AWARDS] = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
+				gtk_editable_delete_text (GTK_EDITABLE (awardsentry), 0, -1);
+			}
+
 			powerhbox = lookup_widget (mainwindow, "powerhbox");
 			if (GTK_WIDGET_VISIBLE (powerhbox))
 			{
@@ -426,7 +527,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			if (GTK_WIDGET_VISIBLE (endhbox))
 			{
 				endentry = lookup_widget (mainwindow, "endentry");
-				qso[GMTEND] =	gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1);
+				qso[GMTEND] = gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1);
 				gtk_editable_delete_text (GTK_EDITABLE (endentry), 0, -1);
 			}
 
@@ -451,7 +552,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			if (GTK_WIDGET_VISIBLE (namehbox))
 			{
 				nameentry = lookup_widget (mainwindow, "nameentry");
-				qso[NAME] =	gtk_editable_get_chars (GTK_EDITABLE (nameentry), 0, -1);
+				qso[NAME] = gtk_editable_get_chars (GTK_EDITABLE (nameentry), 0, -1);
 				gtk_editable_delete_text (GTK_EDITABLE (nameentry), 0, -1);
 			}
 
@@ -475,7 +576,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			if (GTK_WIDGET_VISIBLE (unknown1hbox))
 			{
 				unknownentry1 = lookup_widget (mainwindow, "unknownentry1");
-				qso[U1] =	gtk_editable_get_chars (GTK_EDITABLE (unknownentry1), 0, -1);
+				qso[U1] = gtk_editable_get_chars (GTK_EDITABLE (unknownentry1), 0, -1);
 				gtk_editable_delete_text (GTK_EDITABLE (unknownentry1), 0, -1);
 			}
 
@@ -483,7 +584,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			if (GTK_WIDGET_VISIBLE (unknown2hbox))
 			{
 				unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
-				qso[U2] =	gtk_editable_get_chars (GTK_EDITABLE (unknownentry2), 0, -1);
+				qso[U2] = gtk_editable_get_chars (GTK_EDITABLE (unknownentry2), 0, -1);
 				gtk_editable_delete_text (GTK_EDITABLE (unknownentry2), 0, -1);
 			}
 
@@ -494,18 +595,26 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
 				gtk_text_buffer_get_bounds (b, &start, &end);
 				qso[REMARKS] = gtk_text_buffer_get_text (b, &start, &end, TRUE);
+				g_strdelimit (qso[REMARKS], "\n", ' ');
 				gtk_text_buffer_set_text (b, "", 0);
 			}
 
+			/* save call and freq for scoring */
+			gtk_tree_model_get (model, &selected, CALL, &logcall, -1);
+			gtk_tree_model_get (model, &selected, BAND, &logfreq, -1);
+			gtk_tree_model_get (model, &selected, QSLIN, &logqslin, -1);
+			gtk_tree_model_get (model, &selected, AWARDS, &logawards, -1);
+
 			/* change the selected QSO */
-			gtk_tree_store_set (GTK_TREE_STORE(model), &selected, NR, qso[NR], 
+			gtk_list_store_set (GTK_LIST_STORE(model), &selected, NR, qso[NR], 
 				DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND], CALL, qso[CALL], 
-				BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST], MYRST, qso[MYRST], 
+				BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST], MYRST, qso[MYRST], AWARDS, qso[AWARDS],
 				QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN], POWER, qso[POWER], NAME, qso[NAME], 
 				QTH, qso[QTH], LOCATOR, qso[LOCATOR], U1, qso[U1], U2, qso[U2], 
 				REMARKS, qso[REMARKS], -1);
 
-			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (logw->treeview)));
+			gtk_tree_selection_unselect_all
+				(gtk_tree_view_get_selection (GTK_TREE_VIEW (logw->treeview)));
 
 			gtk_editable_delete_text (GTK_EDITABLE (gmtentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (callentry), 0, -1);
@@ -520,22 +629,80 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			framelabel = gtk_frame_get_label_widget (GTK_FRAME(qsoframe));
 			temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
 			gtk_label_set_markup (GTK_LABEL (framelabel), temp);
-			g_free (temp);
+
+			if (GTK_WIDGET_VISIBLE(scorewindow))
+			{ /* first we delete, then we add */
+				gchar *result = valid_awards_entry (logawards);
+				if (result)
+				{
+					lookup = lookupcountry_by_prefix (result);
+					g_free (result);
+				}
+				else
+				lookup = lookupcountry_by_callsign (logcall);
+
+				f = freq2enum (logfreq);
+				if (preferences.scoringbands[f] == '1')
+				{
+
+					w[lookup.country][f]--;
+					w[lookup.country][BAND_ALL]--;
+
+					if (!g_ascii_strcasecmp (logqslin, "x") ||
+						!g_ascii_strcasecmp (logqslin, "y"))
+					{
+						c[lookup.country][f]--;
+						c[lookup.country][BAND_ALL]--;
+					}
+				}
+
+				result = valid_awards_entry (qso[AWARDS]);
+				if (result)
+				{
+					lookup = lookupcountry_by_prefix (result);
+					g_free (result);
+				}
+				else
+				lookup = lookupcountry_by_callsign (qso[CALL]);
+
+				f = freq2enum (qso[BAND]);
+				if (preferences.scoringbands[f] == '1')
+				{
+
+					w[lookup.country][f]++;
+					w[lookup.country][BAND_ALL]++;
+
+					if (!g_ascii_strcasecmp (qso[QSLIN], "x") ||
+						!g_ascii_strcasecmp (qso[QSLIN], "y"))
+					{
+						c[lookup.country][f]++;
+						c[lookup.country][BAND_ALL]++;
+					}
+				}
+
+				/* don't bother if this is a new one or if a
+					country is deleted, just update scoring */
+				update_dxccscoring ();
+			}
 
 			if (preferences.saving == 2)
 			{
 				savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
 				logw->logchanged = FALSE;
-				statustext = g_strdup_printf (_("QSO %s updated in %s log, log saved"),	qso[NR], logw->logname);
+				temp = g_strdup_printf (_("QSO %s updated in %s log, log saved"),
+					qso[NR], logw->logname);
 			}
 			else
 			{
 				logw->logchanged = TRUE;
-				gtk_label_set_text (GTK_LABEL (logw->label),	g_strconcat (logw->logname, " *", NULL));
-				statustext =	g_strdup_printf (_("QSO %s updated in %s log"), qso[NR], logw->logname);
+				label = g_strdup_printf ("<b>%s*</b>", logw->logname);
+				gtk_label_set_markup (GTK_LABEL (logw->label), label);
+				g_free (label);
+				temp = g_strdup_printf (_("QSO %s updated in %s log"),
+					qso[NR], logw->logname);
 			}
-			update_statusbar (statustext);
-			g_free (statustext);
+			update_statusbar (temp);
+			g_free (temp);
 
 			gmtbutton = lookup_widget (mainwindow, "gmtbutton");
 			gtk_widget_grab_focus (gmtbutton);
