@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "callbacks_preferencesdialog.h"
 #include "gui_utils.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "utils.h"
 
@@ -41,7 +41,6 @@
 extern GtkWidget *mainwindow;
 extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
-extern keyerstatetype keyerstate;
 extern GtkWidget *preferencesdialog;
 extern gint clocktimer, savetimer;
 extern GList *logwindowlist;
