@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 #include <libgnomeprint/gnome-print-job.h>
 
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "utils.h"
 #include "callbacks_printdialog.h"
