@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,6 @@
 #include <gtk/gtk.h>
 
 #include "support.h"
-#include "types.h"
 #include "utils.h"
 #include "gc.h"
 
@@ -158,14 +157,14 @@ parse (gchar * s, gdouble * lat, gdouble * lon)
 	}
 
 	/* Prevent ACOS() Domain Error */
-	if (*lat == 90.0)	*lat = 89.9;
+	if (*lat == 90.0) *lat = 89.9;
 	if (*lat == -90.0) *lat = -89.9;
 
 	return (0);
 }
 
 gchar *
-gc (gint units, gchar * qth, gdouble DEST_Lat, gdouble DEST_Long)
+greatcircle (gint units, gchar * qth, gdouble DEST_Lat, gdouble DEST_Long)
 {
 	gdouble tmp, arc, cosaz, az, azsp, azlp, distsp, distlp;
 	gdouble QTH_Lat = 0, QTH_Long = 0, Delta_Long;
