@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,4 +21,4 @@
  * gc.h
  */
 
-gchar *gc (gint units, gchar * qth, gdouble DEST_Lat, gdouble DEST_Long);
+gchar *greatcircle (gint units, gchar * qth, gdouble DEST_Lat, gdouble DEST_Long);
