@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,5 +19,5 @@
 
 /* gui_b4dialog.h */
 
-GtkWidget* create_b4dialog (void);
+GtkWidget* create_b4window (void);
 void on_menu_worked_activate (GtkAction *action, gpointer user_data);
