@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,11 +27,12 @@
 
 #include "gui_closedialog.h"
 #include "support.h"
-#include "types.h"
 #include "log.h"
 #include "gui_utils.h"
+#include "main.h"
+#include "dxcc.h"
 
-extern GtkWidget *mainwindow;
+extern GtkWidget *mainwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
 extern GList *logwindowlist;
 extern statetype state;
@@ -39,9 +40,7 @@ extern statetype state;
 void
 on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *closedialog, *dialog_vbox, *label, *dialog_action_area,
-		*closecancelbutton, *closeokbutton;
-	GdkPixbuf *closedialog_icon_pixbuf;
+	GtkWidget *closedialog, *label, *image, *vbox;
 	logtype *logwindow;
 	gint page, response;
 
@@ -51,34 +50,22 @@ on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 		logwindow = g_list_nth_data (logwindowlist, page);
 		if (logwindow->logchanged)
 		{
-			closedialog = gtk_dialog_new ();
-			gtk_window_set_title (GTK_WINDOW (closedialog), _("xlog - closing"));
-			gtk_window_set_position (GTK_WINDOW (closedialog), GTK_WIN_POS_MOUSE);
-			closedialog_icon_pixbuf = create_pixbuf ("xlog.png");
-			if (closedialog_icon_pixbuf)
-			{
-				gtk_window_set_icon (GTK_WINDOW (closedialog), closedialog_icon_pixbuf);
-				g_object_unref (closedialog_icon_pixbuf);
-			}
-			dialog_vbox = GTK_DIALOG (closedialog)->vbox;
-			gtk_widget_show (dialog_vbox);
-			label = gtk_label_new (_("This log has not been saved, do you want to close it anyway?"));
-			gtk_widget_show (label);
-			gtk_box_pack_start (GTK_BOX (dialog_vbox), label, FALSE, FALSE, 0);
-			gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
+			closedialog = gtk_dialog_new_with_buttons (_("xlog - closing"),
+				GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+			vbox = gtk_vbox_new (TRUE, 0);
+			gtk_container_add
+				(GTK_CONTAINER (GTK_DIALOG (closedialog)->vbox), vbox);
+			image = gtk_image_new_from_stock
+				("gtk-dialog-question", GTK_ICON_SIZE_DIALOG);
+			gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
+			label = gtk_label_new
+	(_("This log has not been saved, do you want to close it anyway?"));
+			gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 			gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 			gtk_misc_set_padding (GTK_MISC (label), 20, 20);
-			dialog_action_area = GTK_DIALOG (closedialog)->action_area;
-			gtk_widget_show (dialog_action_area);
-			gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_SPREAD);
-			closecancelbutton = gtk_button_new_from_stock ("gtk-cancel");
-			gtk_widget_show (closecancelbutton);
-			gtk_dialog_add_action_widget (GTK_DIALOG (closedialog), closecancelbutton, GTK_RESPONSE_CANCEL);
-			GTK_WIDGET_SET_FLAGS (closecancelbutton, GTK_CAN_DEFAULT);
-			closeokbutton = gtk_button_new_from_stock ("gtk-ok");
-			gtk_widget_show (closeokbutton);
-			gtk_dialog_add_action_widget (GTK_DIALOG (closedialog), closeokbutton, GTK_RESPONSE_OK);
-			GTK_WIDGET_SET_FLAGS (closeokbutton, GTK_CAN_DEFAULT);
+			gtk_widget_show_all (closedialog);
 			response = gtk_dialog_run (GTK_DIALOG(closedialog));
 			if (response == GTK_RESPONSE_OK)
 			{
@@ -89,6 +76,11 @@ on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_notebook_remove_page (GTK_NOTEBOOK (mainnotebook), page);
 				set_tabs_menu ();
 				state.logwindows--;
+				if (GTK_WIDGET_VISIBLE(scorewindow))
+				{
+					fill_worked_array ();
+					update_dxccscoring ();
+				}
 			}
 			gtk_widget_destroy (closedialog);
 		}
@@ -101,6 +93,11 @@ on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_notebook_remove_page (GTK_NOTEBOOK (mainnotebook), page);
 			set_tabs_menu ();
 			state.logwindows--;
+			if (GTK_WIDGET_VISIBLE(scorewindow))
+			{
+				fill_worked_array ();
+				update_dxccscoring ();
+			}
 		}
 	}
 }
