@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include <string.h>
 
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 
 extern GtkWidget *mainwindow;
 extern preferencestype preferences;
@@ -37,12 +37,12 @@ void
 on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *defaultsmhzentry, *defaultsmodeentry, *defaultstxrstentry,
-		*defaultsrxrstentry, *defaultspowerentry, *defaultsdialog,
+		*defaultsrxrstentry, *defaultsawardsentry, *defaultspowerentry, *defaultsdialog,
 		*defaultsfreefield1entry, *defaultsfreefield2entry, *defaultsremarksentry,
 		*defaultsfreefield1label, *defaultsfreefield2label,
 		*mainvbox, *defaultslabel, *frame, *framevbox, *hbox1, *mhzlabel,
 		*hbox2, *modelabel, *hbox3, *txrstlabel, *hbox4, *rxrstlabel,
-		*hbox5, *powerlabel, *hbox6, *hbox7, *hbox8, *remarkslabel;
+		*hbox9, *awardslabel, *hbox5, *powerlabel, *hbox6, *hbox7, *hbox8, *remarkslabel;
 	gchar *temp;
 	gint response;
 
@@ -71,6 +71,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox1), defaultsmhzentry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultsmhzentry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultsmhzentry), 15);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsmhzentry), TRUE);
 	hbox2 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox2, FALSE, FALSE, 0);
 	modelabel = gtk_label_new (_("Mode"));
@@ -79,6 +80,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox2), defaultsmodeentry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultsmodeentry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultsmodeentry), 8);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsmodeentry), TRUE);
 	hbox3 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox3, FALSE, FALSE, 0);
 	txrstlabel = gtk_label_new ("TX(RST)");
@@ -87,6 +89,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox3), defaultstxrstentry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultstxrstentry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultstxrstentry), 15);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultstxrstentry), TRUE);
 	hbox4 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox4, FALSE, FALSE, 0);
 	rxrstlabel = gtk_label_new ("RX(RST)");
@@ -95,6 +98,16 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox4), defaultsrxrstentry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultsrxrstentry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultsrxrstentry), 15);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsrxrstentry), TRUE);
+	hbox9 = gtk_hbox_new (TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (framevbox), hbox9, FALSE, FALSE, 0);
+	awardslabel = gtk_label_new (_("Awards"));
+	gtk_box_pack_start (GTK_BOX (hbox9), awardslabel, FALSE, FALSE, 0);
+	defaultsawardsentry = gtk_entry_new ();
+	gtk_box_pack_start (GTK_BOX (hbox9), defaultsawardsentry, FALSE, FALSE, 0);
+	gtk_widget_set_size_request (defaultsawardsentry, 150, -1);
+	gtk_entry_set_max_length (GTK_ENTRY (defaultsawardsentry), 30);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsawardsentry), TRUE);
 	hbox5 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox5, FALSE, FALSE, 0);
 	powerlabel = gtk_label_new (_("Power"));
@@ -103,6 +116,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox5), defaultspowerentry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultspowerentry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultspowerentry), 8);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultspowerentry), TRUE);
 	hbox6 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox6, FALSE, FALSE, 0);
 	defaultsfreefield1label = gtk_label_new (_("Freefield1"));
@@ -111,6 +125,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox6), defaultsfreefield1entry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultsfreefield1entry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultsfreefield1entry), 30);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsfreefield1entry), TRUE);
 	hbox7 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox7, FALSE, FALSE, 0);
 	defaultsfreefield2label = gtk_label_new (_("Freefield2"));
@@ -119,6 +134,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox7), defaultsfreefield2entry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultsfreefield2entry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultsfreefield2entry), 30);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsfreefield2entry), TRUE);
 	hbox8 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (framevbox), hbox8, FALSE, FALSE, 0);
 	remarkslabel = gtk_label_new (_("Remarks"));
@@ -127,6 +143,7 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox8), defaultsremarksentry, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (defaultsremarksentry, 150, -1);
 	gtk_entry_set_max_length (GTK_ENTRY (defaultsremarksentry), 80);
+	gtk_entry_set_activates_default (GTK_ENTRY (defaultsremarksentry), TRUE);
 
 	gtk_label_set_text (GTK_LABEL(defaultsfreefield1label), 
 		preferences.freefield1);
@@ -134,7 +151,8 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 		preferences.freefield2);
 
 	if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
-		gtk_entry_set_text (GTK_ENTRY (defaultsmhzentry), preferences.defaultmhz);
+		gtk_entry_set_text (GTK_ENTRY (defaultsmhzentry),
+			preferences.defaultmhz);
 	if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
 		gtk_entry_set_text (GTK_ENTRY (defaultsmodeentry),
 			preferences.defaultmode);
@@ -144,6 +162,9 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (g_ascii_strcasecmp (preferences.defaultrxrst, "?"))
 		gtk_entry_set_text (GTK_ENTRY (defaultsrxrstentry),
 			preferences.defaultrxrst);
+	if (g_ascii_strcasecmp (preferences.defaultawards, "?"))
+		gtk_entry_set_text (GTK_ENTRY (defaultsawardsentry),
+			preferences.defaultawards);
 	if (g_ascii_strcasecmp (preferences.defaultpower, "?"))
 		gtk_entry_set_text (GTK_ENTRY (defaultspowerentry),
 			preferences.defaultpower);
@@ -157,6 +178,8 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_entry_set_text (GTK_ENTRY (defaultsremarksentry),
 			preferences.defaultremarks);
 
+	gtk_dialog_set_default_response (GTK_DIALOG (defaultsdialog),
+                                             GTK_RESPONSE_OK);
 	gtk_widget_show_all (defaultsdialog);
 	response = gtk_dialog_run (GTK_DIALOG(defaultsdialog));
 	if (response == GTK_RESPONSE_OK)
@@ -166,41 +189,55 @@ on_menu_defaults_activate (GtkMenuItem * menuitem, gpointer user_data)
 			preferences.defaultmhz = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultmhz, temp))
 			preferences.defaultmhz = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultsmodeentry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaultmode = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultmode, temp))
 			preferences.defaultmode = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultstxrstentry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaulttxrst = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaulttxrst, temp))
 			preferences.defaulttxrst = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultsrxrstentry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaultrxrst = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultrxrst, temp))
 			preferences.defaultrxrst = g_strdup (temp);
+
+		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultsawardsentry), 0, -1);
+		if (strlen (temp) == 0)
+			preferences.defaultawards = g_strdup ("?");
+		else if (g_ascii_strcasecmp (preferences.defaultawards, temp))
+			preferences.defaultawards = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultspowerentry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaultpower = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultpower, temp))
 			preferences.defaultpower = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultsfreefield1entry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaultfreefield1 = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultfreefield1, temp))
 			preferences.defaultfreefield1 = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultsfreefield2entry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaultfreefield2 = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultfreefield2, temp))
 			preferences.defaultfreefield2 = g_strdup (temp);
+
 		temp = gtk_editable_get_chars (GTK_EDITABLE (defaultsremarksentry), 0, -1);
 		if (strlen (temp) == 0)
 			preferences.defaultremarks = g_strdup ("?");
 		else if (g_ascii_strcasecmp (preferences.defaultremarks, temp))
 			preferences.defaultremarks = g_strdup (temp);
+
 		g_free (temp);
 	}
 	gtk_widget_destroy (defaultsdialog);
