@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,10 +30,10 @@
 
 #include "gui_dialogsdialog.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 
 extern GtkWidget *mainwindow;
-extern GtkWidget *b4dialog;
+extern GtkWidget *b4window;
 extern preferencestype preferences;
 
 void
@@ -42,16 +42,16 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	GtkWidget *dialogsdialog, *notebook, *vbox, *label,
 		*frame, *framehbox, *leftvbox, *middlevbox, *rightvbox, *vbox2,
 		*b40, *b41, *b42, *b43, *b44, *b45, *b46, *b47, *b48, *b49,
-		*b410, *b411, *b412, *b413, *b414, *b415, *b416, *b417, *b418,
+		*b410, *b411, *b412, *b413, *b414, *b415, *b416, *b417, *b418, *b419,
 		*badif, *hsep, *bu1, *bu2, *bu3, *bu4, *bu5, *bu6, *bu7, *bu8,
-		*bu9, *bu10, *bu11, *bu12, *bu13, *bu14, *bu15, *bu16, *bu17,
+		*bu9, *bu10, *bu11, *bu12, *bu13, *bu14, *bu15, *bu16, *bu17, *bu18,
 		*b4treeview, *tsvhbox, *bucalc;
 	gchar **states, **split;
 	gboolean check;
 	GtkTreeViewColumn *column;
 	gint i, response;
 
-	split = g_strsplit(preferences.b4columns, ",", 0);
+	split = g_strsplit(preferences.b4columns2, ",", 0);
 	dialogsdialog = gtk_dialog_new_with_buttons (_("xlog - dialogs"),
 		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
@@ -106,36 +106,39 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	b49 = gtk_check_button_new_with_label ("RX(RST)");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b49), atoi(split[9]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), b49, FALSE, FALSE, 0);
-	b410 = gtk_check_button_new_with_label (_("Qsl Out"));
+	b410 = gtk_check_button_new_with_label (_("Awards"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b410), atoi(split[10]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), b410, FALSE, FALSE, 0);
-	b411 = gtk_check_button_new_with_label (_("Qsl In"));
+	b411 = gtk_check_button_new_with_label (_("Qsl Out"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b411), atoi(split[11]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), b411, FALSE, FALSE, 0);
-	b412 = gtk_check_button_new_with_label (_("Power"));
+	b412 = gtk_check_button_new_with_label (_("Qsl In"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b412), atoi(split[12]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), b412, FALSE, FALSE, 0);
+	b413 = gtk_check_button_new_with_label (_("Power"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b413), atoi(split[13]));
+	gtk_box_pack_start (GTK_BOX (middlevbox), b413, FALSE, FALSE, 0);
 
 	rightvbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (framehbox), rightvbox, FALSE, FALSE, 0);
-	b413 = gtk_check_button_new_with_label (_("Name"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b413), atoi(split[13]));
-	gtk_box_pack_start (GTK_BOX (rightvbox), b413, FALSE, FALSE, 0);
-	b414 = gtk_check_button_new_with_label ("QTH");
+	b414 = gtk_check_button_new_with_label (_("Name"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b414), atoi(split[14]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), b414, FALSE, FALSE, 0);
-	b415 = gtk_check_button_new_with_label (_("Locator"));
+	b415 = gtk_check_button_new_with_label ("QTH");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b415), atoi(split[15]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), b415, FALSE, FALSE, 0);
-	b416 = gtk_check_button_new_with_label (_("Freefield1"));
+	b416 = gtk_check_button_new_with_label (_("Locator"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b416), atoi(split[16]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), b416, FALSE, FALSE, 0);
-	b417 = gtk_check_button_new_with_label (_("Freefield2"));
+	b417 = gtk_check_button_new_with_label ("");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b417), atoi(split[17]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), b417, FALSE, FALSE, 0);
-	b418 = gtk_check_button_new_with_label (_("Remarks"));
+	b418 = gtk_check_button_new_with_label ("");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b418), atoi(split[18]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), b418, FALSE, FALSE, 0);
+	b419 = gtk_check_button_new_with_label (_("Remarks"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (b419), atoi(split[19]));
+	gtk_box_pack_start (GTK_BOX (rightvbox), b419, FALSE, FALSE, 0);
 
 	g_strfreev(split);
 
@@ -168,7 +171,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	tsvhbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (vbox2), tsvhbox);
 
-	split = g_strsplit(preferences.saveastsv, ",", 0);
+	split = g_strsplit(preferences.saveastsv2, ",", 0);
 	leftvbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (tsvhbox), leftvbox, FALSE, FALSE, 0);
 	bu1 = gtk_check_button_new_with_label (_("Date"));
@@ -198,36 +201,39 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	bu8 = gtk_check_button_new_with_label ("RX(RST)");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu8), atoi(split[7]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), bu8, FALSE, FALSE, 0);
-	bu9 = gtk_check_button_new_with_label (_("Qsl Out"));
+	bu9 = gtk_check_button_new_with_label (_("Awards"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu9), atoi(split[8]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), bu9, FALSE, FALSE, 0);
-	bu10 = gtk_check_button_new_with_label (_("Qsl In"));
+	bu10 = gtk_check_button_new_with_label (_("Qsl Out"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu10), atoi(split[9]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), bu10, FALSE, FALSE, 0);
-	bu11 = gtk_check_button_new_with_label (_("Power"));
+	bu11 = gtk_check_button_new_with_label (_("Qsl In"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu11), atoi(split[10]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), bu11, FALSE, FALSE, 0);
-	bu12 = gtk_check_button_new_with_label (_("Name"));
+	bu12 = gtk_check_button_new_with_label (_("Power"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu12), atoi(split[11]));
 	gtk_box_pack_start (GTK_BOX (middlevbox), bu12, FALSE, FALSE, 0);
 
 	rightvbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (tsvhbox), rightvbox, FALSE, FALSE, 0);
-	bu13 = gtk_check_button_new_with_label ("QTH");
+	bu13 = gtk_check_button_new_with_label (_("Name"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu13), atoi(split[12]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), bu13, FALSE, FALSE, 0);
-	bu14 = gtk_check_button_new_with_label (_("Locator"));
+	bu14 = gtk_check_button_new_with_label ("QTH");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu14), atoi(split[13]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), bu14, FALSE, FALSE, 0);
-	bu15 = gtk_check_button_new_with_label (_("Freefield1"));
+	bu15 = gtk_check_button_new_with_label (_("Locator"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu15), atoi(split[14]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), bu15, FALSE, FALSE, 0);
-	bu16 = gtk_check_button_new_with_label (_("Freefield2"));
+	bu16 = gtk_check_button_new_with_label ("");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu16), atoi(split[15]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), bu16, FALSE, FALSE, 0);
-	bu17 = gtk_check_button_new_with_label (_("Remarks"));
+	bu17 = gtk_check_button_new_with_label ("");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu17), atoi(split[16]));
 	gtk_box_pack_start (GTK_BOX (rightvbox), bu17, FALSE, FALSE, 0);
+	bu18 = gtk_check_button_new_with_label (_("Remarks"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bu18), atoi(split[17]));
+	gtk_box_pack_start (GTK_BOX (rightvbox), bu18, FALSE, FALSE, 0);
 
 	g_strfreev(split);
 
@@ -247,155 +253,165 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
 		gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), label);
 
-	gtk_button_set_label (GTK_BUTTON (b416), preferences.freefield1);
-	gtk_button_set_label (GTK_BUTTON (b417), preferences.freefield2);
-	gtk_button_set_label (GTK_BUTTON (bu15), preferences.freefield1);
-	gtk_button_set_label (GTK_BUTTON (bu16), preferences.freefield2);
+	gtk_button_set_label (GTK_BUTTON (b417), preferences.freefield1);
+	gtk_button_set_label (GTK_BUTTON (b418), preferences.freefield2);
+	gtk_button_set_label (GTK_BUTTON (bu16), preferences.freefield1);
+	gtk_button_set_label (GTK_BUTTON (bu17), preferences.freefield2);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialogsdialog),
+                                             GTK_RESPONSE_OK);
 
 	gtk_widget_show_all (dialogsdialog);	
 	response = gtk_dialog_run (GTK_DIALOG(dialogsdialog));
 	if (response == GTK_RESPONSE_OK)
 	{
-		states = g_new0 (gchar *, 20);
-		b4treeview = lookup_widget (b4dialog, "b4treeview");
+		states = g_new0 (gchar *, 21);
+		b4treeview = lookup_widget (b4window, "b4treeview");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b40));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 0);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[0] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b41));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 1);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[1] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b42));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 2);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[2] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b43));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 3);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[3] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b44));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 4);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[4] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b45));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 5);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[5] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b46));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 6);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[6] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b47));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 7);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[7] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b48));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 8);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[8] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b49));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 9);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[9] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b410));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 10);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[10] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b411));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 11);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[11] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b412));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 12);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[12] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b413));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 13);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[13] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b414));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 14);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[14] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b415));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 15);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[15] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b416));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 16);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[16] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b417));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 17);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[17] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b418));
-		if (b4dialog && GTK_WIDGET_VISIBLE (b4dialog))
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
 		{
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 18);
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
 		}
 		states[18] = g_strdup (check ? "1" : "0");
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(b419));
+		if (b4window && GTK_WIDGET_VISIBLE (b4window))
+		{
+			column = gtk_tree_view_get_column (GTK_TREE_VIEW(b4treeview), 19);
+			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), check);
+		}
+		states[19] = g_strdup (check ? "1" : "0");
 
-		states[19] = NULL;	/* terminator for g_strjoinv */
-		preferences.b4columns = g_strjoinv (",", states);
+		states[20] = NULL;	/* terminator for g_strjoinv */
+		preferences.b4columns2 = g_strjoinv (",", states);
 
-		for (i = 0; i < 19; i++)
+		for (i = 0; i < 21; i++)
 			g_free (states[i]);
 		g_free (states);
 
@@ -405,7 +421,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		else
 			preferences.saveasadif = 0;
 
-		states = g_new0 (gchar *, 18);
+		states = g_new0 (gchar *, 19);
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bu1));
 		states[0] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bu2));
@@ -440,11 +456,13 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		states[15] = g_strdup (check ? "1" : "0");
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bu17));
 		states[16] = g_strdup (check ? "1" : "0");
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bu18));
+		states[17] = g_strdup (check ? "1" : "0");
 
-		states[17] = NULL;	/* terminator for g_strjoinv */
-		preferences.saveastsv = g_strjoinv (",", states);
+		states[18] = NULL;	/* terminator for g_strjoinv */
+		preferences.saveastsv2 = g_strjoinv (",", states);
 
-		for (i = 0; i < 17; i++)
+		for (i = 0; i < 18; i++)
 			g_free (states[i]);
 		g_free (states);
 
