@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "gui_exportdialog.h"
 #include "support.h"
@@ -99,6 +99,8 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 		selection = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S, NULL);
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (exportdialog), selection);
 		g_free (selection);
+		gtk_dialog_set_default_response (GTK_DIALOG (exportdialog),
+						 GTK_RESPONSE_OK);
 
 		export_response = gtk_dialog_run (GTK_DIALOG (exportdialog));
 		if (export_response == GTK_RESPONSE_OK)
