@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,16 +29,19 @@
 
 #include "gui_mergedialog.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "utils.h"
 #include "gui_utils.h"
+#include "main.h"
+#include "dxcc.h"
 
-extern GtkWidget *mainwindow;
+extern GtkWidget *mainwindow, *scorewindow;
+extern GtkWidget *mainnotebook;
 extern preferencestype preferences;
 extern statetype state;
 extern GList *logwindowlist;
-extern GtkWidget *mainnotebook;
+
 GtkWidget *importlogdialog;
 static GtkWidget *previewscrolledwindow;
 
@@ -155,11 +158,12 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 	LOGDB *lp;
 	logtype *logw;
 	gboolean logexists = FALSE;
+	GtkTreePath *path;
 
 	importlogdialog = gtk_dialog_new_with_buttons (_("xlog - import"),
 		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		GTK_STOCK_APPLY, GTK_RESPONSE_OK,
+		_("_Import"), GTK_RESPONSE_OK,
 		NULL);
 	gtk_window_set_default_size (GTK_WINDOW (importlogdialog), 400, 120);
 	vbox = gtk_vbox_new (TRUE, 0);
@@ -171,8 +175,7 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (vbox), loghbox, FALSE, FALSE, 0);
 	logentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (loghbox), logentry, TRUE, TRUE, 0);
-	gtk_editable_set_editable (GTK_EDITABLE (logentry), FALSE);
-	GTK_WIDGET_UNSET_FLAGS (logentry, GTK_CAN_FOCUS);
+	gtk_entry_set_activates_default (GTK_ENTRY (logentry), TRUE);
 
 	logbutton = gtk_button_new_from_stock (GTK_STOCK_OPEN);
 	gtk_box_pack_start (GTK_BOX (loghbox), logbutton, FALSE, FALSE, 0);
@@ -194,6 +197,8 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 		G_CALLBACK (on_importlogbutton_clicked), NULL);
 	GLADE_HOOKUP_OBJECT (importlogdialog, logentry, "logentry");
 
+	gtk_dialog_set_default_response (GTK_DIALOG (importlogdialog),
+		GTK_RESPONSE_OK);
 	gtk_widget_show_all (importlogdialog);
 	response = gtk_dialog_run (GTK_DIALOG (importlogdialog));
 	if (response == GTK_RESPONSE_OK)
@@ -224,17 +229,31 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 			{
 				logn = logname (g_path_get_basename (log));
 				logw =	openlog (lp, logn, state.logwindows++);
-				g_free (logn);
+				gtk_notebook_set_current_page 
+					(GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
 				log_file_qso_foreach (lp, fillin_list, logw);
 				log_file_close (lp);
+				g_free (logn);
 				logw->filename = g_strconcat
-					(preferences.savedir, G_DIR_SEPARATOR_S, logn, ".xlog", NULL);
+					(preferences.savedir, G_DIR_SEPARATOR_S, logw->logname, ".xlog", NULL);
 				lp->type = filetype + 1;
 				logwindowlist =	g_list_append (logwindowlist, logw);
 				gtk_notebook_set_current_page 
 					(GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
 				set_qsoframe (logw);
 				set_tabs_menu ();
+
+				if (GTK_WIDGET_VISIBLE(scorewindow))
+				{
+					fill_worked_array ();
+					update_dxccscoring ();
+				}
+
+				path = gtk_tree_path_new_from_string ("0");
+					gtk_tree_view_scroll_to_cell
+			(GTK_TREE_VIEW (logw->treeview), path, NULL, TRUE, 0.5, 0.0);
+				gtk_tree_path_free (path);
+
 				set_font (preferences.logfont);
 				temp = g_strdup_printf (_("%d QSO's imported"), state.qsos);
 				update_statusbar (temp);
