@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include <string.h>
 
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "utils.h"
 #include "gui_logeditordialog.h"
@@ -109,7 +109,7 @@ static gboolean wchanged (gpointer arg)
 	gboolean ret = FALSE;
 
 	temp = g_strjoinv (",", arg);
-	if (g_ascii_strcasecmp (temp, preferences.logcwidths) != 0)
+	if (g_ascii_strcasecmp (temp, preferences.logcwidths2) != 0)
 		ret = TRUE;
 	g_free (temp);
 	return ret;
@@ -119,10 +119,10 @@ void
 on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *logeditor, 
-		*endhbox, *powerhbox,*qslhbox, *namehbox, *qthhbox, *locatorhbox, 
-		*unknown1hbox, *unknown2hbox, *remarksvbox, *unknownlabel1, 
-		*unknownlabel2, *dialog_vbox, *mainvbox, *mainhbox, *fieldlabel, 
-		*showhidelabel, *widthlabel, *hseparator, 
+		*endhbox, *awardshbox, *powerhbox, *qslhbox, *namehbox, *qthhbox,
+		*locatorhbox,  *unknown1hbox, *unknown2hbox, *remarksvbox,
+		*unknownlabel1, *unknownlabel2, *hbox, *vboxleft, *vboxright, *hboxtopleft,
+		*hboxtopright, *fieldlabel, *showhidelabel, *widthlabel, *hsep, *vsep, 
 		*lehbox0, *lelabel0_1, *lelabel0_2, *lee0,
 		*lehbox1, *lelabel1_1, *lelabel1_2, *lee1,
 		*lehbox2, *lelabel2_1, *lelabel2_2, *lee2,
@@ -132,6 +132,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*lehbox6, *lelabel6_1, *lelabel6_2, *lee6,
 		*lehbox7, *lelabel7_1, *lelabel7_2, *lee7,
 		*lehbox8, *lelabel8_1, *lelabel8_2, *lee8,
+		*lehbox18, *lelabel18, *lecombo18, *lee18,
 		*lehbox9_10, *lelabel9_10, *lecombo9_10, *lee9_10,
 		*lehbox11, *lelabel11, *lecombo11, *lee11,
 		*lehbox12, *lelabel12, *lecombo12, *lee12,
@@ -139,9 +140,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*lehbox14, *lelabel14, *lecombo14, *lee14,
 		*lehbox15, *leentry15, *lecombo15, *lee15,
 		*lehbox16, *leentry16, *lecombo16, *lee16,
-		*lehbox17, *lelabel17_1, *lecombo17, *lee17,
-		*dialog_action_area, *logeditorcancelbutton, *logeditorokbutton;
-	GdkPixbuf *logeditor_icon_pixbuf;
+		*lehbox17, *lelabel17_1, *lecombo17, *lee17;
 	logtype *logw;
 	gchar *temp, **w;
 	gint i, j, index, page, response, columns, fields[QSO_FIELDS];
@@ -151,44 +150,37 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	if (page >= 0)
 	{
-		w = g_strsplit(preferences.logcwidths, ",", 0);
+		w = g_strsplit(preferences.logcwidths2, ",", 0);
 		
-		logeditor = gtk_dialog_new ();
-		gtk_window_set_title (GTK_WINDOW (logeditor), _("xlog - logeditor"));
-		gtk_window_set_position (GTK_WINDOW (logeditor), GTK_WIN_POS_MOUSE);
-		logeditor_icon_pixbuf = create_pixbuf ("xlog.png");
-		if (logeditor_icon_pixbuf)
-		{
-			gtk_window_set_icon (GTK_WINDOW (logeditor), logeditor_icon_pixbuf);
-			g_object_unref (logeditor_icon_pixbuf);
-		}
+		logeditor = gtk_dialog_new_with_buttons (_("xlog - logeditor"),
+			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+		hbox = gtk_hbox_new (FALSE, 0);
+		gtk_container_add
+			(GTK_CONTAINER (GTK_DIALOG (logeditor)->vbox), hbox);
+		vboxleft = gtk_vbox_new (FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), vboxleft, FALSE, FALSE, 0);
+		vsep = gtk_vseparator_new ();
+		gtk_box_pack_start (GTK_BOX (hbox), vsep, FALSE, FALSE, 0);
+		vboxright = gtk_vbox_new (FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), vboxright, FALSE, FALSE, 0);
 
-		dialog_vbox = GTK_DIALOG (logeditor)->vbox;
-		gtk_widget_show (dialog_vbox);
-
-		mainvbox = gtk_vbox_new (FALSE, 0);
-		gtk_widget_show (mainvbox);
-		gtk_box_pack_start (GTK_BOX (dialog_vbox), mainvbox, FALSE, FALSE, 0);
-
-		mainhbox = gtk_hbox_new (TRUE, 0);
-		gtk_widget_set_size_request (mainhbox, -1, 50);
-		gtk_widget_show (mainhbox);
-		gtk_box_pack_start (GTK_BOX (mainvbox), mainhbox, TRUE, TRUE, 0);
-	
+		hboxtopleft = gtk_hbox_new (TRUE, 0);
+		gtk_widget_set_size_request (hboxtopleft, -1, 50);
+		gtk_box_pack_start (GTK_BOX (vboxleft), hboxtopleft, FALSE, FALSE, 0);
 		fieldlabel = gtk_label_new (_("Fieldname"));
-		gtk_box_pack_start (GTK_BOX (mainhbox), fieldlabel, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hboxtopleft), fieldlabel, FALSE, FALSE, 0);
 		showhidelabel = gtk_label_new (_("Show / Hide\n-This log-"));
-		gtk_box_pack_start (GTK_BOX (mainhbox), showhidelabel, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hboxtopleft), showhidelabel, FALSE, FALSE, 0);
 		widthlabel = gtk_label_new (_("Width (Pixels)\n-All logs-"));
-		gtk_box_pack_start (GTK_BOX (mainhbox), widthlabel, FALSE, FALSE, 0);
-		gtk_widget_show_all (mainhbox);
+		gtk_box_pack_start (GTK_BOX (hboxtopleft), widthlabel, FALSE, FALSE, 0);
+
+		hsep = gtk_hseparator_new ();
+		gtk_box_pack_start (GTK_BOX (vboxleft), hsep, FALSE, FALSE, 10);
 
-		hseparator = gtk_hseparator_new ();
-		gtk_widget_show (hseparator);
-		gtk_box_pack_start (GTK_BOX (mainvbox), hseparator, FALSE, FALSE, 0);
-	
 		lehbox0 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox0, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox0, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox0, -1, 30);
 		lelabel0_1 = gtk_label_new (_("QSO Number"));
 		gtk_box_pack_start (GTK_BOX (lehbox0), lelabel0_1, FALSE, FALSE, 0);
@@ -197,11 +189,15 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee0 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee0, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox0), lee0, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee0), w[NR]);
-		gtk_widget_show_all (lehbox0);
-
+		logw = g_list_nth_data (logwindowlist, page);
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), NR);
+		if (gtk_tree_view_column_get_visible (column))
+			gtk_entry_set_text (GTK_ENTRY(lee0), w[NR]);
+		else
+			gtk_entry_set_text (GTK_ENTRY(lee0), "0");
+		gtk_entry_set_activates_default (GTK_ENTRY (lee0), TRUE);
 		lehbox1 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox1, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox1, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox1, -1, 30);
 		lelabel1_1 = gtk_label_new (_("Date"));
 		gtk_box_pack_start (GTK_BOX (lehbox1), lelabel1_1, FALSE, FALSE, 0);
@@ -211,10 +207,10 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee1, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox1), lee1, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee1), w[DATE]);
-		gtk_widget_show_all (lehbox1);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee1), TRUE);
 
 		lehbox2 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox2, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox2, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox2, -1, 30);
 		lelabel2_1 = gtk_label_new ("GMT");
 		gtk_box_pack_start (GTK_BOX (lehbox2), lelabel2_1, FALSE, FALSE, 0);
@@ -224,24 +220,24 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee2, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox2), lee2, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee2), w[GMT]);
-		gtk_widget_show_all (lehbox2);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee2), TRUE);
 
 		lehbox3 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox3, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox3, FALSE, FALSE, 0);
 		lelabel3_1 = gtk_label_new (_("Endtime (GMT)"));
 		gtk_box_pack_start (GTK_BOX (lehbox3), lelabel3_1, FALSE, FALSE, 0);
 		lecombo3 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox3), lecombo3, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox3), lecombo3, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo3), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo3), _("Hide"));
 		lee3 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee3, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox3), lee3, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee3), w[GMTEND]);
-		gtk_widget_show_all (lehbox3);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee3), TRUE);
 
 		lehbox4 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox4, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox4, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox4, -1, 30);
 		lelabel4_1 = gtk_label_new (_("Call"));
 		gtk_box_pack_start (GTK_BOX (lehbox4), lelabel4_1, FALSE, FALSE, 0);
@@ -251,10 +247,10 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee4, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox4), lee4, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee4), w[CALL]);
-		gtk_widget_show_all (lehbox4);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee4), TRUE);
 
 		lehbox5 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox5, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox5, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox5, -1, 30);
 		lelabel5_1 = gtk_label_new ("MHz");
 		gtk_box_pack_start (GTK_BOX (lehbox5), lelabel5_1, FALSE, FALSE, 0);
@@ -264,10 +260,10 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee5, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox5), lee5, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee5), w[BAND]);
-		gtk_widget_show_all (lehbox5);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee5), TRUE);
 
 		lehbox6 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox6, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox6, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox6, -1, 30);
 		lelabel6_1 = gtk_label_new (_("Mode"));
 		gtk_box_pack_start (GTK_BOX (lehbox6), lelabel6_1, FALSE, FALSE, 0);
@@ -277,10 +273,10 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee6, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox6), lee6, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee6), w[MODE]);
-		gtk_widget_show_all (lehbox6);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee6), TRUE);
 
 		lehbox7 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox7, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox7, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox7, -1, 30);
 		lelabel7_1 = gtk_label_new ("TX(RST)");
 		gtk_box_pack_start (GTK_BOX (lehbox7), lelabel7_1, FALSE, FALSE, 0);
@@ -290,10 +286,10 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee7, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox7), lee7, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee7), w[RST]);
-		gtk_widget_show_all (lehbox7);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee7), TRUE);
 
 		lehbox8 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox8, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox8, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox8, -1, 30);
 		lelabel8_1 = gtk_label_new ("RX(RST)");
 		gtk_box_pack_start (GTK_BOX (lehbox8), lelabel8_1, FALSE, FALSE, 0);
@@ -303,137 +299,151 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_widget_set_size_request (lee8, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox8), lee8, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee8), w[MYRST]);
-		gtk_widget_show_all (lehbox8);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee8), TRUE);
+
+		hboxtopright = gtk_hbox_new (TRUE, 0);
+		gtk_widget_set_size_request (hboxtopright, -1, 50);
+		gtk_box_pack_start (GTK_BOX (vboxright), hboxtopright, FALSE, FALSE, 0);
+		fieldlabel = gtk_label_new (_("Fieldname"));
+		gtk_box_pack_start (GTK_BOX (hboxtopright), fieldlabel, FALSE, FALSE, 0);
+		showhidelabel = gtk_label_new (_("Show / Hide\n-This log-"));
+		gtk_box_pack_start (GTK_BOX (hboxtopright), showhidelabel, FALSE, FALSE, 0);
+		widthlabel = gtk_label_new (_("Width (Pixels)\n-All logs-"));
+		gtk_box_pack_start (GTK_BOX (hboxtopright), widthlabel, FALSE, FALSE, 0);
+
+		hsep = gtk_hseparator_new ();
+		gtk_box_pack_start (GTK_BOX (vboxright), hsep, FALSE, FALSE, 10);
+
+		lehbox18 = gtk_hbox_new (TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox18, FALSE, FALSE, 0);
+		gtk_widget_set_size_request (lehbox18, -1, 30);
+		lelabel18 = gtk_label_new (_("Awards"));
+		gtk_box_pack_start (GTK_BOX (lehbox18), lelabel18, FALSE, FALSE, 0);
+		lecombo18 = gtk_combo_box_new_text ();
+		gtk_box_pack_start (GTK_BOX (lehbox18), lecombo18, FALSE, FALSE, 0);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo18), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo18), _("Hide"));
+		lee18 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee18, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox18), lee18, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee18), w[AWARDS]);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee18), TRUE);
 
 		lehbox9_10 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox9_10, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox9_10, FALSE, FALSE, 0);
 		lelabel9_10 = gtk_label_new (_("QSL out/in"));
 		gtk_box_pack_start (GTK_BOX (lehbox9_10), lelabel9_10, FALSE, FALSE, 0);
 		lecombo9_10 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox9_10), lecombo9_10, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox9_10), lecombo9_10, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo9_10), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo9_10), _("Hide"));
 		lee9_10 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee9_10, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox9_10), lee9_10, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee9_10), w[QSLIN]);
-		gtk_widget_show_all (lehbox9_10);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee9_10), TRUE);
 
 		lehbox11 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox11);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox11, TRUE, TRUE, 0);
-
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox11, FALSE, FALSE, 0);
 		lelabel11 = gtk_label_new (_("Power"));
 		gtk_box_pack_start (GTK_BOX (lehbox11), lelabel11, FALSE, FALSE, 0);
 		lecombo11 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox11), lecombo11, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox11), lecombo11, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo11), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo11), _("Hide"));
 		lee11 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee11, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox11), lee11, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee11), w[POWER]);
-		gtk_widget_show_all (lehbox11);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee11), TRUE);
 
 		lehbox12 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox12, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox12, FALSE, FALSE, 0);
 		lelabel12 = gtk_label_new (_("Name"));
 		gtk_box_pack_start (GTK_BOX (lehbox12), lelabel12, FALSE, FALSE, 0);
 		lecombo12 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox12), lecombo12, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox12), lecombo12, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo12), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo12), _("Hide"));
 		lee12 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee12, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox12), lee12, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee12), w[NAME]);
-		gtk_widget_show_all (lehbox12);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee12), TRUE);
 
 		lehbox13 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox13, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox13, FALSE, FALSE, 0);
 		lelabel13 = gtk_label_new ("QTH");
 		gtk_box_pack_start (GTK_BOX (lehbox13), lelabel13, FALSE, FALSE, 0);
 		lecombo13 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox13), lecombo13, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox13), lecombo13, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo13), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo13), _("Hide"));
 		lee13 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee13, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox13), lee13, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee13), w[QTH]);
-		gtk_widget_show_all (lehbox13);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee13), TRUE);
 
 		lehbox14 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox14, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox14, FALSE, FALSE, 0);
 		lelabel14 = gtk_label_new (_("QTH Locator"));
 		gtk_box_pack_start (GTK_BOX (lehbox14), lelabel14, FALSE, FALSE, 0);
 		lecombo14 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox14), lecombo14, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox14), lecombo14, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo14), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo14), _("Hide"));
 		lee14 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee14, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox14), lee14, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee14), w[LOCATOR]);
-		gtk_widget_show_all (lehbox14);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee14), TRUE);
 
 		lehbox15 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox15, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox15, FALSE, FALSE, 0);
 		leentry15 = gtk_entry_new ();
 		gtk_widget_set_size_request (leentry15, 100, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox15), leentry15, FALSE, FALSE, 0);
+		gtk_entry_set_activates_default (GTK_ENTRY (leentry15), TRUE);
 		lecombo15 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox15), lecombo15, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox15), lecombo15, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo15), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo15), _("Hide"));
 		lee15 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee15, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox15), lee15, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee15), w[U1]);
-		gtk_widget_show_all (lehbox15);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee15), TRUE);
 
 		lehbox16 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox16, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox16, FALSE, FALSE, 0);
 		leentry16 = gtk_entry_new ();
 		gtk_widget_set_size_request (leentry16, 100, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox16), leentry16, FALSE, FALSE, 0);
+		gtk_entry_set_activates_default (GTK_ENTRY (leentry16), TRUE);
 		lecombo16 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox16), lecombo16, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox16), lecombo16, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo16), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo16), _("Hide"));
 		lee16 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee16, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox16), lee16, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee16), w[U2]);
-		gtk_widget_show_all (lehbox16);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee16), TRUE);
 
 		lehbox17 = gtk_hbox_new (TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox17, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (vboxright), lehbox17, FALSE, FALSE, 0);
 		lelabel17_1 = gtk_label_new (_("Remarks"));
 		gtk_box_pack_start (GTK_BOX (lehbox17), lelabel17_1, FALSE, FALSE, 0);
 		lecombo17 = gtk_combo_box_new_text ();
-		gtk_box_pack_start (GTK_BOX (lehbox17), lecombo17, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (lehbox17), lecombo17, FALSE, FALSE, 0);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo17), _("Show"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo17), _("Hide"));
 		lee17 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee17, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox17), lee17, FALSE, FALSE, 0);
 		gtk_entry_set_text (GTK_ENTRY(lee17), w[REMARKS]);
-		gtk_widget_show_all (lehbox17);
-
-		dialog_action_area = GTK_DIALOG (logeditor)->action_area;
-		gtk_widget_show (dialog_action_area);
-		gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_SPREAD);
-	
-		logeditorcancelbutton = gtk_button_new_from_stock ("gtk-cancel");
-		gtk_widget_show (logeditorcancelbutton);
-		gtk_dialog_add_action_widget (GTK_DIALOG (logeditor), logeditorcancelbutton, GTK_RESPONSE_CANCEL);
-		GTK_WIDGET_SET_FLAGS (logeditorcancelbutton, GTK_CAN_DEFAULT);
-
-		logeditorokbutton = gtk_button_new_from_stock ("gtk-ok");
-		gtk_widget_show (logeditorokbutton);
-		gtk_dialog_add_action_widget (GTK_DIALOG (logeditor), logeditorokbutton, GTK_RESPONSE_OK);
-		GTK_WIDGET_SET_FLAGS (logeditorokbutton, GTK_CAN_DEFAULT);
+		gtk_entry_set_activates_default (GTK_ENTRY (lee17), TRUE);
 
 		endhbox = lookup_widget (mainwindow, "endhbox");
 		if (GTK_WIDGET_VISIBLE (endhbox))
@@ -441,6 +451,12 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 1);
 	
+		awardshbox = lookup_widget (mainwindow, "awardshbox");
+		if (GTK_WIDGET_VISIBLE (awardshbox))
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo18), 0);
+		else
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo18), 1);
+
 		qslhbox = lookup_widget (mainwindow, "qslhbox");
 		if (GTK_WIDGET_VISIBLE (qslhbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo9_10), 0);
@@ -491,13 +507,14 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 1);
+		gtk_dialog_set_default_response (GTK_DIALOG (logeditor),
+						 GTK_RESPONSE_OK);
 
+		gtk_widget_show_all (logeditor);
 		response = gtk_dialog_run (GTK_DIALOG(logeditor));
 		if (response == GTK_RESPONSE_OK)
 		{
 
-			logw = g_list_nth_data (logwindowlist, page);
-
 			/* fields is the array with visible columns */
 			for (i = 0; i < logw->columns; i++)
 				fields[i] = logw->logfields[i];
@@ -513,6 +530,14 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (GMTEND, fields, index);
 		
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo18));
+			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), AWARDS);
+			if (index == 1)
+				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
+			else
+				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
+			update_logfields (AWARDS, fields, index);
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo9_10));
 			if (index == 1)
 			{
@@ -601,7 +626,9 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				if (fields[i] != logw->logfields[i])
 				{
 					logw->logchanged = TRUE;
-					gtk_label_set_text (GTK_LABEL (logw->label), g_strconcat (logw->logname, " *", NULL));
+					temp = g_strdup_printf ("<b>%s*</b>", logw->logname);
+					gtk_label_set_markup (GTK_LABEL (logw->label), temp);
+					g_free (temp);
 					break;
 				}
 			}
@@ -654,6 +681,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		w[MODE] = gtk_editable_get_chars (GTK_EDITABLE (lee6), 0, -1);
 		w[RST] = gtk_editable_get_chars (GTK_EDITABLE (lee7), 0, -1);
 		w[MYRST] = gtk_editable_get_chars (GTK_EDITABLE (lee8), 0, -1);
+		w[AWARDS] = gtk_editable_get_chars (GTK_EDITABLE (lee18), 0, -1);
 		w[QSLIN] = gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1);
 		w[QSLOUT] = gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1);
 		w[POWER] = gtk_editable_get_chars (GTK_EDITABLE (lee11), 0, -1);
@@ -672,18 +700,39 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				{
 					column = gtk_tree_view_get_column 
 						(GTK_TREE_VIEW(logw->treeview), j);
-					if (atoi(w[j]) > 19)
-						gtk_tree_view_column_set_fixed_width 
-							(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
+					if (j != NR)
+					{
+						if (atoi(w[j]) > 19)
+							gtk_tree_view_column_set_fixed_width 
+								(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
+						else
+						{
+							gtk_tree_view_column_set_fixed_width 
+								(GTK_TREE_VIEW_COLUMN(column), 20);
+							w[j] = g_strdup ("20");
+						}
+					}
 					else
 					{
-						gtk_tree_view_column_set_fixed_width 
-							(GTK_TREE_VIEW_COLUMN(column), 20);
-						w[j] = g_strdup ("20");
+						if (atoi(w[j]) == 0)
+							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
+						else
+						{
+							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
+							if (atoi(w[j]) > 19)
+								gtk_tree_view_column_set_fixed_width 
+									(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
+							else
+							{
+								gtk_tree_view_column_set_fixed_width 
+									(GTK_TREE_VIEW_COLUMN(column), 20);
+								w[j] = g_strdup ("20");
+							}
+						}
 					}
 				}
 			}
-			preferences.logcwidths = g_strjoinv (",", w);
+			preferences.logcwidths2 = g_strjoinv (",", w);
 		}
 		g_strfreev (w);
 		gtk_widget_destroy (logeditor);
