@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,27 +33,30 @@
 #include "gui_defaultsdialog.h"
 #include "gui_dialogsdialog.h"
 #include "gui_dupecheckdialog.h"
+#include "gui_dxcclist.h"
 #include "gui_openlogdialog.h"
 #include "gui_helpdialog.h"
+#include "gui_keys.h"
 #include "gui_logeditordialog.h"
 #include "gui_newlogdialog.h"
 #include "gui_printdialog.h"
 #include "gui_preferencesdialog.h"
 #include "gui_saveasdialog.h"
+#include "gui_scorewindow.h"
 #include "gui_searchdialog.h"
 #include "gui_netkeyer.h"
 #include "gui_mergedialog.h"
 #include "gui_importdialog.h"
 #include "gui_exportdialog.h"
 #include "gui_tracedialog.h"
+#include "gui_awards_dxcc.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 
 #if WANT_HAMLIB
 #	include "gui_tracedialog.h"
 #endif
 
-GtkWidget *mainwindow, *mainnotebook;
 GtkUIManager *ui_manager;
 extern preferencestype preferences;
 
@@ -94,30 +97,30 @@ register_my_stock_icons (void)
 GtkWidget*
 create_mainwindow (void)
 {
-	GtkWidget *mainwindow, *mainvbox, *menubar;
-	GdkPixbuf *mainwindow_icon_pixbuf;
+	GtkWidget *window, *mainvbox, *menubar;
+	GdkPixbuf *window_icon_pixbuf;
 	GtkWidget *hpaned, *qsomainvbox, *handlebox, *toolbar, *qsoscrolledwindow,
 		*qsoviewport, *qsoframesvbox;
-	GtkWidget *qsoframe,
-		*qsofieldsvbox, *datehbox, *datebutton, *dateentry, *gmthbox,
-		*gmtbutton, *gmtentry, *endhbox, *endbutton, *endentry, *callhbox,
-		*calllabel, *callentry, *bandhbox, *mhzhbox, *mhzbutton, *mhzlabel,
-		*bandhbox2, *bandentry, *modehbox, *modehbox1, *modebutton, *modelabel,
-		*modehbox2, *modeentry, *hrsthbox, *hbox1, *rstbutton, *rstlabel,
-		*rstentry, *mrsthbox, *myrstlabel, *myrstentry, *qslhbox,
-		*outcheckbutton, *incheckbutton, *powerhbox, *hbox2, *powerbutton,
-		*powerlabel, *powerentry, *namehbox, *namelabel, *nameentry, *qthhbox,
-		*qthlabel, *qthentry, *locatorhbox, *locatorlabel, *locatorentry,
-		*unknown1hbox, *unknownlabel1, *unknownentry1, *unknown2hbox,
-		*unknownlabel2, *unknownentry2, *remarksvbox, *rembox1, *rembox2,
-		*remarkslabel, *remscr, *remtv;
+	GtkWidget *qsoframe, *qsofieldsvbox,
+		*datehbox, *datebutton, *dateentry,
+		*gmthbox, *gmtbutton, *gmtentry,
+		*endhbox, *endbutton, *endentry,
+		*callhbox, *calllabel, *callentry,
+		*bandhbox, *mhzhbox, *mhzbutton, *mhzlabel, *bandhbox2, *bandentry, 
+		*modehbox, *modehbox1, *modebutton, *modelabel,	*modehbox2, *modeentry,
+		*hrsthbox, *hbox1, *rstbutton, *rstlabel, *rstentry,
+		*mrsthbox, *myrstlabel, *myrstentry,
+		*awardshbox, *awardslabel, *awardsentry,
+		*qslhbox, *outcheckbutton, *incheckbutton,
+		*powerhbox, *hbox2, *powerbutton, *powerlabel, *powerentry,
+		*namehbox, *namelabel, *nameentry,
+		*qthhbox, *qthlabel, *qthentry,
+		*locatorhbox, *locatorlabel, *locatorentry,
+		*unknown1hbox, *unknownlabel1, *unknownentry1,
+		*unknown2hbox, *unknownlabel2, *unknownentry2,
+		*remarksvbox, *rembox1, *rembox2, *remarkslabel, *remscr, *remtv;
 	GtkTextBuffer *b;
 	GtkWidget *label1;
-	GtkWidget *dxccframe, *dxccvbox, *dxcclabel1, *dxcclabel2, *dxcclabel3,
-		*dxcclabel4, *dxcclabel5;
-	GtkWidget *label2;
-	GtkWidget *locatorframe, *locatorvbox, *locatorlabel1;
-	GtkWidget *label3;
 	GtkWidget *statushbox, *statusbar, *frequencyhandlebox, *frequencyhbox,
 		*frequencypixmap, *frequencylabel, *smeterhandlebox, *smeterhbox,
 		*smeterpixmap, *smeterdrawingarea, *clockhandlebox, *clockhbox,
@@ -131,13 +134,13 @@ create_mainwindow (void)
 /* Normal items */
 static GtkActionEntry entries[] = 
 {
-  { "LogMenu", NULL, N_("_Log") },
-  { "EditMenu", NULL, N_("_Edit") },
-  { "OptionMenu", NULL, N_("_Options") },
-  { "ToolsMenu", NULL, N_("_Tools") },
-  { "TabsMenu", NULL, N_("_Page") },
-  { "SettingsMenu", NULL, N_("_Settings") },
-  { "HelpMenu", NULL, N_("_Help") },
+  { "LogMenu", NULL, N_("Log") },
+  { "EditMenu", NULL, N_("Edit") },
+  { "OptionMenu", NULL, N_("Options") },
+  { "ToolsMenu", NULL, N_("Tools") },
+  { "TabsMenu", NULL, N_("Page") },
+  { "SettingsMenu", NULL, N_("Settings") },
+  { "HelpMenu", NULL, N_("Help") },
 
   { "New", GTK_STOCK_NEW, N_("New..."), "<control>N", "New log", G_CALLBACK(on_menu_new_activate) },
   { "Open", GTK_STOCK_OPEN, N_("Open"), "<control>O", "Open a log", G_CALLBACK(on_menu_open_activate) },
@@ -163,25 +166,28 @@ static GtkActionEntry entries[] =
   { "Update", GTK_STOCK_REFRESH, N_("Update"), "<control>U",
 		N_("Update a modified log entry [Ctrl-U]"), G_CALLBACK(on_ubutton_clicked) },
 
-  { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
-  { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
+  { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "<control><shift>C", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
+  { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "<control><shift>E", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
 #if WANT_HAMLIB
-  { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
+  { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "<control><shift>T", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
 #endif
-  { "Sort", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "", "Sort log by date", G_CALLBACK(on_sort_log_activate) },
-  { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
+  { "Sort", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "<control><shift>O", "Sort log by date", G_CALLBACK(on_sort_log_activate) },
+  { "Awards", GTK_STOCK_INDEX, N_("Awards"), "", "Overview of Awards", NULL },
+  { "DXCC", GTK_STOCK_INFO, "DXCC", "<control>1", "DXCC worked/confirmed", G_CALLBACK(on_awards_dxcc_activate) },
 
   { "Defaults", GTK_STOCK_INDEX, N_("Defaults"), "<control>L", "Default values to use for logging", G_CALLBACK(on_menu_defaults_activate) },
   { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs"), "<control>B", "Settings for dialogs used", G_CALLBACK(on_menu_dialogs_activate) },
   { "Preferences", GTK_STOCK_PREFERENCES, N_("Preferences..."), "<control>G", "Preferences for xlog", G_CALLBACK(on_menu_preferences_activate) },
 
   { "Documentation", GTK_STOCK_HELP, N_("Documentation"), "", "Important documents", NULL },
-  { "About", GTK_STOCK_DIALOG_INFO, N_("About..."), "", "About xlog", G_CALLBACK(on_menu_about_activate) },
+  { "DXCC List", GTK_STOCK_JUSTIFY_FILL, N_("DXCC list"), "<control><shift>D", "Show cty.dat", G_CALLBACK(on_menu_dxcclist_activate) },
+  { "Keys", GTK_STOCK_DIALOG_INFO, N_("Keys"), "<control>Z", "Xlog keys", G_CALLBACK(on_helpkeys_activate) },
+  { "Manual", GTK_STOCK_DIALOG_INFO, N_("Manual"), "<control>H", "Xlog manual", G_CALLBACK(on_helpmanual_activate) },
+  { "About", GTK_STOCK_ABOUT, N_("About..."), "<control><shift>I", "About xlog", G_CALLBACK(on_menu_about_activate) },
 
   { "Bugs", GTK_STOCK_DIALOG_INFO, N_("Bugs"), "", "How to report bugs", G_CALLBACK(on_helpbugs_activate) },
   { "Changelog", GTK_STOCK_DIALOG_INFO, N_("Changelog"), "", "Read the changelog", G_CALLBACK(on_helpchangelog_activate) },
-  { "Faq", GTK_STOCK_DIALOG_QUESTION, N_("Faq"), "", "Frequently asked quenstions", G_CALLBACK(on_helpfaq_activate) },
-  { "Manual", GTK_STOCK_DIALOG_INFO, N_("Manual"), "<control>H", "Xlog manual", G_CALLBACK(on_helpmanual_activate) },
+  { "Faq", GTK_STOCK_DIALOG_QUESTION, N_("Faq"), "", "Frequently asked questions", G_CALLBACK(on_helpfaq_activate) },
   { "Thanks", GTK_STOCK_DIALOG_INFO, N_("Thanks"), "", "Thanks to these hams", G_CALLBACK(on_helpthanks_activate) },
   { "Todo", GTK_STOCK_DIALOG_INFO, N_("Todo"), "", "Things to do for future versions", G_CALLBACK(on_helptodo_activate) },
 
@@ -199,6 +205,8 @@ static GtkActionEntry entries[] =
 
 static GtkToggleActionEntry toggle_entries[] = 
 {
+  { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
+  { "Scoring", NULL, N_("Scoring Window"), "<control>J", "Show/hide the scoring window", G_CALLBACK(on_scoring_activate) },
   { "ShowToolbar", NULL, N_("Show Toolbar"), "<control>T", "Show/hide the toolbar", G_CALLBACK(on_view_toolbar_activate) },
   { "WorkedBefore", NULL, N_("Worked Before"), "<control>4", "Show/hide the worked before dialog", G_CALLBACK(on_menu_worked_activate) },
 };
@@ -232,18 +240,22 @@ static const char *ui_description =
 "		<menuitem action='Find'/>"
 "	 </menu>"
 "	 <menu action='OptionMenu'>"
+"		<menuitem action='Keyer'/>"
+"		<menuitem action='Scoring'/>"
 "		<menuitem action='ShowToolbar'/>"
 "		<menuitem action='WorkedBefore'/>"
 "	 </menu>"
 "	 <menu action='ToolsMenu'>"
-"		<menuitem action='Log Editor'/>"
 "		<menuitem action='Dupe Check'/>"
+"		<menuitem action='Log Editor'/>"
 #if WANT_HAMLIB
 "		<menuitem action='Trace Hamlib'/>"
 #endif
 "		<menuitem action='Sort'/>"
 "		<separator name='sep6'/>"
-"		<menuitem action='Keyer'/>"
+"		<menu action='Awards'>"
+"		  <menuitem action='DXCC'/>"
+"		</menu>"
 "	 </menu>"
 "	 <menu action='TabsMenu'>"
 "		<menuitem action='1'/>"
@@ -268,12 +280,15 @@ static const char *ui_description =
 "		  <menuitem action='Bugs'/>"
 "		  <menuitem action='Changelog'/>"
 "		  <menuitem action='Faq'/>"
-"		  <menuitem action='Manual'/>"
 "		  <menuitem action='Thanks'/>"
 "		  <menuitem action='Todo'/>"
 "		</menu>"
-"		<separator name='sep8'/>"
-"		<menuitem action='About'/>"
+"	  <separator name='sep8'/>"
+"	  <menuitem action='DXCC List'/>"
+"	  <menuitem action='Keys'/>"
+"	  <menuitem action='Manual'/>"
+"		 <separator name='sep9'/>"
+"		 <menuitem action='About'/>"
 "	 </menu>"
 "  </menubar>"
 "  <toolbar name='ToolBar'>"
@@ -285,35 +300,35 @@ static const char *ui_description =
 
 	register_my_stock_icons ();
 
-	mainwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (mainwindow), "xlog");
-	mainwindow_icon_pixbuf = create_pixbuf ("xlog.png");
-	if (mainwindow_icon_pixbuf)
+	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (window), "xlog");
+	window_icon_pixbuf = create_pixbuf ("xlog.png");
+	if (window_icon_pixbuf)
 	{
-		gtk_window_set_icon (GTK_WINDOW (mainwindow), mainwindow_icon_pixbuf);
-		g_object_unref (mainwindow_icon_pixbuf);
+		gtk_window_set_icon (GTK_WINDOW (window), window_icon_pixbuf);
+		g_object_unref (window_icon_pixbuf);
 	}
 
 	mainvbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (mainwindow), mainvbox);
+	gtk_container_add (GTK_CONTAINER (window), mainvbox);
 
 	action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, PACKAGE);
 	gtk_action_group_add_actions (action_group, entries,
-		G_N_ELEMENTS (entries), mainwindow);
+		G_N_ELEMENTS (entries), window);
 
 	if (preferences.viewtoolbar == 1)
-		toggle_entries[0].is_active = TRUE;
-	if (preferences.viewb4 == 1)
 		toggle_entries[1].is_active = TRUE;
+	if (preferences.viewb4 == 1)
+		toggle_entries[2].is_active = TRUE;
 	gtk_action_group_add_toggle_actions (action_group,
-		toggle_entries, G_N_ELEMENTS (toggle_entries), mainwindow);
+		toggle_entries, G_N_ELEMENTS (toggle_entries), window);
 
 	ui_manager = gtk_ui_manager_new ();
 	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
 
 	accel_group = gtk_ui_manager_get_accel_group (ui_manager);
-	gtk_window_add_accel_group (GTK_WINDOW (mainwindow), accel_group);
+	gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 
 	error = NULL;
 	merge_id = gtk_ui_manager_add_ui_from_string 
@@ -355,46 +370,52 @@ static const char *ui_description =
 	gtk_frame_set_label_align (GTK_FRAME (qsoframe), 0.5, 0.5);
 	qsofieldsvbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (qsoframe), qsofieldsvbox);
+
 	datehbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), datehbox, FALSE, FALSE, 0);
-	datebutton = gtk_button_new_with_label (_("Date"));
+	datebutton = gtk_button_new_with_mnemonic (_("_Date"));
 	gtk_box_pack_start (GTK_BOX (datehbox), datebutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (datebutton, 100, -1);
 	dateentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (datehbox), dateentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (dateentry), 15);
+
 	gmthbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), gmthbox, FALSE, FALSE, 0);
-	gmtbutton = gtk_button_new_with_label ("GMT");
+	gmtbutton = gtk_button_new_with_mnemonic ("_GMT");
 	gtk_box_pack_start (GTK_BOX (gmthbox), gmtbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (gmtbutton, 100, -1);
 	gmtentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (gmthbox), gmtentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (gmtentry), 8);
+
 	endhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), endhbox, FALSE, FALSE, 0);
-	endbutton = gtk_button_new_with_label (_("End (GMT)"));
+	endbutton = gtk_button_new_with_mnemonic (_("_End (GMT)"));
 	gtk_box_pack_start (GTK_BOX (endhbox), endbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (endbutton, 100, -1);
 	endentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (endhbox), endentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (endentry), 8);
+
 	callhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), callhbox, FALSE, FALSE, 0);
-	calllabel = gtk_label_new (_("Call"));
+	calllabel = gtk_label_new_with_mnemonic (_("_Call"));
 	gtk_box_pack_start (GTK_BOX (callhbox), calllabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (calllabel, 100, 17);
 	callentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(calllabel), callentry);
 	gtk_box_pack_start (GTK_BOX (callhbox), callentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (callentry), 15);
+
 	bandhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), bandhbox, FALSE, FALSE, 0);
 	mhzhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (bandhbox), mhzhbox, FALSE, FALSE, 0);
-	mhzbutton = gtk_button_new_with_label ("MHz");
+	mhzbutton = gtk_button_new_with_mnemonic ("_MHz");
 	gtk_box_pack_start (GTK_BOX (mhzhbox), mhzbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (mhzbutton, 100, -1);
-	mhzlabel = gtk_label_new ("MHz");
+	mhzlabel = gtk_label_new_with_mnemonic ("_MHz");
 	gtk_box_pack_start (GTK_BOX (mhzhbox), mhzlabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (mhzlabel, 100, -1);
 	bandhbox2 = gtk_hbox_new (FALSE, 0);
@@ -402,14 +423,15 @@ static const char *ui_description =
 	bandentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (bandhbox2), bandentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (bandentry), 15);
+
 	modehbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), modehbox, FALSE, FALSE, 0);
 	modehbox1 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (modehbox), modehbox1, FALSE, FALSE, 0);
-	modebutton = gtk_button_new_with_label (_("Mode"));
+	modebutton = gtk_button_new_with_mnemonic (_("M_ode"));
 	gtk_box_pack_start (GTK_BOX (modehbox1), modebutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (modebutton, 100, -1);
-	modelabel = gtk_label_new (_("Mode"));
+	modelabel = gtk_label_new_with_mnemonic (_("M_ode"));
 	gtk_box_pack_start (GTK_BOX (modehbox1), modelabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (modelabel, 100, -1);
 	modehbox2 = gtk_hbox_new (FALSE, 0);
@@ -417,93 +439,119 @@ static const char *ui_description =
 	modeentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (modehbox2), modeentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (modeentry), 8);
+
 	hrsthbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), hrsthbox, FALSE, FALSE, 0);
 	hbox1 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hrsthbox), hbox1, FALSE, FALSE, 0);
-	rstbutton = gtk_button_new_with_label ("TX(RST)");
+	rstbutton = gtk_button_new_with_mnemonic ("_TX(RST)");
 	gtk_box_pack_start (GTK_BOX (hbox1), rstbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (rstbutton, 100, -1);
-	rstlabel = gtk_label_new ("TX(RST)");
+	rstlabel = gtk_label_new_with_mnemonic ("_TX(RST)");
 	gtk_box_pack_start (GTK_BOX (hbox1), rstlabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (rstlabel, 100, -1);
 	rstentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(rstlabel), rstentry);
 	gtk_box_pack_start (GTK_BOX (hrsthbox), rstentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (rstentry), 15);
+
 	mrsthbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), mrsthbox, FALSE, FALSE, 0);
-	myrstlabel = gtk_label_new ("RX(RST)");
+	myrstlabel = gtk_label_new_with_mnemonic ("_RX(RST)");
 	gtk_box_pack_start (GTK_BOX (mrsthbox), myrstlabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (myrstlabel, 100, -1);
 	myrstentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(myrstlabel), myrstentry);
 	gtk_box_pack_start (GTK_BOX (mrsthbox), myrstentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (myrstentry), 15);
+
+	awardshbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), awardshbox, FALSE, FALSE, 0);
+	awardslabel = gtk_label_new_with_mnemonic (_("_Awards"));
+	gtk_box_pack_start (GTK_BOX (awardshbox), awardslabel, FALSE, FALSE, 0);
+	gtk_widget_set_size_request (awardslabel, 100, -1);
+	awardsentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(awardslabel), awardsentry);
+	gtk_box_pack_start (GTK_BOX (awardshbox), awardsentry, TRUE, TRUE, 0);
+	gtk_entry_set_max_length (GTK_ENTRY (awardsentry), 30);
+
 	qslhbox = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), qslhbox, FALSE, FALSE, 0);
-	outcheckbutton = gtk_check_button_new_with_label (_("QSL out"));
+	outcheckbutton = gtk_check_button_new_with_mnemonic (_("_QSL out"));
 	gtk_box_pack_start (GTK_BOX (qslhbox), outcheckbutton, FALSE, FALSE, 0);
-	GTK_WIDGET_UNSET_FLAGS (outcheckbutton, GTK_CAN_FOCUS);
-	incheckbutton = gtk_check_button_new_with_label (_("QSL in"));
+	incheckbutton = gtk_check_button_new_with_mnemonic (_("Q_SL in"));
 	gtk_box_pack_start (GTK_BOX (qslhbox), incheckbutton, FALSE, FALSE, 0);
-	GTK_WIDGET_UNSET_FLAGS (incheckbutton, GTK_CAN_FOCUS);
+
 	powerhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), powerhbox, FALSE, FALSE, 0);
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (powerhbox), hbox2, FALSE, FALSE, 0);
-	powerbutton = gtk_button_new_with_label (_("Power"));
+	powerbutton = gtk_button_new_with_mnemonic (_("_Power"));
 	gtk_box_pack_start (GTK_BOX (hbox2), powerbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (powerbutton, 100, -1);
-	powerlabel = gtk_label_new (_("Power"));
+	powerlabel = gtk_label_new_with_mnemonic (_("_Power"));
 	gtk_box_pack_start (GTK_BOX (hbox2), powerlabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (powerlabel, 100, -1);
 	powerentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(powerlabel), powerentry);
 	gtk_box_pack_start (GTK_BOX (powerhbox), powerentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (powerentry), 8);
+
 	namehbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), namehbox, FALSE, FALSE, 0);
-	namelabel = gtk_label_new (_("Name"));
+	namelabel = gtk_label_new_with_mnemonic (_("_Name"));
 	gtk_box_pack_start (GTK_BOX (namehbox), namelabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (namelabel, 100, -1);
 	nameentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(namelabel), nameentry);
 	gtk_box_pack_start (GTK_BOX (namehbox), nameentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (nameentry), 30);
+
 	qthhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), qthhbox, FALSE, FALSE, 0);
-	qthlabel = gtk_label_new ("QTH");
+	qthlabel = gtk_label_new_with_mnemonic ("QT_H");
 	gtk_box_pack_start (GTK_BOX (qthhbox), qthlabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (qthlabel, 100, -1);
 	qthentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(qthlabel), qthentry);
 	gtk_box_pack_start (GTK_BOX (qthhbox), qthentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (qthentry), 30);
+
 	locatorhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), locatorhbox, FALSE, FALSE, 0);
-	locatorlabel = gtk_label_new (_("Locator"));
+	locatorlabel = gtk_label_new_with_mnemonic (_("_Locator"));
 	gtk_box_pack_start (GTK_BOX (locatorhbox), locatorlabel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (locatorlabel, 100, -1);
 	locatorentry = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(locatorlabel), locatorentry);
 	gtk_box_pack_start (GTK_BOX (locatorhbox), locatorentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (locatorentry), 8);
+
 	unknown1hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), unknown1hbox, FALSE, FALSE, 0);
-	unknownlabel1 = gtk_label_new ("");
+	unknownlabel1 = gtk_label_new_with_mnemonic ("");
 	gtk_box_pack_start (GTK_BOX (unknown1hbox), unknownlabel1, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (unknownlabel1, 100, -1);
 	unknownentry1 = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(unknownlabel1), unknownentry1);
 	gtk_box_pack_start (GTK_BOX (unknown1hbox), unknownentry1, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (unknownentry1), 30);
+
 	unknown2hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), unknown2hbox, FALSE, FALSE, 0);
-	unknownlabel2 = gtk_label_new ("");
+	unknownlabel2 = gtk_label_new_with_mnemonic ("");
 	gtk_box_pack_start (GTK_BOX (unknown2hbox), unknownlabel2, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (unknownlabel2, 100, -1);
 	unknownentry2 = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(unknownlabel2), unknownentry2);
 	gtk_box_pack_start (GTK_BOX (unknown2hbox), unknownentry2, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (unknownentry2), 30);
+
 	remarksvbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), remarksvbox, FALSE, FALSE, 0);
 	rembox1 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (remarksvbox), rembox1, FALSE, FALSE, 0);
-	remarkslabel = gtk_label_new (_("Remarks"));
+	remarkslabel = gtk_label_new_with_mnemonic (_("Remar_ks"));
 	gtk_box_pack_start (GTK_BOX (rembox1), remarkslabel, TRUE, TRUE, 0);
 	rembox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (remarksvbox), rembox2, FALSE, FALSE, 0);
@@ -514,50 +562,18 @@ static const char *ui_description =
 	gtk_scrolled_window_set_shadow_type
 		(GTK_SCROLLED_WINDOW (remscr), GTK_SHADOW_ETCHED_IN);
 	remtv = gtk_text_view_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL(remarkslabel), remtv);
 	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(remtv), GTK_WRAP_WORD);
 	b = gtk_text_view_get_buffer (GTK_TEXT_VIEW(remtv));
 	gtk_text_buffer_create_tag (b, "tiny", "size", 8 * PANGO_SCALE, NULL);
 	gtk_container_add (GTK_CONTAINER (remscr), remtv);
+
 	temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
 	label1 = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (label1), temp);
 	g_free (temp);
 	gtk_frame_set_label_widget (GTK_FRAME (qsoframe), label1);
 
-	/* locator information frame */
-	locatorframe = gtk_frame_new (NULL);
-	gtk_box_pack_start (GTK_BOX (qsoframesvbox), locatorframe, TRUE, TRUE, 0);
-	gtk_frame_set_label_align (GTK_FRAME (locatorframe), 0.5, 0.5);
-	locatorvbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (locatorframe), locatorvbox);
-	locatorlabel1 = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (locatorvbox), locatorlabel1, FALSE, FALSE, 0);
-	label3 = gtk_label_new (_("Locator"));
-	gtk_frame_set_label_widget (GTK_FRAME (locatorframe), label3);
-
-	/* dxcc information frame */
-	dxccframe = gtk_frame_new (NULL);
-	gtk_box_pack_start (GTK_BOX (qsoframesvbox), dxccframe, TRUE, TRUE, 0);
-	gtk_frame_set_label_align (GTK_FRAME (dxccframe), 0.5, 0.5);
-	dxccvbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (dxccframe), dxccvbox);
-	dxcclabel1 = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel1, FALSE, FALSE, 0);
-	dxcclabel2 = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel2, FALSE, FALSE, 0);
-	dxcclabel3 = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel3, FALSE, FALSE, 0);
-	dxcclabel4 = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel4, FALSE, FALSE, 0);
-	dxcclabel5 = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel5, FALSE, FALSE, 0);
-	label2 = gtk_label_new (NULL);
-	gtk_label_set_markup (GTK_LABEL (label2), "<b>DXCC</b>");
-	gtk_frame_set_label_widget (GTK_FRAME (dxccframe), label2);
-	gtk_label_set_line_wrap (GTK_LABEL (dxcclabel1), TRUE);
-	gtk_widget_set_size_request (dxcclabel1, 200, 60);
-	gtk_label_set_justify (GTK_LABEL (dxcclabel1), GTK_JUSTIFY_CENTER);
-
 	/* status bar */
 	statushbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (mainvbox), statushbox, FALSE, FALSE, 0);
@@ -568,7 +584,7 @@ static const char *ui_description =
 	gtk_box_pack_start (GTK_BOX (statushbox), frequencyhandlebox, FALSE, FALSE, 0);
 	frequencyhbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (frequencyhandlebox), frequencyhbox);
-	frequencypixmap = create_pixmap (mainwindow, "mini-trx.xpm");
+	frequencypixmap = create_pixmap (window, "mini-trx.xpm");
 	gtk_box_pack_start (GTK_BOX (frequencyhbox), frequencypixmap, FALSE, FALSE, 0);
 	gtk_misc_set_padding (GTK_MISC (frequencypixmap), 5, 0);
 	frequencylabel = gtk_label_new ("");
@@ -579,7 +595,7 @@ static const char *ui_description =
 	smeterhbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (smeterhandlebox), smeterhbox);
 	gtk_container_set_border_width (GTK_CONTAINER (smeterhbox), 2);
-	smeterpixmap = create_pixmap (mainwindow, "s.xpm");
+	smeterpixmap = create_pixmap (window, "s.xpm");
 	gtk_box_pack_start (GTK_BOX (smeterhbox), smeterpixmap, FALSE, FALSE, 0);
 	smeterdrawingarea = gtk_drawing_area_new ();
 	gtk_box_pack_start (GTK_BOX (smeterhbox), smeterdrawingarea, TRUE, TRUE, 0);
@@ -588,7 +604,7 @@ static const char *ui_description =
 	gtk_box_pack_start (GTK_BOX (statushbox), clockhandlebox, FALSE, FALSE, 0);
 	clockhbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (clockhandlebox), clockhbox);
-	clockpixmap = create_pixmap (mainwindow, "mini-clock.xpm");
+	clockpixmap = create_pixmap (window, "mini-clock.xpm");
 	gtk_box_pack_start (GTK_BOX (clockhbox), clockpixmap, FALSE, FALSE, 0);
 	gtk_misc_set_padding (GTK_MISC (clockpixmap), 5, 0);
 	clocklabel = gtk_label_new ("");
@@ -596,9 +612,9 @@ static const char *ui_description =
 	gtk_misc_set_padding (GTK_MISC (clocklabel), 5, 0);
 
 	gtk_widget_show_all (mainvbox);
-	g_signal_connect ((gpointer) mainwindow, "delete_event",
+	g_signal_connect ((gpointer) window, "delete_event",
 		G_CALLBACK (on_mainwindow_delete_event), NULL);
-	g_signal_connect ((gpointer) mainwindow, "key_press_event",
+	g_signal_connect ((gpointer) window, "key_press_event",
 		G_CALLBACK (on_mainwindow_keypress), NULL);
 	g_signal_connect ((gpointer) datebutton, "clicked",
 		G_CALLBACK (on_datebutton_clicked), NULL);
@@ -613,80 +629,101 @@ static const char *ui_description =
 	g_signal_connect ((gpointer) locatorentry, "changed",
 		G_CALLBACK (on_locatorentry_changed), NULL);
 	g_signal_connect (G_OBJECT(b), "changed", G_CALLBACK (tv_changed), NULL);
+	g_signal_connect ((gpointer) awardsentry, "insert_text",
+		G_CALLBACK (on_awardsentry_insert_text), NULL);
+	g_signal_connect ((gpointer) awardsentry, "changed",
+		G_CALLBACK (on_awardsentry_changed), NULL);
+
+	g_signal_connect (G_OBJECT(bandentry), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(1));
+	g_signal_connect (G_OBJECT(modeentry), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(2));
+	g_signal_connect (G_OBJECT(rstentry), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(3));
+	g_signal_connect (G_OBJECT(myrstentry), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(4));
+	g_signal_connect (G_OBJECT(awardsentry), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(5));
+	g_signal_connect (G_OBJECT(powerentry), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(6));
+	g_signal_connect (G_OBJECT(unknownentry1), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(7));
+	g_signal_connect (G_OBJECT(unknownentry2), "mnemonic-activate",
+		G_CALLBACK (entry_mnemonic_activate), GINT_TO_POINTER(8));
+
+	g_signal_connect (G_OBJECT(remtv), "mnemonic-activate",
+		G_CALLBACK (tv_mnemonic_activate), NULL);
 
 	/* Store pointers to all widgets, for use by lookup_widget(). */
-	GLADE_HOOKUP_OBJECT_NO_REF (mainwindow, mainwindow, "mainwindow");
+	GLADE_HOOKUP_OBJECT_NO_REF (window, window, "window");
 	
-	GLADE_HOOKUP_OBJECT (mainwindow, handlebox, "handlebox");
-	GLADE_HOOKUP_OBJECT (mainwindow, hpaned, "hpaned");
-	GLADE_HOOKUP_OBJECT (mainwindow, qsoframe, "qsoframe");
-	GLADE_HOOKUP_OBJECT (mainwindow, datebutton, "datebutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, dateentry, "dateentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, gmtbutton, "gmtbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, gmtentry, "gmtentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, endhbox, "endhbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, endbutton, "endbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, endentry, "endentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, calllabel, "calllabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, callentry, "callentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, mhzbutton, "mhzbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, mhzlabel, "mhzlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, bandhbox2, "bandhbox2");
-	GLADE_HOOKUP_OBJECT (mainwindow, bandentry, "bandentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, modebutton, "modebutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, modelabel, "modelabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, modehbox2, "modehbox2");
-	GLADE_HOOKUP_OBJECT (mainwindow, modeentry, "modeentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, rstbutton, "rstbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, rstlabel, "rstlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, rstentry, "rstentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, myrstlabel, "myrstlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, myrstentry, "myrstentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, qslhbox, "qslhbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, outcheckbutton, "outcheckbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, incheckbutton, "incheckbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, powerhbox, "powerhbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, powerbutton, "powerbutton");
-	GLADE_HOOKUP_OBJECT (mainwindow, powerlabel, "powerlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, powerentry, "powerentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, namehbox, "namehbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, namelabel, "namelabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, nameentry, "nameentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, qthhbox, "qthhbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, qthlabel, "qthlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, qthentry, "qthentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, locatorhbox, "locatorhbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, locatorlabel, "locatorlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, locatorentry, "locatorentry");
-	GLADE_HOOKUP_OBJECT (mainwindow, unknown1hbox, "unknown1hbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, unknownlabel1, "unknownlabel1");
-	GLADE_HOOKUP_OBJECT (mainwindow, unknownentry1, "unknownentry1");
-	GLADE_HOOKUP_OBJECT (mainwindow, unknown2hbox, "unknown2hbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, unknownlabel2, "unknownlabel2");
-	GLADE_HOOKUP_OBJECT (mainwindow, unknownentry2, "unknownentry2");
-	GLADE_HOOKUP_OBJECT (mainwindow, remarksvbox, "remarksvbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, remarkslabel, "remarkslabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, remtv, "remtv");
+	GLADE_HOOKUP_OBJECT (window, handlebox, "handlebox");
+	GLADE_HOOKUP_OBJECT (window, hpaned, "hpaned");
+	GLADE_HOOKUP_OBJECT (window, qsoframe, "qsoframe");
+	GLADE_HOOKUP_OBJECT (window, datebutton, "datebutton");
+	GLADE_HOOKUP_OBJECT (window, dateentry, "dateentry");
+	GLADE_HOOKUP_OBJECT (window, gmtbutton, "gmtbutton");
+	GLADE_HOOKUP_OBJECT (window, gmtentry, "gmtentry");
+	GLADE_HOOKUP_OBJECT (window, endhbox, "endhbox");
+	GLADE_HOOKUP_OBJECT (window, endbutton, "endbutton");
+	GLADE_HOOKUP_OBJECT (window, endentry, "endentry");
+	GLADE_HOOKUP_OBJECT (window, calllabel, "calllabel");
+	GLADE_HOOKUP_OBJECT (window, callentry, "callentry");
+	GLADE_HOOKUP_OBJECT (window, mhzbutton, "mhzbutton");
+	GLADE_HOOKUP_OBJECT (window, mhzlabel, "mhzlabel");
+	GLADE_HOOKUP_OBJECT (window, bandhbox2, "bandhbox2");
+	GLADE_HOOKUP_OBJECT (window, bandentry, "bandentry");
+	GLADE_HOOKUP_OBJECT (window, modebutton, "modebutton");
+	GLADE_HOOKUP_OBJECT (window, modelabel, "modelabel");
+	GLADE_HOOKUP_OBJECT (window, modehbox2, "modehbox2");
+	GLADE_HOOKUP_OBJECT (window, modeentry, "modeentry");
+	GLADE_HOOKUP_OBJECT (window, rstbutton, "rstbutton");
+	GLADE_HOOKUP_OBJECT (window, rstlabel, "rstlabel");
+	GLADE_HOOKUP_OBJECT (window, rstentry, "rstentry");
+	GLADE_HOOKUP_OBJECT (window, myrstlabel, "myrstlabel");
+	GLADE_HOOKUP_OBJECT (window, myrstentry, "myrstentry");
+	GLADE_HOOKUP_OBJECT (window, awardshbox, "awardshbox");
+	GLADE_HOOKUP_OBJECT (window, awardslabel, "awardslabel");
+	GLADE_HOOKUP_OBJECT (window, awardsentry, "awardsentry");
+	GLADE_HOOKUP_OBJECT (window, qslhbox, "qslhbox");
+	GLADE_HOOKUP_OBJECT (window, outcheckbutton, "outcheckbutton");
+	GLADE_HOOKUP_OBJECT (window, incheckbutton, "incheckbutton");
+	GLADE_HOOKUP_OBJECT (window, powerhbox, "powerhbox");
+	GLADE_HOOKUP_OBJECT (window, powerbutton, "powerbutton");
+	GLADE_HOOKUP_OBJECT (window, powerlabel, "powerlabel");
+	GLADE_HOOKUP_OBJECT (window, powerentry, "powerentry");
+	GLADE_HOOKUP_OBJECT (window, namehbox, "namehbox");
+	GLADE_HOOKUP_OBJECT (window, namelabel, "namelabel");
+	GLADE_HOOKUP_OBJECT (window, nameentry, "nameentry");
+	GLADE_HOOKUP_OBJECT (window, qthhbox, "qthhbox");
+	GLADE_HOOKUP_OBJECT (window, qthlabel, "qthlabel");
+	GLADE_HOOKUP_OBJECT (window, qthentry, "qthentry");
+	GLADE_HOOKUP_OBJECT (window, locatorhbox, "locatorhbox");
+	GLADE_HOOKUP_OBJECT (window, locatorlabel, "locatorlabel");
+	GLADE_HOOKUP_OBJECT (window, locatorentry, "locatorentry");
+	GLADE_HOOKUP_OBJECT (window, unknown1hbox, "unknown1hbox");
+	GLADE_HOOKUP_OBJECT (window, unknownlabel1, "unknownlabel1");
+	GLADE_HOOKUP_OBJECT (window, unknownentry1, "unknownentry1");
+	GLADE_HOOKUP_OBJECT (window, unknown2hbox, "unknown2hbox");
+	GLADE_HOOKUP_OBJECT (window, unknownlabel2, "unknownlabel2");
+	GLADE_HOOKUP_OBJECT (window, unknownentry2, "unknownentry2");
+	GLADE_HOOKUP_OBJECT (window, remarksvbox, "remarksvbox");
+	GLADE_HOOKUP_OBJECT (window, remarkslabel, "remarkslabel");
+	GLADE_HOOKUP_OBJECT (window, remtv, "remtv");
 
-	GLADE_HOOKUP_OBJECT (mainwindow, dxccframe, "dxccframe");
-	GLADE_HOOKUP_OBJECT (mainwindow, dxcclabel1, "dxcclabel1");
-	GLADE_HOOKUP_OBJECT (mainwindow, dxcclabel2, "dxcclabel2");
-	GLADE_HOOKUP_OBJECT (mainwindow, dxcclabel3, "dxcclabel3");
-	GLADE_HOOKUP_OBJECT (mainwindow, dxcclabel4, "dxcclabel4");
-	GLADE_HOOKUP_OBJECT (mainwindow, dxcclabel5, "dxcclabel5");
+	GLADE_HOOKUP_OBJECT (window, statusbar, "statusbar");
+	GLADE_HOOKUP_OBJECT (window, frequencyhandlebox, "frequencyhandlebox");
+	GLADE_HOOKUP_OBJECT (window, frequencylabel, "frequencylabel");
+	GLADE_HOOKUP_OBJECT (window, smeterhandlebox, "smeterhandlebox");
+	GLADE_HOOKUP_OBJECT (window, smeterhbox, "smeterhbox");
+	GLADE_HOOKUP_OBJECT (window, smeterpixmap, "smeterpixmap");
+	GLADE_HOOKUP_OBJECT (window, smeterdrawingarea, "smeterdrawingarea");
+	GLADE_HOOKUP_OBJECT (window, clockhandlebox, "clockhandlebox");
+	GLADE_HOOKUP_OBJECT (window, clocklabel, "clocklabel");
 
-	GLADE_HOOKUP_OBJECT (mainwindow, locatorframe, "locatorframe");
-	GLADE_HOOKUP_OBJECT (mainwindow, locatorlabel1, "locatorlabel1");
+	/* prevent F10 from using the menu */
+	gtk_settings_set_string_property (gtk_settings_get_default (),
+			"gtk-menu-bar-accel", "<control>F10", "xlog");
 
-	GLADE_HOOKUP_OBJECT (mainwindow, statusbar, "statusbar");
-	GLADE_HOOKUP_OBJECT (mainwindow, frequencyhandlebox, "frequencyhandlebox");
-	GLADE_HOOKUP_OBJECT (mainwindow, frequencylabel, "frequencylabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, smeterhandlebox, "smeterhandlebox");
-	GLADE_HOOKUP_OBJECT (mainwindow, smeterhbox, "smeterhbox");
-	GLADE_HOOKUP_OBJECT (mainwindow, smeterpixmap, "smeterpixmap");
-	GLADE_HOOKUP_OBJECT (mainwindow, smeterdrawingarea, "smeterdrawingarea");
-	GLADE_HOOKUP_OBJECT (mainwindow, clockhandlebox, "clockhandlebox");
-	GLADE_HOOKUP_OBJECT (mainwindow, clocklabel, "clocklabel");
-
-	return mainwindow;
+	return window;
 }
