@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,17 +26,18 @@
 #include "gui_netkeyer.h"
 #include "gui_utils.h"
 #include "utils.h"
-#include "types.h"
+#include "preferences.h"
+#include "hamlib-utils.h"
+#include "main.h"
 
 GtkWidget *keyerwindow = NULL;
 extern preferencestype preferences;
+extern statetype state;
 extern GtkWidget *mainwindow;
+extern GtkUIManager *ui_manager;
 keyerstatetype keyerstate;
 
-/* delete keyer window and save settings, close connection to cwdaemon */
-static gboolean
-on_keyerwindow_delete_event (GtkWidget * widget, GdkEvent * event,
-	gpointer user_data)
+void savekeyer (void)
 {
 	GtkWidget *f1entry, *f2entry, *f3entry, *f4entry, *f5entry,
 		*f6entry, *f7entry, *f8entry, *f9entry, *f10entry, *f11entry,
@@ -134,10 +135,21 @@ on_keyerwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 	g_free (temp);
 
 	netkeyer_close ();
+}
+
+/* delete keyer window and save settings, close connection to cwdaemon */
+static gboolean
+on_keyerwindow_delete_event (GtkWidget * widget, GdkEvent * event,
+	gpointer user_data)
+{
+	GtkWidget *keyermenu;
+
+	savekeyer ();
 	keyerwindow = NULL;
-	/* restore menu key binding */
-	gtk_settings_set_string_property (gtk_settings_get_default (),
-			"gtk-menu-bar-accel", "F10", "xlog");
+
+	keyermenu = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/Keyer");
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(keyermenu), FALSE);
+
 	return FALSE;
 }
 
@@ -259,6 +271,28 @@ on_keyerwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		stopbutton = lookup_widget (keyerwindow, "stopbutton");
 		g_signal_emit_by_name (G_OBJECT (stopbutton), "activate");
 	break;
+	case GDK_Up:
+		if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
+		{
+			if (preferences.polltime == 0)
+				get_frequency ();
+			set_frequency (state.rigfrequency + 100);
+			return TRUE;
+		}
+		else
+			return FALSE;
+	break;
+	case GDK_Down:
+		if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
+		{
+			if (preferences.polltime == 0)
+				get_frequency ();
+			set_frequency (state.rigfrequency - 100);
+			return TRUE;
+		}
+		else
+			return FALSE;
+	break;
 	default:
 	break;
 	}
@@ -309,7 +343,7 @@ on_shortnr_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 }
 
 /* activate keyer window and initialize UDP socket */
-void on_keyer_activate (GtkMenuItem * menuitem, gpointer user_data)
+void on_keyer_activate (GtkAction *action, gpointer user_data)
 {
 	GtkWidget *keyervbox, *hbox1, *hbox2, *hbox3, *hbox4, *hbox5, *hbox6,
 		*hbox7, *hbox8,	*hbox9, *hsep,
@@ -327,14 +361,11 @@ void on_keyer_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkTooltips *tooltips;
 	gint result = 0;
 	gchar *speed;
+	gboolean status;
 
-	if (keyerwindow)
+	status = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+	if (status)
 	{
-		wpm = lookup_widget (keyerwindow, "wpm");
-		gtk_widget_grab_focus (wpm);
-		gtk_window_present (GTK_WINDOW(keyerwindow));
-		return;
-	}
 	keyerwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (keyerwindow), _("xlog - keyer"));
 	keyer_icon_pixbuf = create_pixbuf ("xlog-keyer.png");
@@ -343,7 +374,6 @@ void on_keyer_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_window_set_icon (GTK_WINDOW (keyerwindow), keyer_icon_pixbuf);
 		g_object_unref (keyer_icon_pixbuf);
 	}
-	gtk_window_set_destroy_with_parent (GTK_WINDOW(keyerwindow), TRUE);
 	tooltips = gtk_tooltips_new ();
 
 	keyervbox = gtk_vbox_new (FALSE, 0);
@@ -622,8 +652,14 @@ void on_keyer_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_signal_connect ((gpointer) shortnr, "toggled", G_CALLBACK (on_shortnr_toggled), NULL);
 
 	gtk_widget_grab_focus (wpm);
-	/* prevent F10 from using the menu */
-	gtk_settings_set_string_property (gtk_settings_get_default (),
-			"gtk-menu-bar-accel", "VoidSymbol", "xlog");
 	gtk_widget_show_all (keyerwindow);
+	}
+	else
+	{
+		if (keyerwindow)
+		{
+			gtk_widget_destroy (keyerwindow);
+			keyerwindow = NULL;
+		}
+	}
 }
