@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,15 +32,17 @@
 
 #include "gui_openlogdialog.h"
 #include "gui_warningdialog.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "support.h"
 #include "utils.h"
 #include "gui_utils.h"
+#include "main.h"
+#include "dxcc.h"
 
 extern statetype state;
 extern preferencestype preferences;
-extern GtkWidget *mainwindow;
+extern GtkWidget *mainwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
 extern GList *logwindowlist;
 
@@ -55,6 +57,7 @@ on_menu_open_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gint i, response;
 	logtype *logwindow;
 	LOGDB *lp;
+	GtkTreePath *path;
 
 	fileselection = gtk_file_chooser_dialog_new (_("xlog - open log"),
     	GTK_WINDOW(mainwindow), GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, 
@@ -135,6 +138,18 @@ on_menu_open_activate (GtkMenuItem * menuitem, gpointer user_data)
 				logwindowlist =	g_list_append (logwindowlist, logwindow);
 				set_qsoframe (logwindow);
 				set_tabs_menu ();
+
+				if (GTK_WIDGET_VISIBLE(scorewindow))
+				{
+					fill_worked_array ();
+					update_dxccscoring ();
+				}
+
+				path = gtk_tree_path_new_from_string ("0");
+					gtk_tree_view_scroll_to_cell
+			(GTK_TREE_VIEW (logwindow->treeview), path, NULL, TRUE, 0.5, 0.0);
+				gtk_tree_path_free (path);
+
 				set_font (preferences.logfont);
 				temp = g_strdup_printf (_("%d QSO's loaded"), state.qsos);
 				update_statusbar (temp);
