@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,41 +30,41 @@
 #include "gui_pathselectiondialog.h"
 #include "support.h"
 
-extern GtkWidget *preferencesdialog;
+extern GtkWidget *preferencesdialog, *mainwindow;
 
+/* fill in entries in the preferences dialog, depending on the directory
+   which is selected here */
 void
 on_pathbutton_clicked (GtkButton * button, gpointer user_data)
 {
-	GtkWidget *pathselection, *pathentry;
-	GdkPixbuf *pathselection_icon_pixbuf;
-	gint response;
+	GtkWidget *pathselection, *pathentry, *backupentry;
+	gint response, which;
 	gchar *selpath;
 
+	which = GPOINTER_TO_INT (user_data);
 	pathselection = gtk_file_chooser_dialog_new (_("xlog - select a directory"),
-    	GTK_WINDOW(preferencesdialog), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, 
+    	GTK_WINDOW(mainwindow), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, 
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, 
 		GTK_RESPONSE_OK, NULL);
-
-	gtk_window_set_position (GTK_WINDOW (pathselection), GTK_WIN_POS_MOUSE);
-	pathselection_icon_pixbuf = create_pixbuf ("xlog.png");
-	if (pathselection_icon_pixbuf)
-	{
-		gtk_window_set_icon (GTK_WINDOW (pathselection), pathselection_icon_pixbuf);
-		g_object_unref (pathselection_icon_pixbuf);
-	}
-
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (pathselection), 
 		g_get_home_dir ());
-	gtk_widget_set_sensitive (preferencesdialog, 0);
+	gtk_widget_show_all (pathselection);
 	response = gtk_dialog_run (GTK_DIALOG(pathselection));
 	if (response == GTK_RESPONSE_OK)
 	{
 		selpath = gtk_file_chooser_get_filename 
 			(GTK_FILE_CHOOSER (pathselection));
-		pathentry = lookup_widget (preferencesdialog, "pathentry");
-		gtk_entry_set_text (GTK_ENTRY (pathentry), selpath);
+		if (which == 1)
+		{
+			pathentry = lookup_widget (preferencesdialog, "pathentry");
+			gtk_entry_set_text (GTK_ENTRY (pathentry), selpath);
+		}
+		else
+		{
+			backupentry = lookup_widget (preferencesdialog, "backupentry");
+			gtk_entry_set_text (GTK_ENTRY (backupentry), selpath);
+		}
 		g_free (selpath);
 	}
-	gtk_widget_set_sensitive (preferencesdialog, 1);
 	gtk_widget_destroy (pathselection);
 }
