@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,10 +35,11 @@
 #include "gui_fontselectiondialog.h"
 #include "gui_pathselectiondialog.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "callbacks_preferencesdialog.h"
 #include "gui_preferencesdialog.h"
 #include "utils.h"
+#include "main.h"
 
 GtkWidget *preferencesdialog;
 extern preferencestype preferences;
@@ -49,16 +50,15 @@ void
 on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *preferencesnotebook, *preferenceslabel1,
-		*preferenceslabel3, *preferenceslabel4,	*preferenceslabel5,
-		*preferenceslabel6;
-	GtkWidget *vboxpage1, *clockframe, *clockcheckbutton,
+		*preferenceslabel3, *preferenceslabel4,	*preferenceslabel5;
+	GtkWidget *vboxpage1, *clockframe, *clockcheckbutton, *clockvbox,
 		*modesloggingframe, *modesframevbox, *modesframe,
 		*modeseditvbox,	*bandsloggingframe, *bandsframevbox, *bandsframe,
 		*bandseditvbox, *modesentry, *bandsentry, *modesradiobutton1,
 		*modesradiobutton2, *bandsradiobutton1,	*bandsradiobutton2,
 		*modeslabel, *bandslabel, *bandoptionmenu, *modeoptionmenu, *bandentry,
-		*modeentry, *fontframe, *fontvbox, *fontseparator, *fonthbox,
-		*fontentry, *fontbutton, *fontlabel;
+		*bandlabel, *modelabel,	*modeentry, *fontframe, *fontvbox, *fontseparator,
+		*fonthbox, *fontentry, *fontbutton, *fontlabel;
 	GtkWidget *vboxpage3, *callsignframe, *callsignhbox, *callsignlabel,
 		*locationframe, *locationvbox, *labelloc, *lathbox, *locatorhbox,
 		*locatorlabel, *unitsframe, *unitshbox, *labeldist, *latentry,
@@ -77,7 +77,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*saveradiobutton, *autosaveradiobutton,	*autosaveframe, *backupframe,
 		*backupvbox, *backupradiobutton1, *backupradiobutton2, *backupbutton,
 		*backuphbox, *backupentry, *autosavecombo;
-	GtkWidget *vboxpage6, *remotedataframe, *remotedatavbox, *remotedatalabel,
+	GtkWidget *remotedataframe, *remotedatavbox, *remotedatalabel,
 		*remotedataseparator, *typeaheadfindcheckbutton, *remoteradiobutton1,
 		*remoteradiobutton2;
 
@@ -117,11 +117,21 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/* page 1, clock, bands and modes */
 	vboxpage1 = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (preferencesnotebook), vboxpage1);
-	clockframe = gtk_frame_new (_("Clock"));
+	clockframe = gtk_frame_new (_("General"));
 	gtk_box_pack_start (GTK_BOX (vboxpage1), clockframe, FALSE, FALSE, 0);
+	clockvbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (clockframe), clockvbox);
 	clockcheckbutton = gtk_check_button_new_with_label
 		(_("Enable clock on statusbar"));
-	gtk_container_add (GTK_CONTAINER (clockframe), clockcheckbutton);
+	gtk_box_pack_start (GTK_BOX (clockvbox), clockcheckbutton, FALSE, FALSE, 0);
+	typeaheadfindcheckbutton = gtk_check_button_new_with_label
+		(_("Enable type and find"));
+	gtk_box_pack_start
+		(GTK_BOX (clockvbox), typeaheadfindcheckbutton, FALSE, FALSE, 0);
+	gtk_tooltips_set_tip (tooltips, typeaheadfindcheckbutton, _(
+		"Search all the logs for a callsign match and when found, fill "
+		"in name, QTH, locator and remarks like in the previous QSO when "
+		"these fields are empty"), NULL);
 
 	preferenceslabel1 = gtk_label_new (_("General"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
@@ -153,6 +163,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	modesentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (modeseditvbox), modesentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (modesentry), 90);
+	gtk_entry_set_activates_default (GTK_ENTRY (modesentry), TRUE);
 
 	bandsloggingframe = gtk_frame_new (_("Bands"));
 	gtk_box_pack_start
@@ -179,24 +190,30 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	bandsentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (bandseditvbox), bandsentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (bandsentry), 90);
+	gtk_entry_set_activates_default (GTK_ENTRY (bandsentry), TRUE);
 
-	fontframe = gtk_frame_new (_("Font"));
-	gtk_box_pack_start (GTK_BOX (vboxpage1), fontframe, FALSE, FALSE, 0); 	 
-	fontvbox = gtk_vbox_new (FALSE, 0); 	 
-	gtk_container_add (GTK_CONTAINER (fontframe), fontvbox);
-	fontlabel = gtk_label_new (_("Font to use for the log")); 	 
-	gtk_box_pack_start (GTK_BOX (fontvbox), fontlabel, FALSE, FALSE, 0);
-	fontseparator = gtk_hseparator_new (); 	 
-	gtk_box_pack_start (GTK_BOX (fontvbox), fontseparator, FALSE, FALSE, 0);
-	fonthbox = gtk_hbox_new (FALSE, 0); 	 
-	gtk_box_pack_start (GTK_BOX (fontvbox), fonthbox, FALSE, FALSE, 0);
-	fontentry = gtk_entry_new (); 	 
-	gtk_box_pack_start (GTK_BOX (fonthbox), fontentry, TRUE, TRUE, 10); 	 
-	gtk_editable_set_editable (GTK_EDITABLE (fontentry), FALSE); 	 
-	GTK_WIDGET_UNSET_FLAGS (fontentry, GTK_CAN_FOCUS); 	 
-	fontbutton = gtk_button_new_from_stock (GTK_STOCK_SELECT_FONT); 	 
-	gtk_widget_set_size_request (fontbutton, 100, -1); 	 
-	gtk_box_pack_start (GTK_BOX (fonthbox), fontbutton, FALSE, FALSE, 0);
+	remotedataframe = gtk_frame_new (_("Remote data"));
+	gtk_box_pack_start (GTK_BOX (vboxpage1), remotedataframe, FALSE, FALSE, 0);
+	remotedatavbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (remotedataframe), remotedatavbox);
+	remotedatalabel = gtk_label_new
+		(_("When receiving data from another application (gmfsk, ktrack):"));
+	gtk_box_pack_start
+		(GTK_BOX (remotedatavbox), remotedatalabel, FALSE, FALSE, 0);
+	gtk_label_set_line_wrap (GTK_LABEL (remotedatalabel), TRUE);
+	remotedataseparator = gtk_hseparator_new ();
+	gtk_box_pack_start
+		(GTK_BOX (remotedatavbox), remotedataseparator, FALSE, FALSE, 10);
+	remoteradiobutton1 = gtk_radio_button_new_with_label
+		(NULL, _("Add data directly to the log"));
+	gtk_box_pack_start
+		(GTK_BOX (remotedatavbox), remoteradiobutton1, FALSE, FALSE, 0);
+	remoteradiobutton_group = gtk_radio_button_get_group 
+		(GTK_RADIO_BUTTON (remoteradiobutton1));
+	remoteradiobutton2 = gtk_radio_button_new_with_label
+		(remoteradiobutton_group, _("Add data to the QSO frame"));
+	gtk_box_pack_start
+		(GTK_BOX (remotedatavbox), remoteradiobutton2, FALSE, FALSE, 0);
 
 	/* page 2, information */
 	vboxpage3 = gtk_vbox_new (FALSE, 0);
@@ -211,6 +228,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	callsignentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (callsignhbox), callsignentry, TRUE, TRUE, 10);
 	gtk_entry_set_max_length (GTK_ENTRY (callsignentry), 15);
+	gtk_entry_set_activates_default (GTK_ENTRY (callsignentry), TRUE);
 
 	locationframe = gtk_frame_new (_("Location"));
 	gtk_box_pack_start (GTK_BOX (vboxpage3), locationframe, FALSE, FALSE, 0);
@@ -223,6 +241,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	latentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (lathbox), latentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (latentry), 8);
+	gtk_entry_set_activates_default (GTK_ENTRY (latentry), TRUE);
 	NScombo = gtk_combo_box_new_text ();
 	gtk_box_pack_start (GTK_BOX (lathbox), NScombo, FALSE, FALSE, 0);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (NScombo), _("N"));
@@ -230,6 +249,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	longentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (lathbox), longentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (longentry), 8);
+	gtk_entry_set_activates_default (GTK_ENTRY (longentry), TRUE);
 	EWcombo = gtk_combo_box_new_text ();
 	gtk_box_pack_start (GTK_BOX (lathbox), EWcombo, FALSE, FALSE, 0);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (EWcombo), _("E"));
@@ -241,7 +261,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	qthlocatorentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (locatorhbox), qthlocatorentry, TRUE, TRUE, 10);
 	gtk_entry_set_max_length (GTK_ENTRY (qthlocatorentry), 8);
-
+	gtk_entry_set_activates_default (GTK_ENTRY (qthlocatorentry), TRUE);
 	unitsframe = gtk_frame_new (_("Units"));
 	gtk_box_pack_start (GTK_BOX (vboxpage3), unitsframe, FALSE, FALSE, 0);
 	unitshbox = gtk_hbox_new (TRUE, 0);
@@ -295,6 +315,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS3");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "localhost");
 	gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN(devicecombo)->child), 30);
+	gtk_entry_set_activates_default
+	  (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (devicecombo))), TRUE);
 
 	hamlibseparator = gtk_hseparator_new ();
 	gtk_box_pack_start
@@ -309,6 +331,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_entry_set_max_length (GTK_ENTRY (rigsetconfentry), 80);
 	gtk_tooltips_set_tip (tooltips, rigsetconfentry, 
 		_("example: rts_state=ON,timeout=600,serial_speed=19200"), NULL);
+	gtk_entry_set_activates_default (GTK_ENTRY (rigsetconfentry), TRUE);
 
 	hamlibseparator = gtk_hseparator_new ();
 	gtk_box_pack_start
@@ -335,6 +358,9 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (pollinghbox), pollinglabel, FALSE, FALSE, 0);
 	pollcombo = gtk_combo_box_entry_new_text ();
 	gtk_box_pack_start (GTK_BOX (pollinghbox), pollcombo, FALSE, FALSE, 0);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "50");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "100");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "200");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "300");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "400");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "500");
@@ -420,6 +446,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	logsentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (logsvbox), logsentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (logsentry), 90);
+	gtk_entry_set_activates_default (GTK_ENTRY (logsentry), TRUE);
 
 	savingframe = gtk_frame_new (_("Saving"));
 	gtk_box_pack_start (GTK_BOX (vboxpage5), savingframe, FALSE, FALSE, 0);
@@ -492,52 +519,29 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_tooltips_set_tip
 		(tooltips, backupbutton, _("Click here to change the path"), NULL);
 
+	fontframe = gtk_frame_new (_("Font"));
+	gtk_box_pack_start (GTK_BOX (vboxpage5), fontframe, FALSE, FALSE, 0); 	 
+	fontvbox = gtk_vbox_new (FALSE, 0); 	 
+	gtk_container_add (GTK_CONTAINER (fontframe), fontvbox);
+	fontlabel = gtk_label_new (_("Font to use for the log")); 	 
+	gtk_box_pack_start (GTK_BOX (fontvbox), fontlabel, FALSE, FALSE, 0);
+	fontseparator = gtk_hseparator_new (); 	 
+	gtk_box_pack_start (GTK_BOX (fontvbox), fontseparator, FALSE, FALSE, 0);
+	fonthbox = gtk_hbox_new (FALSE, 0); 	 
+	gtk_box_pack_start (GTK_BOX (fontvbox), fonthbox, FALSE, FALSE, 0);
+	fontentry = gtk_entry_new (); 	 
+	gtk_box_pack_start (GTK_BOX (fonthbox), fontentry, TRUE, TRUE, 10); 	 
+	gtk_editable_set_editable (GTK_EDITABLE (fontentry), FALSE); 	 
+	GTK_WIDGET_UNSET_FLAGS (fontentry, GTK_CAN_FOCUS); 	 
+	fontbutton = gtk_button_new_from_stock (GTK_STOCK_SELECT_FONT); 	 
+	gtk_widget_set_size_request (fontbutton, 100, -1); 	 
+	gtk_box_pack_start (GTK_BOX (fonthbox), fontbutton, FALSE, FALSE, 0);
+
 	preferenceslabel5 = gtk_label_new (_("Logs"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
 		gtk_notebook_get_nth_page (GTK_NOTEBOOK (preferencesnotebook), 3),
 		preferenceslabel5);
 
-	/* page 5, other */
-	vboxpage6 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (preferencesnotebook), vboxpage6);
-
-	typeaheadfindcheckbutton = gtk_check_button_new_with_label
-		(_("Enable type and find"));
-	gtk_box_pack_start
-		(GTK_BOX (vboxpage6), typeaheadfindcheckbutton, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip (tooltips, typeaheadfindcheckbutton, _(
-		"Search all the logs for a callsign match and when found, fill "
-		"in name, QTH, locator and remarks like in the previous QSO when "
-		"these fields are empty"), NULL);
-
-	remotedataframe = gtk_frame_new (_("Remote data"));
-	gtk_box_pack_start (GTK_BOX (vboxpage6), remotedataframe, FALSE, FALSE, 0);
-	remotedatavbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (remotedataframe), remotedatavbox);
-	remotedatalabel = gtk_label_new
-		(_("When receiving data from another application (gmfsk, ktrack):"));
-	gtk_box_pack_start
-		(GTK_BOX (remotedatavbox), remotedatalabel, FALSE, FALSE, 0);
-	gtk_label_set_line_wrap (GTK_LABEL (remotedatalabel), TRUE);
-	remotedataseparator = gtk_hseparator_new ();
-	gtk_box_pack_start
-		(GTK_BOX (remotedatavbox), remotedataseparator, FALSE, FALSE, 10);
-	remoteradiobutton1 = gtk_radio_button_new_with_label
-		(NULL, _("Add data directly to the log"));
-	gtk_box_pack_start
-		(GTK_BOX (remotedatavbox), remoteradiobutton1, FALSE, FALSE, 0);
-	remoteradiobutton_group = gtk_radio_button_get_group 
-		(GTK_RADIO_BUTTON (remoteradiobutton1));
-	remoteradiobutton2 = gtk_radio_button_new_with_label
-		(remoteradiobutton_group, _("Add data to the QSO frame"));
-	gtk_box_pack_start
-		(GTK_BOX (remotedatavbox), remoteradiobutton2, FALSE, FALSE, 0);
-
-	preferenceslabel6 = gtk_label_new (_("Other"));
-	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
-		gtk_notebook_get_nth_page (GTK_NOTEBOOK (preferencesnotebook), 4),
-		preferenceslabel6);
-
 	/**************************/
 	/* settings of the dialog */
 	/**************************/
@@ -783,6 +787,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		G_CALLBACK (on_pathbutton_clicked), GINT_TO_POINTER(2));
 	g_signal_connect ((gpointer) backupradiobutton2, "toggled",
 		G_CALLBACK (on_backupradiobutton_toggled), NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (preferencesdialog),
+					 GTK_RESPONSE_OK);
 
 	/******************/
 	/* run the dialog */
@@ -890,33 +896,40 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		 * state of toggle buttons */
 		bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 		bandentry = lookup_widget (mainwindow, "bandentry");
+		bandlabel = g_object_get_data (G_OBJECT (mainwindow), "mhzlabel");
 		toggletrue = gtk_toggle_button_get_active
 			(GTK_TOGGLE_BUTTON(bandsradiobutton1));
 		if (toggletrue)
 		{
 			preferences.bandseditbox = 1;
+			gtk_label_set_mnemonic_widget (GTK_LABEL(bandlabel), bandentry);
 			gtk_widget_hide (bandoptionmenu);
 			gtk_widget_show (bandentry);
 		}
 		else
 		{
 			preferences.bandseditbox = 0;
+			gtk_label_set_mnemonic_widget (GTK_LABEL(bandlabel), bandoptionmenu);
 			gtk_widget_hide (bandentry);
 			gtk_widget_show (bandoptionmenu);
 		}
+
 		modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 		modeentry = lookup_widget (mainwindow, "modeentry");
+		modelabel = g_object_get_data (G_OBJECT (mainwindow), "modelabel");
 		toggletrue = gtk_toggle_button_get_active
 			(GTK_TOGGLE_BUTTON(modesradiobutton1));
 		if (toggletrue)
 		{
 			preferences.modeseditbox = 1;
+			gtk_label_set_mnemonic_widget (GTK_LABEL(modelabel), modeentry);
 			gtk_widget_hide (modeoptionmenu);
 			gtk_widget_show (modeentry);
 		}
 		else
 		{
 			preferences.modeseditbox = 0;
+			gtk_label_set_mnemonic_widget (GTK_LABEL(modelabel), modeoptionmenu);
 			gtk_widget_hide (modeentry);
 			gtk_widget_show (modeoptionmenu);
 		}
