@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #include "callbacks_printdialog.h"
 #include "gui_printdialog.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 
 GtkWidget *printdialog;
@@ -91,6 +91,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 			(GTK_BOX (rangehbox), printlowentry, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (printlowentry, 40, -1);
 		gtk_entry_set_max_length (GTK_ENTRY (printlowentry), 8);
+		gtk_entry_set_activates_default (GTK_ENTRY (printlowentry), TRUE);
 		printrangelabel = gtk_label_new (_("To"));
 		gtk_misc_set_padding (GTK_MISC (printrangelabel), 5, 0);
 		gtk_box_pack_start
@@ -100,6 +101,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 			(GTK_BOX (rangehbox), printhighentry, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (printhighentry, 40, -1);
 		gtk_entry_set_max_length (GTK_ENTRY (printhighentry), 8);
+		gtk_entry_set_activates_default (GTK_ENTRY (printhighentry), TRUE);
 
 		destframe = gtk_frame_new (_("Destination"));
 		gtk_box_pack_start (GTK_BOX (lefttopvbox), destframe, FALSE, FALSE, 0);
@@ -134,6 +136,8 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (papersizecombo), "letter");
 		gtk_editable_set_editable
 			(GTK_EDITABLE (GTK_BIN(papersizecombo)->child), FALSE);
+		gtk_entry_set_activates_default
+		        (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (papersizecombo))), TRUE);
 		pointsizehbox = gtk_hbox_new (TRUE, 0);
 		gtk_box_pack_start
 			(GTK_BOX (papervbox), pointsizehbox, FALSE, FALSE, 0);
@@ -155,6 +159,8 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "14");
 		gtk_editable_set_editable
 			(GTK_EDITABLE (GTK_BIN(pointsizecombo)->child),	FALSE);
+		gtk_entry_set_activates_default
+		        (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (pointsizecombo))), TRUE);
 		orientationhbox = gtk_hbox_new (TRUE, 0);
 		gtk_box_pack_start
 			(GTK_BOX (papervbox), orientationhbox, FALSE, FALSE, 0);
@@ -171,7 +177,8 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 			_("landscape"));
 		gtk_editable_set_editable
 			(GTK_EDITABLE (GTK_BIN(orientationcombo)->child), FALSE);
-
+		gtk_entry_set_activates_default
+		        (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (orientationcombo))), TRUE);
 		columnsframe = gtk_frame_new (_("Columns"));
 		gtk_box_pack_start (GTK_BOX (pvbox), columnsframe, FALSE, FALSE, 0);
 		columnshbox = gtk_hbox_new (TRUE, 0);
@@ -472,6 +479,8 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 			G_CALLBACK (on_printradiobutton_toggled), "1");
 		g_signal_connect (G_OBJECT (printrangeradiobutton), "toggled",
 			G_CALLBACK (on_printradiobutton_toggled), "2");
+		gtk_dialog_set_default_response (GTK_DIALOG (printdialog),
+						 GTK_RESPONSE_OK);
 
 		gtk_widget_show_all (printdialog);
 		response = gtk_dialog_run (GTK_DIALOG(printdialog));
