@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,6 +51,8 @@ create_savedialog (void)
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label), 20, 20);
+	gtk_dialog_set_default_response (GTK_DIALOG (savedialog),
+					 GTK_RESPONSE_OK);
 	gtk_widget_show_all (savedialog);
 	response = gtk_dialog_run (GTK_DIALOG(savedialog));
 	if (response == GTK_RESPONSE_OK)
