@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
 #include "gui_tracedialog.h"
 #include "gui_warningdialog.h"
 #include "support.h"
-#include "types.h"
+#include "preferences.h"
 
 #include <hamlib/rig.h>
 #include "hamlib-utils.h"
