@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#if WANT_HAMLIB
 void stop_hamlib (void);
 gboolean start_hamlib (gint rigid, gchar *device, gint debugmode, gint timervalue);
 GList *riglist_get_list (void);
@@ -27,6 +26,7 @@ gchar *rigmode (gint mode);
 void get_powerlevel(void);
 void get_mode(void);
 void get_frequency(void);
+void set_frequency (long long freq);
 void get_ptt(void);
 void get_smeter(void);
 void get_riginfo (void);
@@ -36,4 +36,3 @@ GString *convert_frequency (void);
 gboolean on_smeterdrawingarea_configure_event (GtkWidget * widget, GdkEventConfigure * event, gpointer user_data);
 gboolean on_smeterdrawingarea_expose_event (GtkWidget * widget, GdkEventExpose * event, gpointer user_data);
 void on_mainwindow_show (GtkWidget * widget, gpointer user_data);
-#endif
