@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,9 +33,10 @@
 #include "callbacks_mainwindow_list.h"
 #include "gui_utils.h"
 #include "utils.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "support.h"
+#include "main.h"
 
 extern GtkWidget *mainnotebook;
 extern statetype state;
@@ -96,19 +97,21 @@ gint
 fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 {
 	GtkTreeIter iter;
-	GtkTreeModel *model;
+	GtkListStore *model;
 	logtype *logw = (logtype *) arg;
 	gchar *date = NULL, *name = NULL, *qth = NULL, *u1 = NULL,
 		*u2 = NULL, *remarks = NULL;
 	GError *error;
 	gint i;
+	GtkTreePath *path;
 
 	state.qsos++;
 	logw->qsos++;
 	q[NR] = g_strdup_printf ("%d", logw->qsos);
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (logw->treeview));
-	gtk_tree_store_prepend (GTK_TREE_STORE (model), &iter, NULL);
+	model = GTK_LIST_STORE
+		(gtk_tree_view_get_model (GTK_TREE_VIEW (logw->treeview)));
+	gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
 
 	if (!q[DATE]) 
 		date = g_strdup ("");
@@ -141,6 +144,8 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		q[RST] = g_strdup ("");
 	if (!q[MYRST]) 
 		q[MYRST] = g_strdup ("");
+	if (!q[AWARDS]) 
+		q[AWARDS] = g_strdup ("");
 	if (!q[QSLOUT]) 
 		q[QSLOUT] = g_strdup ("");
 	if (!q[QSLIN]) 
@@ -236,16 +241,21 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else remarks = g_strdup (q[REMARKS]);
 
-	gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
 		NR, q[NR], DATE, date, GMT, q[GMT], GMTEND, q[GMTEND], CALL, q[CALL], 
-		BAND, q[BAND], MODE, q[MODE], RST, q[RST], MYRST, q[MYRST], QSLOUT, q[QSLOUT], 
-		QSLIN, q[QSLIN], POWER, q[POWER], NAME, name, QTH, qth, LOCATOR, q[LOCATOR], 
-		U1, u1, U2, u2,	REMARKS, remarks, -1);
-
+		BAND, q[BAND], MODE, q[MODE], RST, q[RST], MYRST, q[MYRST], AWARDS, q[AWARDS],
+		QSLOUT, q[QSLOUT], QSLIN, q[QSLIN], POWER, q[POWER], NAME, name, QTH, qth,
+		LOCATOR, q[LOCATOR], U1, u1, U2, u2, REMARKS, remarks, -1);
 	if (!(logw->qsos % 1000))
 	{
 		while (gtk_events_pending ())
 			gtk_main_iteration ();
+
+		path = gtk_tree_path_new_from_string ("0");
+		gtk_tree_view_scroll_to_cell
+			(GTK_TREE_VIEW (logw->treeview), path, NULL, TRUE, 0.5, 0.0);
+		gtk_tree_path_free (path);
+
 		update_statusbar (_("Reading..."));
 	}
 
@@ -293,19 +303,21 @@ openlog (LOGDB * lp, gchar * name, gint page)
 	GtkCellRenderer *renderer, *brenderer;
 	GtkTreeViewColumn *column;
 	GObject *selection;
-	GtkTreeStore *model;
+	GtkListStore *model;
 
 	logwindow = new_logwindow ();
 	logwindow->scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (logwindow->scrolledwindow);
 	gtk_container_add (GTK_CONTAINER (mainnotebook), logwindow->scrolledwindow);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(logwindow->scrolledwindow), GTK_POLICY_AUTOMATIC,	GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(logwindow->scrolledwindow),
+		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	model = gtk_tree_store_new (QSO_FIELDS,
+	model = gtk_list_store_new (QSO_FIELDS,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING,	G_TYPE_STRING, G_TYPE_STRING,	G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING,	G_TYPE_STRING, G_TYPE_STRING,	G_TYPE_STRING, G_TYPE_STRING);
-	logwindow->treeview =	gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING);
+	logwindow->treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 	g_object_unref (G_OBJECT (model));
 
 	/* add callback for selecting a row */
@@ -319,7 +331,7 @@ openlog (LOGDB * lp, gchar * name, gint page)
 		logwindow->logfields[j] = lp->column_fields[j];
 
 	/* column widths */
-	w = g_strsplit(preferences.logcwidths, ",", 0);
+	w = g_strsplit(preferences.logcwidths2, ",", 0);
 
 	/* NR column is the first one */
 	renderer = gtk_cell_renderer_text_new ();
