@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,17 +21,29 @@
  *			Specifications from http://www.hosenose.com/adif/adif.html
  */
 
+#define _XOPEN_SOURCE
+#include <time.h>
+
 #include <stdlib.h>
+#include <strings.h>
 #include <string.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <time.h>
 #include <glib.h>
+#include <locale.h>
 
 #include "logfile.h"
-#include "types.h"
+#include "preferences.h"
+#include "utils.h"
+
+#ifndef HAVE_STRPTIME
+#include "strptime.h"
+#define strptime(s,f,t) mystrptime(s,f,t)
+#endif
+
+extern preferencestype preferences;
 
 /*
  * fields to be stored in the adif file
@@ -42,8 +54,6 @@ static const gint adif_widths[] = { 15, 8, 15, 15, 8, 8, 8, 8, 8, 80, 8, 8, 8,
 	8, 6, 8, 8 };
 static const gint adif_field_nr = 17;
 
-extern preferencestype preferences;
-
 static LOGDB *adif_handle;
 static gint (*adif_fn)(LOGDB*, qso_t*, gpointer);
 static gpointer adif_arg;
@@ -88,6 +98,7 @@ static gint adif_qso_foreach
 
 		if (line[0] != '\n') /* ignore empty lines */
 			buffer = g_strconcat (buffer, line, NULL);
+		else continue;
 
 		if (g_strrstr (line, "<EOH>") || g_strrstr (line, "<eoh>")) /* read past header */
 			buffer = g_strdup ("");
@@ -95,6 +106,7 @@ static gint adif_qso_foreach
 		if (g_strrstr (line, "<EOR>") || g_strrstr (line, "<eor>")) /* read past one record */
 		{
 			/* let's do this simple, check if we have multiple '<' */
+			buffer = my_strreplace (buffer, "\n", "");
 			adifline = g_strsplit (buffer, "<", 0);
 			for (items = 0;; items++)
 				if (!adifline || adifline[items] == NULL) break;
@@ -225,6 +237,21 @@ static gint adif_qso_foreach
 						q[adif_field] =
 							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
+					else if (!strcasecmp (adifid[0], "QSL_VIA"))
+					{
+						if (!strcasecmp (preferences.freefield1, "QSL_VIA"))
+						{
+							adif_field = U1;
+							q[adif_field] =
+								g_strndup (adifitem[1], atoi(adifid[1]));
+						}
+						else if (!strcasecmp (preferences.freefield2, "QSL_VIA"))
+						{
+							adif_field = U2;
+							q[adif_field] =
+								g_strndup (adifitem[1], atoi(adifid[1]));
+						}
+					}
 					else if (!strcasecmp (adifid[0], "NAME"))
 					{
 						adif_field = NAME;
@@ -329,9 +356,11 @@ gint adif_create(LOGDB *handle)
 	if (!fp) return -1;
 	handle->priv = (gpointer)fp;
 
-
+	/* use C locale for date */
+	setlocale (LC_TIME, "C");
 	time(&timet);
 	strftime (sdate, 32, "%d %b %Y %T", localtime(&timet));
+	setlocale (LC_TIME, "");
 
 	/* write header */
 	fprintf(fp, "ADIF Export from " PACKAGE " Version " VERSION "\n"
@@ -418,6 +447,17 @@ static gchar *freq2band (gchar *freq)
 			case 24: return "12M";
 			case 28 ... 29: return "10M";
 			case 50 ... 54: return "6M";
+			case 70: return "4M";
+
+		}
+	}
+	else if ((strlen(freq) == 3) || (freq[3] == '.'))
+	{
+		if (strlen(freq) > 3) freq[3] = '\0';
+		switch (atoi(freq))
+		{
+			case 144 ... 148: return "2M";
+			case 222 ... 225: return "1.25M";
 		}
 	}
 	return "?";
@@ -429,6 +469,8 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 {
 	FILE *fp = (FILE *)handle->priv;
 	int i;
+	struct tm tm_a;
+	gchar *result;
 
 	for (i = 0; i < handle->column_nr; i++)
 	{
@@ -442,13 +484,23 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 		if (qfield_len == 0)
 			continue;
 
-		/* reshape date */
-		if (fld == DATE && strlen(q[DATE]) == 11 && q[DATE][2]==' ' && q[DATE][6]==' ')
+		/* reshape date, convert from locale notation to yyyymmdd */
+		if (fld == DATE)
 		{
-			gchar date[16];
-			sprintf(date, "%s%02d%c%c", q[DATE]+7, scan_month(q[DATE]+3), q[DATE][0], q[DATE][1]);
-			qfield = date;
-			qfield_len = 8;
+			gchar date[32];
+
+			result = strptime (q[DATE], "%d %b %Y", &tm_a);
+			if (result)
+			{
+				strftime (date, sizeof(date), "%Y%m%d", &tm_a);
+				qfield = date;
+				qfield_len = 8;
+			}
+			else
+			{
+				qfield = q[fld];
+				qfield_len = strlen(qfield);
+			}
 		}
 		else if (fld == BAND)
 		{
