@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include <ctype.h>
 
 #include "logfile.h"
-#include "types.h"
+#include "preferences.h"
 
 extern preferencestype preferences;
 
@@ -180,7 +180,7 @@ cabrillo_qso_append (LOGDB * handle, const qso_t * q)
 	if (strlen (freq) < 3)
 	{
 		if (!strcmp (freq, "35")) strcpy (freq, "3500");
-		else if (!strcmp (freq, "5")) strcpy (freq, "5000");
+		else if (!strcmp (freq, "5")) strcpy (freq, "5300");
 		else if (!strcmp (freq, "7")) strcpy (freq, "7000");
 		else if (!strcmp (freq, "10")) strcpy (freq, "10100");
 		else if (!strcmp (freq, "14")) strcpy (freq, "14000");
