@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,13 +22,32 @@
 #include <glib.h>
 
 #include "logfile.h"
-#include "types.h"
+
+#ifdef ENABLE_NLS
+#       include <libintl.h>
+#       undef _
+#       define _(String) dgettext (PACKAGE, String)
+#       ifdef gettext_noop
+#               define N_(String) gettext_noop (String)
+#       else
+#               define N_(String) (String)
+#       endif
+#else
+#       define textdomain(String) (String)
+#       define gettext(String) (String)
+#       define dgettext(Domain,Message) (Message)
+#       define dcgettext(Domain,Message,Type) (Message)
+#       define bindtextdomain(Domain,Directory) (Domain)
+#       define _(String) (String)
+#       define N_(String) (String)
+#endif
 
 static gint flog_open (LOGDB *);
 static void flog_close (LOGDB *);
 static gint flog_create (LOGDB *);
 static gint flog_qso_append (LOGDB *, const qso_t *);
-static gint flog_qso_foreach (LOGDB *, gint (*fn) (LOGDB *, qso_t *, gpointer arg), gpointer arg);
+static gint flog_qso_foreach
+	(LOGDB *, gint (*fn) (LOGDB *, qso_t *, gpointer arg), gpointer arg);
 
 const struct log_ops flog_ops = {
 	.open = flog_open,
@@ -57,19 +76,31 @@ flog_open (LOGDB * handle)
 		return -1;
 	handle->priv = (gpointer) fp;
 
-
-	/* read header line
-	 * TODO: handle error cases
-	 */
 	fgets (header_line, FLOG_MAX_LINE_SIZE, fp);
-	field_name = header_line;
 
+	/* error handling */
+	if (strlen (header_line) < 82)
+	{
+		g_warning (_("The header of log %s is corrupted."), handle->path);
+		g_warning (_("It's length is smaller than 82."));
+		g_warning (_("This does not look like an xlog file."));
+		return 1;
+	}
+	if (strncmp (header_line, "DATE ", 5))
+	{
+		g_warning (_("The header of log %s is corrupted."), handle->path);
+		g_warning (_("It does not start with DATE."));
+		g_warning (_("This does not look like an xlog file."));
+		return 1;
+	}
+
+	field_name = header_line;
 	for (p = header_line; *p; p++)
 	{
 		field_width++;
 		if (in_space_state)
 		{
-		if (*p != ' ')
+			if (*p != ' ')
 			{
 				/* start of a new column */
 				in_space_state = 0;
@@ -78,7 +109,8 @@ flog_open (LOGDB * handle)
 				 * add previous column, 
 				 * now we know the column width
 				 */
-				handle->column_fields[column_nr] = parse_field_name (field_name);
+				handle->column_fields[column_nr] =
+					parse_field_name (field_name);
 				handle->column_widths[column_nr] = field_width;
 				column_nr++;
 
@@ -183,7 +215,8 @@ flog_qso_foreach (LOGDB * handle, gint (*fn) (LOGDB *, qso_t *, gpointer arg),
 		/* chop off EOL */
 		if (width > 0 && buffer[width - 1] == '\n')
 			buffer[width - 1] = '\0';
-		q[handle->column_fields[handle->column_nr - 1]] = g_strdup (g_strstrip (buffer));
+		q[handle->column_fields[handle->column_nr - 1]] =
+			g_strdup (g_strstrip (buffer));
 
 		/*
 		 * populate fields not present in log file
