@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include <glib.h>
 
 #include "logfile.h"
-#include "types.h"
+#include "preferences.h"
 #include "wwl.h"
 
 /*
@@ -97,59 +97,59 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 	FILE *fp = (FILE *) handle->priv;
 	gint kms, miles, l, result;
 
-	if (preferences.saveastsv[0] == '1')
+	if (preferences.saveastsv2[0] == '1')
 	{
 		if (q[DATE]) fprintf (fp, "%s\t", q[DATE]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[2] == '1')
+	if (preferences.saveastsv2[2] == '1')
 	{
 		if (q[GMT]) fprintf (fp, "%s\t", q[GMT]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[4] == '1')
+	if (preferences.saveastsv2[4] == '1')
 	{
 		if (q[GMTEND]) fprintf (fp, "%s\t", q[GMTEND]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[6] == '1')
+	if (preferences.saveastsv2[6] == '1')
 	{
 		if (q[CALL]) fprintf (fp, "%s\t", q[CALL]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[8] == '1')
+	if (preferences.saveastsv2[8] == '1')
 	{
 		if (q[BAND]) fprintf (fp, "%s\t", q[BAND]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[10] == '1')
+	if (preferences.saveastsv2[10] == '1')
 	{
 		if (q[MODE]) fprintf (fp, "%s\t", q[MODE]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[12] == '1')
+	if (preferences.saveastsv2[12] == '1')
 	{
 		if (q[RST]) fprintf (fp, "%s\t", q[RST]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[14] == '1')
+	if (preferences.saveastsv2[14] == '1')
 	{
 		if (q[MYRST]) fprintf (fp, "%s\t", q[MYRST]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[16] == '1')
+	if (preferences.saveastsv2[16] == '1')
 	{
 		if (q[QSLOUT]) fprintf (fp, "%s\t", q[QSLOUT]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[18] == '1')
+	if (preferences.saveastsv2[18] == '1')
 	{
 		if (q[QSLIN]) fprintf (fp, "%s\t", q[QSLIN]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[20] == '1')
+	if (preferences.saveastsv2[20] == '1')
 	{
 		if (q[POWER]) fprintf (fp, "%s\t", q[POWER]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[22] == '1')
+	if (preferences.saveastsv2[22] == '1')
 	{
 		if (q[NAME]) fprintf (fp, "%s\t", q[NAME]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[24] == '1')
+	if (preferences.saveastsv2[24] == '1')
 	{
 		if (q[QTH]) fprintf (fp, "%s\t", q[QTH]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[26] == '1')
+	if (preferences.saveastsv2[26] == '1')
 	{
 		if (q[LOCATOR])
 		{
@@ -180,15 +180,15 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 				fprintf (fp, "\t\t\t");
 		}
 	}
-	if (preferences.saveastsv[28] == '1')
+	if (preferences.saveastsv2[28] == '1')
 	{
 		if (q[U1]) fprintf (fp, "%s\t", q[U1]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[30] == '1')
+	if (preferences.saveastsv2[30] == '1')
 	{
 		if (q[U2]) fprintf (fp, "%s\t", q[U2]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv[32] == '1')
+	if (preferences.saveastsv2[32] == '1')
 	{
 		if (q[REMARKS]) fprintf (fp, "%s\t", q[REMARKS]); else fprintf (fp, "\t");
 	}
