@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,16 +24,14 @@
 #include <time.h>
 
 #include "logfile.h"
-#include "types.h"
-
 
 /*
  * fields to be stored in the flog file
  */
 const gint qso_fields[] =
-  { DATE, GMT, CALL, BAND, MODE, RST, MYRST, QSLOUT, QSLIN, REMARKS };
-const gint qso_widths[] = { 15, 8, 15, 15, 8, 15, 15, 8, 8, 80 };
-const gint qso_field_nr = 10;
+  { DATE, GMT, CALL, BAND, MODE, RST, MYRST, AWARDS, QSLOUT, QSLIN, REMARKS };
+const gint qso_widths[] = { 15, 8, 15, 15, 8, 15, 15, 15, 8, 8, 80 };
+const gint qso_field_nr = 11;
 
 extern const struct log_ops flog_ops;
 extern const struct log_ops twlog_ops;
@@ -42,6 +40,7 @@ extern const struct log_ops cabrillo_ops;
 extern const struct log_ops editest_ops;
 extern const struct log_ops trlog_ops;
 extern const struct log_ops edi_ops;
+extern const struct log_ops oh1aa_ops;
 extern const struct log_ops labels_ops;
 
 LOGDB *
@@ -76,6 +75,9 @@ log_file_open (const gchar * path, enum log_file_type type)
     case TYPE_TRLOG:
       handle->ops = &trlog_ops;
       break;
+    case TYPE_OH1AA:
+      handle->ops = &oh1aa_ops;
+      break;
     case TYPE_LABELS:
       handle->ops = &labels_ops;
       break;
@@ -129,6 +131,9 @@ log_file_create (const gchar * path, enum log_file_type type,
     case TYPE_TRLOG:
       handle->ops = &trlog_ops;
       break;
+    case TYPE_OH1AA:
+      handle->ops = &oh1aa_ops;
+      break;
     case TYPE_LABELS:
       handle->ops = &labels_ops;
       break;
@@ -197,13 +202,13 @@ log_file_delete_column (LOGDB * handle, gint pos)
  * flog fields names
  */
 static const gchar *field_strings[] = {
-  "NR", "DATE", "GMT", "GMTEND", "CALL", "BAND", "MODE", "RST", "MYRST",
+  "NR", "DATE", "GMT", "GMTEND", "CALL", "BAND", "MODE", "RST", "MYRST", "AWARDS",
   "QSLOUT", "QSLIN", "POWER", "NAME", "QTH", "LOCATOR", "U1", "U2", "REMARKS"
 };
 
 
 static const gint field_widths[] = {
-  8, 15, 8, 8, 15, 15, 8, 15, 15, 8, 8, 8, 30, 30, 8, 30, 30, 80
+  8, 15, 8, 8, 15, 15, 8, 15, 15, 30, 8, 8, 8, 30, 30, 8, 30, 30, 80
 };
 
 gint
@@ -246,26 +251,27 @@ gint
 scan_month (const gchar * s)
 {
   int i;
-  static gchar month_abv[12][4] =
+  static gchar month_abv[12][6] =
     { "", "", "", "", "", "", "", "", "", "", "", "" };
-  static struct tm timestruct = { 0, 0, 0, 1, 0, 0, 0, 0, 0 };
+  static struct tm timestruct =
+    { 0, 0, 0, 1, 0, 0, 0, 0, 0 };
 
   /* 
    * get locale month abreviations
    */
-  if (!month_abv[0])
-    {
-      for (i = 0; i < 12; i++)
-	{
-	  timestruct.tm_mon = i;
-	  strftime (month_abv[i], 3, "%b", &timestruct);
-	}
-    }
+  if (strlen(month_abv[0]) == 0)
+  {
+    for (i = 0; i < 12; i++)
+	  {
+	    timestruct.tm_mon = i;
+	    strftime (month_abv[i], sizeof(month_abv[i]), "%b", &timestruct);
+	  }
+  }
   for (i = 0; i < 12; i++)
-    {
-      if (!strncasecmp (s, month_abv[i], 3))
-	return i + 1;
-    }
+  {
+    if (!strncasecmp (s, month_abv[i], 3))
+	  return i + 1;
+  }
 
   /* fall back to english abreviations */
   switch (tolower (s[0]))
