@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,28 @@
 #define FLOG_MAX_LINE_SIZE 300
 #define MAX_VARIABLE_LEN 512
 #define MAX_COLUMN 32
+#define QSO_FIELDS 19
+
+/* fields for the qso array */
+#define NR 0
+#define DATE 1
+#define GMT 2
+#define GMTEND 3
+#define CALL 4
+#define BAND 5
+#define MODE 6
+#define RST 7
+#define MYRST 8
+#define AWARDS 9
+#define QSLOUT 10
+#define QSLIN 11
+#define POWER 12
+#define NAME 13
+#define QTH 14
+#define LOCATOR 15
+#define U1 16
+#define U2 17
+#define REMARKS 18
 
 extern const gint qso_fields[];
 extern const gint qso_widths[];
