@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@
 #endif
 
 #include "logfile.h"
-#include "types.h"
 
 /*
  * file fields
@@ -221,6 +220,8 @@ gint trlog_qso_foreach
 					q[trlog_fields[i]] = g_strdup ("1.8");
 				else if (!strcmp(field, " 80"))
 					q[trlog_fields[i]] = g_strdup ("3.5");
+				else if (!strcmp(field, " 60"))
+					q[trlog_fields[i]] = g_strdup ("5.3");
 				else if (!strcmp(field, " 40"))
 					q[trlog_fields[i]] = g_strdup ("7");
 				else if (!strcmp(field, " 20"))
@@ -235,6 +236,8 @@ gint trlog_qso_foreach
 					q[trlog_fields[i]] = g_strdup ("18");
 				else if (!strcmp(field, " 12"))
 					q[trlog_fields[i]] = g_strdup ("24");
+				else if (!strcmp(field, " 6"))
+					q[trlog_fields[i]] = g_strdup ("50");
 				else
 					q[trlog_fields[i]] = g_strdup (field);
 			}
