@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #endif
 
 #include "gui_b4dialog.h"
+#include "gui_scorewindow.h"
 #include "gui_mainwindow.h"
 #include "gui_setupdialog.h"
 #include "gui_warningdialog.h"
@@ -51,30 +52,32 @@
 #include "callbacks_mainwindow_menu.h"
 #include "callbacks_mainwindow_qsoframe.h"
 #include "callbacks_mainwindow.h"
-#include "types.h"
 #include "preferences.h"
 #include "log.h"
 #include "utils.h"
 #include "dxcc.h"
 #include "remote.h"
 #include "history.h"
+#include "main.h"
 
+GtkWidget *mainwindow, *mainnotebook;
 gchar *xlogdir;
-gint remotetimer = -1, clocktimer = -1, savetimer = -1;
+gint remotetimer = -1, clocktimer = -1, savetimer = -1, sockettimer = -1;
 gchar **qso = NULL;
 statetype state;
 glong msgid;
 GList *logwindowlist = NULL;
 GdkColormap *colormap;
+GIOChannel *channel;
 
 static gboolean openhere = FALSE;
 static GString *logs;
 
-extern GtkWidget *mainwindow;
-extern GtkWidget *mainnotebook;
+extern GtkWidget *b4window, *scorewindow;
 extern preferencestype preferences;
 extern remotetype remote;
-extern GtkWidget *b4dialog;
+extern gint server_sockfd;
+extern GtkUIManager *ui_manager;
 
 /* command line options */
 static void
@@ -171,7 +174,7 @@ setdefaultstate (void)
 static gboolean 
 check_gtk_version (void)
 {
-	if ((gtk_major_version >= 2) && (gtk_minor_version >= 4))
+	if ((gtk_major_version >= 2) && (gtk_minor_version >= 6))
 		return FALSE;
 	return TRUE;
 }
@@ -184,7 +187,8 @@ main (int argc, char *argv[])
 		*bandentry, *modeentry,	*clockhandlebox, *mhzlabel, *mhzbutton,
 		*frequencylabel, *frequencyhandlebox, *modelabel, *modebutton,
 		*rstlabel, *rstbutton, *smeterhandlebox, *smeterdrawingarea,
-		*hpaned, *powerlabel, *powerbutton, *unknownlabel1,	*unknownlabel2, *handlebox;
+		*hpaned, *powerlabel, *powerbutton, *unknownlabel1,
+		*unknownlabel2, *handlebox, *menuitem;
 	gchar *xlogfile, *xlogbackupfile, *temp, *logstoload, **loglist = NULL;
 	gint i, j, result;
 	gboolean showmainwindow = TRUE, logsfromprefs = FALSE, gtk_mismatch = FALSE;
@@ -209,7 +213,7 @@ main (int argc, char *argv[])
 	if (gtk_mismatch)
 	{
 		warningdialog (_("xlog - startup"),
-			_("xlog needs at least version 2.4 of the GTK+ libraries"), "gtk-dialog-error");
+			_("xlog needs at least version 2.6 of the GTK+ libraries"), "gtk-dialog-error");
 		exit (1);
 	}
 	setlocale(LC_NUMERIC, "C");
@@ -250,6 +254,7 @@ main (int argc, char *argv[])
 
 	/* read the logs */
 	mainnotebook = gtk_notebook_new ();
+	gtk_notebook_set_scrollable (GTK_NOTEBOOK(mainnotebook), TRUE);
 	gtk_widget_show (mainnotebook);
 	hpaned = lookup_widget (mainwindow, "hpaned");
 	gtk_paned_pack2 (GTK_PANED (hpaned), mainnotebook, TRUE, TRUE);
@@ -261,17 +266,17 @@ main (int argc, char *argv[])
 	/* check for multiple *.xlog */
 	if (!openhere)
 	{
-	if (g_strrstr (preferences.logstoload, "*"))
+		if (g_strrstr (preferences.logstoload, "*"))
 		/* read all logs of type xlog with a wildcard used */
 		logs = getlogs (preferences.savedir, preferences.logstoload);
-	else
-	{ /* read logs from preferences.logstoload */
-		logstoload = g_strdup (preferences.logstoload);
-		g_strdelimit (logstoload, ",", '\n');
-		logs = g_string_new (logstoload);
-		g_free (logstoload);
-		logsfromprefs = TRUE;
-	}
+		else
+		{ /* read logs from preferences.logstoload */
+			logstoload = g_strdup (preferences.logstoload);
+			g_strdelimit (logstoload, ",", '\n');
+			logs = g_string_new (logstoload);
+			g_free (logstoload);
+			logsfromprefs = TRUE;
+		}
 	}
 
 	if ((logs->len) > 0)		/* flexible logs */
@@ -314,6 +319,7 @@ main (int argc, char *argv[])
 			g_free (xlogbackupfile);
 			j++;
 		}
+		else g_warning (_("Can not open log %s"), xlogfile);
 		g_free (xlogfile);
 	}
 	state.logwindows = j;
@@ -329,18 +335,17 @@ main (int argc, char *argv[])
 	/* set the menu strings for the modeoption menu */
 	makemodeoptionmenu (preferences.modes);
 
-	/* first page has focus */
-	if (lp && i > 0)
-		logwindow = g_list_nth_data (logwindowlist, 0);
-	set_qsoframe (logwindow);
-	set_font (preferences.logfont);
+	/* create wkd B4 dialog in case we need it */
+	b4window = create_b4window ();
 
 	/* we have to set the labels of the unknown fields, 
 		wether they are visible or not */
 	unknownlabel1 = lookup_widget (mainwindow, "unknownlabel1");
-	gtk_label_set_text (GTK_LABEL (unknownlabel1), preferences.freefield1);
+	gtk_label_set_text
+		(GTK_LABEL (unknownlabel1), preferences.freefield1);
 	unknownlabel2 = lookup_widget (mainwindow, "unknownlabel2");
-	gtk_label_set_text (GTK_LABEL (unknownlabel2), preferences.freefield2);
+	gtk_label_set_text
+		(GTK_LABEL (unknownlabel2), preferences.freefield2);
 
 	/* update the statusbar with some information */
 	temp = g_strdup_printf (_("%d QSO's loaded"), state.qsos);
@@ -380,13 +385,26 @@ main (int argc, char *argv[])
 #if HAVE_SYS_IPC_H
 	msgid = msgget ((key_t) 1238, 0666 | IPC_CREAT);
 	if (msgid == -1)
-		{
-			temp = g_strdup_printf (_("Msgget failed: %s"), g_strerror (errno));
-			update_statusbar (temp);
-		}
-	else				/* check for a message twice a second */
+	{
+		temp = g_strdup_printf (_("Msgget failed: %s"), g_strerror (errno));
+		update_statusbar (temp);
+	}
+	else /* check for a message twice a second */
 		remotetimer = g_timeout_add (500, (GSourceFunc) remote_entry, NULL);
 #endif
+	/* Socket Server AF_INET Setup */
+	result = remote_socket_setup();
+	if (result == -1)
+	{
+		temp = g_strdup_printf (_("Socket setup failed: %s"), g_strerror (errno));
+		update_statusbar (temp);
+		close (server_sockfd);
+	}
+	else /* check for a message on the socket */
+	{
+		channel = g_io_channel_unix_new (server_sockfd);
+		sockettimer = g_io_add_watch (channel, G_IO_IN, socket_entry, NULL);
+	}
 
 	/* hamlib stuff */
 	mhzlabel = lookup_widget (mainwindow, "mhzlabel");
@@ -443,30 +461,63 @@ trace hamlib menu is disabled in gui_mainwindow.c */
 	
 	g_free (temp);
 
-	/* create wkd B4 dialog in case we need it */
-	b4dialog = create_b4dialog ();
-
 	gtk_widget_show (mainwindow);
 	/* position the main window */
 	gdk_window_move_resize (mainwindow->window, preferences.x,
 		preferences.y, preferences.width, preferences.height);
 
 	handlebox = lookup_widget (mainwindow, "handlebox");
+	menuitem = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/ShowToolbar");
 	if (preferences.viewtoolbar == 1)
+	{
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), TRUE);
 		gtk_widget_show (handlebox);
+	}
 	else
+	{
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), FALSE);
 		gtk_widget_hide (handlebox);
+	}
 
+	menuitem = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/WorkedBefore");
 	if (preferences.viewb4 == 1)
 	{
-		gtk_widget_show (b4dialog);
-		gdk_window_move_resize (b4dialog->window, preferences.b4x,
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), TRUE);
+		gtk_widget_show (b4window);
+		gdk_window_move_resize (b4window->window, preferences.b4x,
 			preferences.b4y, preferences.b4width, preferences.b4height);
 	}
 	else
-		gtk_widget_hide (b4dialog);
+	{
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), FALSE);
+		gtk_widget_hide (b4window);
+	}
 
-	gtk_window_present (GTK_WINDOW(mainwindow));
+	scorewindow = create_scorewindow ();
+	menuitem = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/Scoring");
+	if (preferences.viewscoring == 1)
+	{
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), TRUE);
+		gtk_widget_show (scorewindow);
+		gdk_window_move_resize (scorewindow->window, preferences.scorex,
+			preferences.scorey, preferences.scorewidth, preferences.scoreheight);
+		fill_worked_array ();
+		update_dxccscoring ();
+	}
+	else
+	{
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), FALSE);
+	}
+
+	/* last page gets focus */
+	if (lp && i > 0)
+	{ 	 
+		logwindow = g_list_nth_data (logwindowlist, state.logwindows - 1);
+		gtk_notebook_set_current_page
+			(GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
+		set_qsoframe (logwindow);
+	}
+	set_font (preferences.logfont);
 
 	if (state.utf8error) 
 	{
