@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,14 @@
 #define K_SPEED 2
 #define K_ABORT 4
 
+/* structure used for keyer state */
+typedef struct
+{
+	gboolean cqmode;
+	gboolean shortnr;
+}
+keyerstatetype;
+
 gint tonetkeyer (gint cw_op, gchar *cwmessage);
 void netkeyer_close (void);
 gint netkeyer_init (void);
