@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,18 +27,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include "preferences.h"
-#include "types.h"
 #include "utils.h"
 #include "support.h"
 
 preferencestype preferences;
 extern gchar *xlogdir;
-#define PREFERENCES_VERSION 5
-gboolean newprefsfile = FALSE;
 
-static void make_default_preferences (void)
+static gint make_default_preferences (void)
 {
-	preferences.version = 0;
 	preferences.x = 10;
 	preferences.y = 30;
 	preferences.width = 750;
@@ -67,14 +63,10 @@ static void make_default_preferences (void)
 	preferences.polltime = 0;
 	preferences.clock = 0;
 	preferences.logfont = g_strdup ("Sans 10");
-	preferences.logcolor = 1;
 	preferences.autosave = 5;
 	preferences.savedir = g_strdup_printf ("%s%s.%s",
 		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
-	preferences.backupdir = g_strdup_printf ("%s%s.%s",
-		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
 	preferences.saving = 1;
-	preferences.backup = 1;
 	preferences.logstoload = g_strdup ("*");
 	preferences.locator = g_strdup ("AA00AA");
 	preferences.freefield1 = g_strdup ("UNKNOWN");
@@ -84,12 +76,13 @@ static void make_default_preferences (void)
 	preferences.defaultmode = g_strdup ("?");
 	preferences.defaulttxrst = g_strdup ("?");
 	preferences.defaultrxrst = g_strdup ("?");
+	preferences.defaultawards = g_strdup ("?");
 	preferences.defaultpower = g_strdup ("?");
 	preferences.defaultfreefield1 = g_strdup ("?");
 	preferences.defaultfreefield2 = g_strdup ("?");
 	preferences.defaultremarks = g_strdup ("?");
-	preferences.b4columns = g_strdup ("1,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0");
-	preferences.logcwidths = g_strdup ("50,100,50,50,100,50,50,50,50,50,50,50,100,100,100,100,100,200");
+	preferences.b4columns2 = g_strdup ("1,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0");
+	preferences.logcwidths2 = g_strdup ("50,100,50,50,100,50,50,50,50,100,50,50,50,100,100,100,100,100,200");
 	preferences.typeaheadfind = 1;
 	preferences.remoteadding = 1;
 	preferences.viewtoolbar = 1;
@@ -99,7 +92,7 @@ static void make_default_preferences (void)
 	preferences.b4width = 500;
 	preferences.b4height = 300;
 	preferences.saveasadif = 0;
-	preferences.saveastsv = g_strdup ("1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0");
+	preferences.saveastsv2 = g_strdup ("1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0");
 	preferences.handlebarpos = 300;
 	preferences.cwf1 = g_strdup ("cq de % % test");
 	preferences.cwf2 = g_strdup ("@ de %");
@@ -116,23 +109,28 @@ static void make_default_preferences (void)
 	preferences.cwcq = g_strdup ("tu %");
 	preferences.cwsp = g_strdup ("tu 5nn#");
 	preferences.cwspeed = 24;
+	preferences.backupdir = g_strdup_printf ("%s%s.%s",
+		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
+	preferences.backup = 1;
 	preferences.fcc = 0;
 	preferences.tsvcalc = 0;
+	preferences.viewscoring = 1;
+	preferences.scorex = 10;
+	preferences.scorey = 300;
+	preferences.scorewidth = 500;
+	preferences.scoreheight = 300;
+	preferences.scoringbands = g_strdup ("011011111110000000");
+	return 0;
 }
 
 void
 parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 {
 	xmlChar *key;
+
 	cur = cur->xmlChildrenNode;
 	while (cur != NULL)
 	{
-		if ((!xmlStrcmp(cur->name, (const xmlChar *)"version")))
-		{
-			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
-			preferences.version = atoi ((const char *)key);
-			free (key);
-		}
 		if ((!xmlStrcmp(cur->name, (const xmlChar *)"x")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
@@ -373,6 +371,12 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.defaultrxrst = g_strdup ((gchar *)key);
 			free (key);
 		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultawards")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.defaultawards = g_strdup ((gchar *)key);
+			free (key);
+		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultpower")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
@@ -397,16 +401,16 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.defaultremarks = g_strdup ((gchar *)key);
 			free (key);
 		}
-		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4columns")))
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4columns2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
-			preferences.b4columns = g_strdup ((gchar *)key);
+			preferences.b4columns2 = g_strdup ((gchar *)key);
 			free (key);
 		}
-		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logcwidths")))
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logcwidths2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
-			preferences.logcwidths = g_strdup ((gchar *)key);
+			preferences.logcwidths2 = g_strdup ((gchar *)key);
 			free (key);
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"typeaheadfind")))
@@ -463,10 +467,10 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.saveasadif = atoi ((const char *)key);
 			free (key);
 		}
-		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveastsv")))
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveastsv2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
-			preferences.saveastsv = g_strdup ((gchar *)key);
+			preferences.saveastsv2 = g_strdup ((gchar *)key);
 			free (key);
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"handlebarpos")))
@@ -589,6 +593,43 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.tsvcalc = atoi ((const char *)key);
 			free (key);
 		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"viewscoring")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.viewscoring = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"scorex")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.scorex = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"scorey")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.scorey = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"scorewidth")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.scorewidth = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"scoreheight")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.scoreheight = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"scoringbands")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.scoringbands = g_strdup ((gchar *)key);
+			free (key);
+		}
+
 	cur = cur->next;
 	}
 	return;
@@ -601,12 +642,6 @@ void parsesavepreferences (xmlNodePtr cur)
 
 	for (node = cur->children; node != NULL; node = node->next)
 	{
-		if (!g_ascii_strcasecmp ((gchar *)node->name, "version"))
-		{
-			key = g_strdup_printf ("%d", PREFERENCES_VERSION);
-			xmlNodeSetContent (node, (const xmlChar *)key);
-			g_free (key);
-		}
 		if (!g_ascii_strcasecmp ((gchar *)node->name, "x"))
 		{
 			key = g_strdup_printf ("%d", preferences.x);
@@ -775,12 +810,6 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
-		else if (!g_ascii_strcasecmp ((gchar *)node->name, "logcolor"))
-		{
-			key = g_strdup_printf ("%d", preferences.logcolor);
-			xmlNodeSetContent (node, (const xmlChar *)key);
-			g_free (key);
-		}
 		else if (!g_ascii_strcasecmp ((gchar *)node->name, "autosave"))
 		{
 			key = g_strdup_printf ("%d", preferences.autosave);
@@ -853,6 +882,12 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "defaultawards"))
+		{
+			key = g_strdup (preferences.defaultawards);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
 		else if (!g_ascii_strcasecmp ((gchar *)node->name, "defaultpower"))
 		{
 			key = g_strdup (preferences.defaultpower);
@@ -877,15 +912,15 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
-		else if (!g_ascii_strcasecmp ((gchar *)node->name, "b4columns"))
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "b4columns2"))
 		{
-			key = g_strdup (preferences.b4columns);
+			key = g_strdup (preferences.b4columns2);
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
-		else if (!g_ascii_strcasecmp ((gchar *)node->name, "logcwidths"))
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "logcwidths2"))
 		{
-			key = g_strdup (preferences.logcwidths);
+			key = g_strdup (preferences.logcwidths2);
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
@@ -943,9 +978,9 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
-		else if (!g_ascii_strcasecmp ((gchar *)node->name, "saveastsv"))
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "saveastsv2"))
 		{
-			key = g_strdup_printf ("%s", preferences.saveastsv);
+			key = g_strdup_printf ("%s", preferences.saveastsv2);
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
@@ -1069,6 +1104,43 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "viewscoring"))
+		{
+			key = g_strdup_printf ("%d", preferences.viewscoring);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "scorex"))
+		{
+			key = g_strdup_printf ("%d", preferences.scorex);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "scorey"))
+		{
+			key = g_strdup_printf ("%d", preferences.scorey);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "scorewidth"))
+		{
+			key = g_strdup_printf ("%d", preferences.scorewidth);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "scoreheight"))
+		{
+			key = g_strdup_printf ("%d", preferences.scoreheight);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "scoringbands"))
+		{
+			key = g_strdup (preferences.scoringbands);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+
 	}
 }
 
@@ -1076,166 +1148,93 @@ void parsesavepreferences (xmlNodePtr cur)
 static void
 newsavepreferences (xmlNodePtr cur)
 {
-	gchar *key;
+	gchar *homedir = g_strdup_printf ("%s%s.%s",
+		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
 
-	make_default_preferences ();
-	key = g_strdup_printf ("%d", PREFERENCES_VERSION);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"version", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.x);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"x", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.y);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"y", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.width);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"width", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.height);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"height", (const xmlChar *)key);
-	key = g_strdup_printf ("%3.2f", preferences.latitude);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"latitude", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.NS);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"NS", (const xmlChar *)key);
-	key = g_strdup_printf ("%3.2f", preferences.longitude);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"longitude", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.EW);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"EW", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.units);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"units", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.bands);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"bands", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.modes);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"modes", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.bandseditbox);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"bandseditbox", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.modeseditbox);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"modeseditbox", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.bandoptionmenu);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"bandoptionmenu", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.modeoptionmenu);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"modeoptionmenu", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.printall);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"printall", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.printsize);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"printsize", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.printpoint);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"printpoint", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.printorientation);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"printorientation", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.printdestination);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"printdestination", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.hamlib);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"hamlib", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.rigid);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"rigid", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.device);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"device", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.rigconf);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"rigconf", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.round);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"round", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.polltime);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"polltime", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.clock);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"clock", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.logfont);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"logfont", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.logcolor);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"logcolor", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.autosave);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"autosave", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.savedir);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"savedir", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.saving);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"saving", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.logstoload);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"logstoload", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.locator);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"locator", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.freefield1);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"freefield1", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.freefield2);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"freefield2", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.callsign);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"callsign", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultmhz);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultmhz", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultmode);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultmode", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaulttxrst);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaulttxrst", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultrxrst);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultrxrst", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultpower);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultpower", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultfreefield1);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultfreefield1", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultfreefield2);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultfreefield2", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.defaultremarks);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultremarks", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.b4columns);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4columns", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.logcwidths);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"logcwidths", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.typeaheadfind);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"typeaheadfind", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.remoteadding);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"remoteadding", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.viewtoolbar);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"viewtoolbar", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.viewb4);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"viewb4", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.b4x);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4x", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.b4y);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4y", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.b4width);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4width", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.b4height);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4height", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.saveasadif);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"saveasadif", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.saveastsv);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"saveastsv", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.handlebarpos);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"handlebarpos", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf1);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf1", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf2);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf2", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf3);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf3", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf4);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf4", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf5);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf5", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf6);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf6", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf7);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf7", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf8);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf8", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf9);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf9", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf10);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf10", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf11);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf11", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwf12);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf12", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwcq);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwcq", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.cwsp);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwsp", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.cwspeed);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwspeed", (const xmlChar *)key);
-	key = g_strdup_printf ("%s", preferences.backupdir);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"backupdir", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.backup);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"backup", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.fcc);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"fcc", (const xmlChar *)key);
-	key = g_strdup_printf ("%d", preferences.tsvcalc);
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"tsvcalc", (const xmlChar *)key);
-	g_free (key);
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"x", (const xmlChar *)"10");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"y", (const xmlChar *)"30");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"width", (const xmlChar *)"750");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"height", (const xmlChar *)"540");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"latitude", (const xmlChar *)"0.0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"NS", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"longitude", (const xmlChar *)"0.0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"EW", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"units", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"bands", (const xmlChar *)"1.8,3.5,7,10,14,18,21,24,28");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"modes", (const xmlChar *)"CW,USB,LSB,FM,PSK31,MFSK,MT63,SSTV");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"bandseditbox", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"modeseditbox", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"bandoptionmenu", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"modeoptionmenu", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"printall", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"printsize", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"printpoint", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"printorientation", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"printdestination", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"hamlib", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"rigid", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"device", (const xmlChar *)"/dev/ttyS1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"rigconf", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"round", (const xmlChar *)"3");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"polltime", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"clock", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"logfont", (const xmlChar *)"Sans 10");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"autosave", (const xmlChar *)"5");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"savedir", (const xmlChar *)homedir);
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"saving", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"logstoload", (const xmlChar *)"*");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"locator", (const xmlChar *)"AA00AA");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"freefield1", (const xmlChar *)"UNKNOWN");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"freefield2", (const xmlChar *)"UNKNOWN");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"callsign", (const xmlChar *)"N0CALL");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultmhz", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultmode", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaulttxrst", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultrxrst", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultawards", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultpower", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultfreefield1", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultfreefield2", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"defaultremarks", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4columns2", (const xmlChar *)"1,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"logcwidths2", (const xmlChar *)"50,100,50,50,100,50,50,50,50,100,50,50,50,100,100,100,100,100,200");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"typeaheadfind", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"remoteadding", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"viewtoolbar", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"viewb4", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4x", (const xmlChar *)"10");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4y", (const xmlChar *)"30");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4width", (const xmlChar *)"500");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"b4height", (const xmlChar *)"300");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"saveasadif", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"saveastsv2", (const xmlChar *)"1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"handlebarpos", (const xmlChar *)"300");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf1", (const xmlChar *)"cq de % % test");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf2", (const xmlChar *)"@ de %");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf3", (const xmlChar *)"@ ++5nn--#");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf4", (const xmlChar *)"tu 73");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf5", (const xmlChar *)"@");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf6", (const xmlChar *)"%");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf7", (const xmlChar *)"@ sri qso b4 gl");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf8", (const xmlChar *)"agn");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf9", (const xmlChar *)"?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf10", (const xmlChar *)"qrz?");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf11", (const xmlChar *)"pse k");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf12", (const xmlChar *)"++++test---- % %");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwcq", (const xmlChar *)"tu %");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwsp", (const xmlChar *)"tu 5nn#");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"cwspeed", (const xmlChar *)"24");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"backupdir", (const xmlChar *)homedir);
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"backup", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"fcc", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"tsvcalc", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"viewscoring", (const xmlChar *)"1");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"scorex", (const xmlChar *)"10");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"scorey", (const xmlChar *)"300");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"scorewidth", (const xmlChar *)"500");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoreheight", (const xmlChar *)"300");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoringbands", (const xmlChar *)"011011111110000000");
+	g_free (homedir);
 }
 
 void
@@ -1243,15 +1242,23 @@ loadpreferences (void)
 {
 	gchar *preferencesfile;
 	xmlDocPtr prefs;
-	xmlNodePtr cur, node;
+	xmlNodePtr cur;
+	gint result;
+	FILE *fp;
 
+	result = make_default_preferences ();
 
-	make_default_preferences ();
 	/* open preferences file */
 	preferencesfile =
 		g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "preferences.xml", NULL);
-	prefs = xmlParseFile (preferencesfile);
+	if (!(fp = fopen (preferencesfile, "r")))
+	{
+		g_free (preferencesfile);
+		return;
+	}
+	fclose (fp); 
 
+	prefs = xmlParseFile (preferencesfile);
 	if (prefs != NULL)
 	{
 		cur = xmlDocGetRootElement (prefs);
@@ -1279,37 +1286,27 @@ loadpreferences (void)
 		}
 		xmlFreeDoc (prefs);
 	}
-	else
-	{ /* create a new preferences file with defaults */
-		g_print (_("Creating a new preferences file...\n"));
-		prefs = xmlNewDoc ((const xmlChar *)"1.0");
-		cur = xmlNewDocRawNode (prefs, NULL, (const xmlChar *)"xlog", NULL);
-		xmlDocSetRootElement (prefs, cur);
-		node = xmlNewChild (cur, NULL, (const xmlChar *)"xlog_preferences", NULL);
-		newsavepreferences (node);
-		xmlSaveFormatFile (preferencesfile, prefs, 1);
-		xmlFreeDoc (prefs);
-		newprefsfile = TRUE;
-	}
 	g_free (preferencesfile);
 }
 
 void
 savepreferences (void)
 {
-	gchar *preferencesfile, *key;
+	gchar *preferencesfile;
 	xmlDocPtr prefs;
-	xmlNodePtr root, cur;
+	xmlNodePtr root, cur, node;
+	gint result;
 
-	/* open preferences file */
+	/* save defaults first, so we can parse the file later */
+	prefs = xmlNewDoc ((const xmlChar *)"1.0");
+	cur = xmlNewDocRawNode (prefs, NULL, (const xmlChar *)"xlog", NULL);
+	xmlDocSetRootElement (prefs, cur);
+	node = xmlNewChild (cur, NULL, (const xmlChar *)"xlog_preferences", NULL);
+	newsavepreferences (node);
 	preferencesfile =
 		g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "preferences.xml", NULL);
-	prefs = xmlParseFile (preferencesfile);
-	if (prefs == NULL )
-	{
-		g_warning (_("preferences not parsed successfully"));
-		return;
-	}
+	result = xmlSaveFormatFile (preferencesfile, prefs, 1);
+
 	root = xmlDocGetRootElement (prefs);
 	if (root == NULL)
 	{
@@ -1323,95 +1320,15 @@ savepreferences (void)
 		xmlFreeDoc (prefs);
 		return;
 	}
+	root = xmlDocGetRootElement (prefs);
 	cur = root->xmlChildrenNode;
 	while (cur != NULL)
 	{
 		if ((!xmlStrcmp(cur->name, (const xmlChar *)"xlog_preferences")))
-		{
 			parsesavepreferences (cur);
-			if (!newprefsfile && (preferences.version < 1))
-			{	
-		        /* introduced in xlog version 0.9.8 */
-				key = g_strdup_printf ("%d", PREFERENCES_VERSION);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"version", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.logcwidths);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"logcwidths", (const xmlChar *)key);
-				g_free (key);
-			}
-			if (!newprefsfile && (preferences.version < 2))
-			{	
-		        /* introduced in xlog version 0.9.10 */
-				key = g_strdup_printf ("%d", preferences.saveasadif);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"saveasadif", (const xmlChar *)key);
-				g_free (key);
-			}
-			if (!newprefsfile && (preferences.version < 3))
-			{	
-		        /* introduced in xlog version 1.1 */
-				key = g_strdup_printf ("%s", preferences.saveastsv);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"saveastsv", (const xmlChar *)key);
-				key = g_strdup_printf ("%d", preferences.handlebarpos);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"handlebarpos", (const xmlChar *)key);
-				g_free (key);
-			}
-			if (!newprefsfile && (preferences.version < 4))
-			{	
-		        /* introduced in xlog version 1.2 */
-				key = g_strdup_printf ("%s", preferences.cwf1);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf1", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf2);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf2", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf3);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf3", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf4);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf4", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf5);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf5", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf6);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf6", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf7);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf7", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf8);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf8", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf9);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf9", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf10);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf10", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf11);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf11", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwf12);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwf12", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwcq);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwcq", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.cwsp);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwsp", (const xmlChar *)key);
-				key = g_strdup_printf ("%d", preferences.cwspeed);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"cwspeed", (const xmlChar *)key);
-				key = g_strdup_printf ("%s", preferences.backupdir);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"backupdir", (const xmlChar *)key);
-				key = g_strdup_printf ("%d", preferences.backup);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"backup", (const xmlChar *)key);
-				key = g_strdup_printf ("%d", preferences.fcc);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"fcc", (const xmlChar *)key);
-				g_free (key);
-			}
-			if (!newprefsfile && (preferences.version < 5))
-			{	
-		        /* introduced in xlog version 1.3 */
-				key = g_strdup_printf ("%d", preferences.rigid);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"rigid", (const xmlChar *)key);
-				g_free (key);
-				key = g_strdup_printf ("%d", preferences.tsvcalc);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"tsvcalc", (const xmlChar *)key);
-				g_free (key);
-				key = g_strdup_printf ("%s", preferences.logfont);
-				xmlNewTextChild (cur, NULL, (const xmlChar *)"logfont", (const xmlChar *)key);
-				g_free (key);
-			}
-		}
 		cur = cur->next;
 	}
-	xmlSaveFormatFile (preferencesfile, prefs, 0);
+	result = xmlSaveFormatFile (preferencesfile, prefs, 1);
 	xmlFreeDoc (prefs);
 	g_free (preferencesfile);
 }
