@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
  * mode:<any one of CW,SSB,RTTY,PSK31,etc (will be converted to uppercase)>
  * tx:<report (RST) which you have send>
  * rx:<report (RST) which you have received>
+ * awards:<awards string, see the manual>
  * name:<name of the operator you have contacted>
  * qth:<town of the operator you have contacted>
  * notes:<additional notes>
@@ -49,6 +50,7 @@
  */
 
 #include <stdlib.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <errno.h>
 #include <gtk/gtk.h>
@@ -60,10 +62,16 @@
 #endif
 
 #include "remote.h"
-#include "types.h"
+#include "preferences.h"
 #include "log.h"
 #include "utils.h"
 #include "support.h"
+#include "main.h"
+
+/* Socket related includes */
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #if WANT_HAMLIB
 # include "hamlib-utils.h"
@@ -71,6 +79,7 @@
 
 msgtype msgbuf;
 remotetype remote;
+gint server_sockfd;
 extern statetype state;
 extern preferencestype preferences;
 extern glong msgid;
@@ -104,13 +113,13 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 		*dateentry, *gmtentry, *callentry, *endentry, *rstentry,
 		*myrstentry, *powerentry, *nameentry, *qthentry,
 		*locatorentry, *unknownentry1, *unknownentry2, *remtv,
-		*remarksvbox;
+		*remarksvbox, *awardshbox, *awardsentry;
 	GtkTextBuffer *b;
-	gchar *temp, **remoteinfo, *argument = NULL, *remarks;
+	gchar *temp, **remoteinfo, *argument = NULL, *remarks, *label;
 	gint i, j = 0, bandindex, modeindex, err = 0;
 	logtype *logw;
 	GtkTreeIter iter;
-	GtkTreeModel *model;
+	GtkListStore *model;
 	GtkTreePath *path;
 #if WANT_HAMLIB
 	GString *digits = g_string_new ("");
@@ -134,6 +143,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 		powerhbox = lookup_widget (mainwindow, "powerhbox");
 		unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
 		unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
+		awardshbox = lookup_widget (mainwindow, "awardshbox");
 
 		remoteinfo = g_strsplit (entry, "\1", 0);
 		for (;;)
@@ -257,6 +267,15 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				} /* don't bother adding endtime to remarks field */
 			}
 
+			else if (g_ascii_strncasecmp (remoteinfo[j], "awards:", 7) == 0)
+			{
+				if ((argument = getargument (remoteinfo[j])))
+				{
+					if (GTK_WIDGET_VISIBLE (awardshbox))
+						qso[AWARDS] = g_strndup (argument, 30);
+				}
+			}
+
 			else if (g_ascii_strncasecmp (remoteinfo[j], "name:", 5) == 0)
 			{
 				if ((argument = getargument (remoteinfo[j])))
@@ -396,7 +415,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				qso[BAND] = lookup_band (bandindex);
 			}
 			else
-				qso[BAND] =	gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
+				qso[BAND] = gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
 		}
 		if (g_ascii_strcasecmp (qso[MODE], "") == 0)
 		{
@@ -406,7 +425,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				qso[MODE] = lookup_mode (modeindex);
 			}
 			else
-				qso[MODE] =	gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
+				qso[MODE] = gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
 		}
 	
 		if (preferences.remoteadding == 1 && logw)
@@ -414,18 +433,22 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 			qso[NR] = g_strdup_printf ("%d", ++logw->qsos);
 	
 			/* add the QSO */
-			model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
-			gtk_tree_store_prepend (GTK_TREE_STORE (model), &iter, NULL);
-			gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
-				NR,	qso[NR], DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND],
-				CALL, qso[CALL], BAND, qso[BAND],	MODE, qso[MODE], RST, qso[RST],
-				MYRST, qso[MYRST], QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN],
-				POWER, qso[POWER], NAME, qso[NAME], QTH, qso[QTH], LOCATOR,
-				qso[LOCATOR], U1, qso[U1], U2, qso[U2], REMARKS, qso[REMARKS], -1);
+			model = GTK_LIST_STORE(gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview)));
+			gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+				NR, qso[NR], DATE, qso[DATE], GMT, qso[GMT],
+				GMTEND, qso[GMTEND], CALL, qso[CALL],
+				BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST],
+				MYRST, qso[MYRST], QSLOUT, qso[QSLOUT],
+				QSLIN, qso[QSLIN], AWARDS, qso[AWARDS],
+				POWER, qso[POWER], NAME, qso[NAME],
+				QTH, qso[QTH], LOCATOR, qso[LOCATOR],
+				U1, qso[U1], U2, qso[U2], REMARKS, qso[REMARKS], -1);
 	
 			/* scroll there */
 			path = gtk_tree_path_new_from_string ("0");
-			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(logw->treeview),	path, NULL, TRUE, 1.0, 0.0);
+			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(logw->treeview),
+				path, NULL, TRUE, 1.0, 0.0);
 			gtk_tree_path_free (path);
 			
       /* save with every log change */
@@ -439,8 +462,9 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 			{ /* autosave */
 				temp = g_strdup_printf (_("Remote data received from %s (#%d), QSO %s added"), remote.program, ++remote.nr, qso[NR]);
 				logw->logchanged = TRUE;
-				gtk_label_set_text (GTK_LABEL (logw->label),
-				g_strconcat (logw->logname, " *", NULL));
+				label = g_strdup_printf ("<b>%s*</b>", logw->logname);
+				gtk_label_set_markup (GTK_LABEL (logw->label), label);
+				g_free (label);
 			}
 			update_statusbar (temp);
 		}
@@ -477,6 +501,12 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 			myrstentry = lookup_widget (mainwindow, "myrstentry");
 			if (strlen(qso[MYRST]) > 0)
 				gtk_entry_set_text (GTK_ENTRY (myrstentry), qso[MYRST]);
+			if (GTK_WIDGET_VISIBLE (awardshbox))
+			{
+				awardsentry = lookup_widget (mainwindow, "awardsentry");
+				if (strlen(qso[AWARDS]) > 0)
+					gtk_entry_set_text (GTK_ENTRY (awardsentry), qso[AWARDS]);
+			}
 			if (GTK_WIDGET_VISIBLE (powerhbox))
 			{
 				powerentry = lookup_widget (mainwindow, "powerentry");
@@ -548,3 +578,63 @@ remote_entry (void)
 		addtolog_or_qsoframe (msgbuf.mtype, msgbuf.mtext);
 	return 1;
 }
+
+static gboolean 
+tcp_client_activity (GIOChannel *source, GIOCondition cond, gpointer data)
+{
+	gchar buf[1024];
+	guint num_read = 0;
+	GIOStatus res;
+
+	if (cond == G_IO_IN)
+	{
+		res = g_io_channel_read_chars (source, buf, sizeof (buf), &num_read, NULL);
+		buf[num_read] = '\0';
+		addtolog_or_qsoframe (88, buf);
+	}
+	close (g_io_channel_unix_get_fd (source));
+	return FALSE;
+}
+
+
+gboolean
+socket_entry (GIOChannel * channel, GIOCondition cond, gpointer data)
+{
+	gint new; /* new socket descriptor */
+	socklen_t client;
+	GIOChannel  *new_channel;
+	struct sockaddr_in client_addr;
+
+	if (cond == G_IO_IN)
+	{
+		if ((new = accept (g_io_channel_unix_get_fd (channel),
+			(struct sockaddr *)&client_addr, &client)) < 0)
+		{
+			update_statusbar (_("Unable to accept new connection"));
+			return FALSE;
+		}
+		new_channel = g_io_channel_unix_new (new);
+		g_io_add_watch (new_channel, G_IO_IN, tcp_client_activity, NULL);
+	}
+	return TRUE;
+}
+
+/* Socket Server AF_INET Setup */
+gint
+remote_socket_setup (void)
+{
+	gint server_len, result, tmp = 1;
+	struct sockaddr_in server_address;
+
+	server_sockfd = socket (AF_INET, SOCK_STREAM, 0);
+	result = setsockopt (server_sockfd, SOL_SOCKET, SO_REUSEADDR, (gchar *)&tmp, sizeof (tmp));
+	server_address.sin_family = AF_INET;
+	server_address.sin_addr.s_addr = INADDR_ANY;
+	server_address.sin_port = htons (7311);
+	server_len = sizeof (server_address);
+	if (result == 0)
+		result = bind (server_sockfd, (struct sockaddr *)&server_address, server_len);
+	if (result == 0)
+		result = listen (server_sockfd, 5);
+	return result;
+}
