@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,4 +21,23 @@
  * remote.h
  */
 
+/* struct for remote data state */
+typedef struct
+{
+	gint version;
+	gchar *program;
+	gint nr;
+}
+remotetype;
+
+/* struct for the message queue */
+typedef struct
+{
+	glong mtype;
+	gchar mtext[1024];
+}
+msgtype;
+
 gint remote_entry (void);
+gboolean socket_entry (GIOChannel * channel, GIOCondition cond, gpointer data);
+gint remote_socket_setup(void);
