@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ lookup_widget	(GtkWidget *widget,	const gchar *widget_name)
 
 	found_widget = (GtkWidget*) g_object_get_data (G_OBJECT (widget), widget_name);
 	if (!found_widget)
-		g_warning ("Widget not found: %s", widget_name);
+		g_warning (_("Widget not found: %s"), widget_name);
 	return found_widget;
 }
 
@@ -118,7 +118,8 @@ create_pixbuf(const gchar *filename)
 	pixbuf = gdk_pixbuf_new_from_file (pathname, &error);
 	if (!pixbuf)
 	{
-		fprintf (stderr, "Failed to load pixbuf file: %s: %s\n", pathname, error->message);
+		fprintf (stderr, _("Failed to load pixbuf file: %s: %s\n"),
+			pathname, error->message);
 		g_error_free (error);
 	}
 	g_free (pathname);
