@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,13 +40,16 @@
 #include <sys/shm.h>
 #endif
 
-#include "types.h"
 #include "log.h"
 #include "utils.h"
 #include "preferences.h"
 #include "support.h"
 #include "history.h"
 #include "dxcc.h"
+#include "gui_netkeyer.h"
+#include "remote.h"
+#include "callbacks_mainwindow_qsoframe.h"
+#include "main.h"
 
 #if WANT_HAMLIB
 #	include <hamlib/rig.h>
@@ -54,16 +57,13 @@
 #endif
 
 gint statusbartimer;
-extern GtkWidget *mainwindow;
-extern GtkWidget *keyerwindow;
-extern GtkWidget *b4dialog;
+extern GtkWidget *mainwindow, *keyerwindow, *b4window, *scorewindow;
 extern preferencestype preferences;
 extern statetype state;
 extern remotetype remote;
 extern gchar **qso;
 extern gchar *xlogdir;
-extern gint remotetimer;
-extern gint clocktimer, savetimer;
+extern gint remotetimer, clocktimer, savetimer, sockettimer;
 extern glong msgid;
 extern void *shareCall;
 extern GList *logwindowlist;
@@ -95,10 +95,12 @@ setlocation (gdouble lat, gint NS, gdouble lon, gint EW)
 void
 makebandoptionmenu (gchar *bands)
 {
-	GtkWidget *bandhbox2, *bandoptionmenu, *old;
+	GtkWidget *bandhbox2, *bandoptionmenu, *old, *entry, *label;
 	gchar **split;
 	gint index = 0;
 
+	entry = g_object_get_data (G_OBJECT (mainwindow), "bandentry");
+	label = g_object_get_data (G_OBJECT (mainwindow), "mhzlabel");
 	old = g_object_get_data (G_OBJECT (mainwindow), "bandoptionmenu");
 	if (old) gtk_widget_destroy (old);
 
@@ -119,15 +121,23 @@ makebandoptionmenu (gchar *bands)
 	gtk_combo_box_set_active (GTK_COMBO_BOX (bandoptionmenu),
 		preferences.bandoptionmenu);
 	GLADE_HOOKUP_OBJECT (mainwindow, bandoptionmenu, "bandoptionmenu");
+	if (preferences.bandseditbox == 1)
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
+	else
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), bandoptionmenu);
+	g_signal_connect (G_OBJECT(bandoptionmenu), "mnemonic-activate",
+		G_CALLBACK (bandoptionactivate), NULL);
 }
 
 void
 makemodeoptionmenu (gchar *modes)
 {
-	GtkWidget *modehbox2, *modeoptionmenu, *old;
+	GtkWidget *modehbox2, *modeoptionmenu, *old, *entry, *label;
 	gchar **split;
 	gint index = 0;
 
+	entry = g_object_get_data (G_OBJECT (mainwindow), "modeentry");
+	label = g_object_get_data (G_OBJECT (mainwindow), "modelabel");
 	old = g_object_get_data (G_OBJECT (mainwindow), "modeoptionmenu");
 	if (old) gtk_widget_destroy (old);
 
@@ -148,6 +158,12 @@ makemodeoptionmenu (gchar *modes)
 	gtk_combo_box_set_active (GTK_COMBO_BOX (modeoptionmenu),
 		preferences.modeoptionmenu);
 	GLADE_HOOKUP_OBJECT (mainwindow, modeoptionmenu, "modeoptionmenu");
+	if (preferences.modeseditbox == 1)
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
+	else
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), modeoptionmenu);
+	g_signal_connect (G_OBJECT(modeoptionmenu), "mnemonic-activate",
+		G_CALLBACK (modeoptionactivate), NULL);
 }
 
 /* removing leading and trailing whitespaces from an array of strings */
@@ -227,9 +243,9 @@ freeprefs (void)
 	g_free (preferences.defaultfreefield1);
 	g_free (preferences.defaultfreefield2);
 	g_free (preferences.defaultremarks);
-	g_free (preferences.b4columns);
-	g_free (preferences.logcwidths);
-	g_free (preferences.saveastsv);
+	g_free (preferences.b4columns2);
+	g_free (preferences.logcwidths2);
+	g_free (preferences.saveastsv2);
 	g_free (preferences.cwf1);
 	g_free (preferences.cwf2);
 	g_free (preferences.cwf3);
@@ -284,12 +300,12 @@ save_windowsize_and_cleanup (void)
 		preferences.viewtoolbar = 1;
 	else
 		preferences.viewtoolbar = 0;
-	if (GTK_WIDGET_VISIBLE(b4dialog))
+	if (GTK_WIDGET_VISIBLE(b4window))
 	{
 		preferences.viewb4 = 1;
-		gtk_window_get_size (GTK_WINDOW(b4dialog), 
+		gtk_window_get_size (GTK_WINDOW(b4window), 
 			&preferences.b4width, &preferences.b4height);
-		gtk_window_get_position (GTK_WINDOW(b4dialog), 
+		gtk_window_get_position (GTK_WINDOW(b4window), 
 			&preferences.b4x, &preferences.b4y);
 	}
 	else
@@ -300,12 +316,27 @@ save_windowsize_and_cleanup (void)
 		preferences.b4width = 500;
 		preferences.b4height = 300;
 	}
+	if (GTK_WIDGET_VISIBLE(scorewindow))
+	{
+		gtk_window_get_size (GTK_WINDOW(scorewindow), 
+			&preferences.scorewidth, &preferences.scoreheight);
+		gtk_window_get_position (GTK_WINDOW(scorewindow), 
+			&preferences.scorex, &preferences.scorey);
+		preferences.viewscoring = 1;
+	}
+	else
+	{
+		preferences.viewscoring = 0;
+		preferences.scorex = 10;
+		preferences.scorey = 300;
+		preferences.scorewidth = 500;
+		preferences.scoreheight = 300;
+	}
 
 	hpaned = lookup_widget (mainwindow, "hpaned");
 	preferences.handlebarpos = gtk_paned_get_position (GTK_PANED(hpaned));
-	if (keyerwindow)
-		g_signal_emit_by_name (G_OBJECT(keyerwindow), "delete-event");
 
+	if (keyerwindow) savekeyer ();
 	savepreferences ();
 	savehistory ();
 
@@ -321,6 +352,8 @@ save_windowsize_and_cleanup (void)
 		g_source_remove (savetimer);
 	if (clocktimer != -1)
 		g_source_remove (clocktimer);
+	if (sockettimer != -1)
+		g_source_remove (sockettimer);
 
 	/* remove message queue */
 #if HAVE_SYS_IPC_H
@@ -342,6 +375,90 @@ save_windowsize_and_cleanup (void)
 	freeremote ();
 }
 
+/* translate enumerated band to a meaningful string */
+gchar *
+band_enum2char (guint band_enum)
+{
+		switch (band_enum)
+		{
+			case BAND_2200: return g_strdup ("0.136");
+			case BAND_160: return g_strdup ("1.8");
+			case BAND_80: return g_strdup ("3.5");
+			case BAND_60: return g_strdup ("5.3");
+			case BAND_40: return g_strdup ("7");
+			case BAND_30: return g_strdup ("10");
+			case BAND_20: return g_strdup ("14");
+			case BAND_17: return g_strdup ("18");
+			case BAND_15: return g_strdup ("21");
+			case BAND_12: return g_strdup ("24");
+			case BAND_10: return g_strdup ("28");
+			case BAND_6: return g_strdup ("50");
+			case BAND_4: return g_strdup ("70");
+			case BAND_2: return g_strdup ("144");
+			case BAND_125CM: return g_strdup ("222");
+			case BAND_70CM: return g_strdup ("432");
+			case BAND_33CM: return g_strdup ("902");
+			case BAND_23CM: return g_strdup ("1296");
+		}
+		return NULL;
+}
+
+/* return band as enum from a given string */
+gint
+freq2enum (gchar * str)
+{
+	gchar *p;
+	guint fr;
+
+	p = g_strrstr (str, ".");
+	if (p)
+	{
+		*p = '\0';
+		fr = atoi (str);
+		switch (fr)
+		{
+			case 0: return BAND_2200;
+			case 1: return BAND_160;
+			case 3: return BAND_80;
+			case 5: return BAND_60;
+			case 7: return BAND_40;
+			case 10: return BAND_30;
+			case 14: return BAND_20;
+			case 18: return BAND_17;
+			case 21: return BAND_15;
+			case 24: return BAND_12;
+			case 28 ... 29: return BAND_10;
+			case 50 ... 54: return BAND_6;
+			case 70: return BAND_4;
+			case 144 ... 148: return BAND_2;
+			case 222 ... 225: return BAND_125CM;
+			case 420 ... 450: return BAND_70CM;
+			case 902 ... 928: return BAND_33CM;
+			case 1240 ... 1325: return BAND_23CM;
+		}
+	}
+	fr = atoi (str);
+	switch (fr)
+	{
+		case 5: return BAND_60;
+		case 7: return BAND_40;
+		case 10: return BAND_30;
+		case 14: return BAND_20;
+		case 18: return BAND_17;
+		case 21: return BAND_15;
+		case 24: return BAND_12;
+		case 28 ... 29: return BAND_10;
+		case 50 ... 54: return BAND_6;
+		case 70: return BAND_4;
+		case 144 ... 148: return BAND_2;
+		case 222 ... 225: return BAND_125CM;
+		case 420 ... 450: return BAND_70CM;
+		case 902 ... 928: return BAND_33CM;
+		case 1240 ... 1325: return BAND_23CM;
+	}
+	return -1;
+}
+
 /* find dot in frequency and return correct band */
 gchar *
 finddot (gchar * str)
@@ -359,14 +476,16 @@ finddot (gchar * str)
 			break;
 		}
 	}
-	if (g_ascii_strcasecmp (qsoband, "1") == 0)
+
+	/* no conversion needed for 7, 10, 14, 18, 21 and 24 MHz */
+	if (g_ascii_strcasecmp (qsoband, "0") == 0)
+		found = "0.136";
+	else if (g_ascii_strcasecmp (qsoband, "1") == 0)
 		found = "1.8";
 	else if (g_ascii_strcasecmp (qsoband, "3") == 0)
 		found = "3.5";
 	else if (g_ascii_strcasecmp (qsoband, "5") == 0)
 		found = "5.3";
-	else if (g_ascii_strcasecmp (qsoband, "7") == 0)
-		found = "7";
 	else if (g_ascii_strcasecmp (qsoband, "29") == 0)
 		found = "28";
 	else found = qsoband;
@@ -391,25 +510,6 @@ finddot (gchar * str)
 	return (g_strdup(found));
 }
 
-/* find dot in frequency and return string before the dot */
-gchar *
-findint (gchar * freq)
-{
-	gchar *end, *j;
-
-	end = freq + strlen (freq);
-	for (j = freq; j < end; ++j)
-		{
-			switch (*j)
-	{
-	case '.':
-		*j = '\0';
-		break;
-	}
-		}
-	return (freq);
-}
-
 /* try to find the correct band for dupe checking */
 gchar *
 findband (gchar * arg)
@@ -474,7 +574,7 @@ getdate (void)
 
 	time (&current);
 	timestruct = localtime (&current);
-	strftime (datenow, 20, "%d %b %Y", timestruct);
+	strftime (datenow, sizeof(datenow), "%d %b %Y", timestruct);
 
 	if (!g_utf8_validate (datenow, -1, NULL ))
 	{
@@ -501,7 +601,7 @@ gettime (void)
 
 	time (&current);
 	timestruct = localtime (&current);
-	strftime (stimenow, 20, "%H%M", timestruct);
+	strftime (stimenow, sizeof(stimenow), "%H%M", timestruct);
 	return (g_strdup (stimenow));
 }
 
@@ -583,7 +683,9 @@ autosave (void)
 		{
 			savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
 			logw->logchanged = FALSE;
-			gtk_label_set_text (GTK_LABEL (logw->label), logw->logname);
+			temp = g_strdup_printf ("<b>%s</b>", logw->logname);
+			gtk_label_set_markup (GTK_LABEL (logw->label), temp);
+			g_free (temp);
 			message = TRUE;
 		}
 	}
@@ -605,18 +707,19 @@ void
 set_qsoframe (gpointer arg)
 {
 	gint i, j;
-	GtkWidget *endhbox, *powerhbox, *namehbox, *locatorhbox, *qthhbox,
+	GtkWidget *endhbox, *awardshbox, *powerhbox, *namehbox, *locatorhbox, *qthhbox,
 		*unknown1hbox, *unknown2hbox, *powerbutton, *powerlabel, *qslhbox,
 		*locatorframe, *remarksvbox, *clearallmenu;
 	logtype *logw = (logtype *) arg;
 
 	endhbox = lookup_widget (mainwindow, "endhbox");
+	awardshbox = lookup_widget (mainwindow, "awardshbox");
 	powerhbox = lookup_widget (mainwindow, "powerhbox");
 	qslhbox = lookup_widget (mainwindow, "qslhbox");
 	namehbox = lookup_widget (mainwindow, "namehbox");
 	qthhbox = lookup_widget (mainwindow, "qthhbox");
 	locatorhbox = lookup_widget (mainwindow, "locatorhbox");
-	locatorframe = lookup_widget (mainwindow, "locatorframe");
+	locatorframe = lookup_widget (scorewindow, "locatorframe");
 	unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
 	unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
 	remarksvbox = lookup_widget (mainwindow, "remarksvbox");
@@ -635,6 +738,13 @@ set_qsoframe (gpointer arg)
 			else
 				gtk_widget_show (endhbox);
 		}
+		else if (i == AWARDS)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (awardshbox);
+			else
+				gtk_widget_show (awardshbox);
+		}
 		else if (i == POWER)
 		{
 			powerbutton = lookup_widget (mainwindow, "powerbutton");
@@ -763,3 +873,29 @@ my_strreplace(const char *str, const char *delimiter, const char *replacement)
 
 	return ret;
 }
+
+/* check if the awards entry contains a valid DXCC string */
+gchar *
+valid_awards_entry (gchar *a)
+{
+	gchar **s = g_strsplit (a, ",", -1);
+	gchar **dxcc = NULL, *dup = NULL;
+	guint i = 0;
+
+	for (;;)
+	{
+		if (s[i] == NULL) break;
+		dxcc = g_strsplit (s[i], "-", -1);
+		if (strcmp (dxcc[0], "DXCC-") && dxcc[1] && strlen (dxcc[1]) > 0)
+			{
+				g_strfreev (s);
+				dup = g_strdup (dxcc[1]);
+				g_strfreev (dxcc);
+				return (dup);
+			}
+		i++;
+	}
+	if (dxcc) g_strfreev (dxcc);
+	g_strfreev (s);
+	return dup;
+}
