@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,9 @@ void deletespaces (gchar ** split);
 void update_statusbar (gchar * string);
 gboolean remove_prefixes (gchar * key, gpointer value, gpointer user_data);
 void save_windowsize_and_cleanup (void);
+gchar *band_enum2char (guint band_enum);
+gint freq2enum (gchar * str);
 gchar *finddot (gchar * qsoband);
-gchar *findint (gchar * freq);
 gchar *findband (gchar * arg);
 gchar *getdate (void);
 gchar *gettime (void);
@@ -37,8 +38,8 @@ gchar *lookup_mode (gint index);
 gchar *lookup_band (gint index);
 gint updateclock (void);
 gchar *color_parse (gchar * value);
-gchar *getlabelcolor (GtkWidget * label);
 gint autosave (void);
 void set_qsoframe (gpointer arg);
 gboolean fileexist (gchar * path);
 gchar *my_strreplace(const char *str, const char *delimiter, const char *replacement);
+gchar *valid_awards_entry (gchar *a);
